@@ -16,7 +16,7 @@
     </message>
     <message>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
-        <translation>Lliberáu baxo la &lt;a href=&apos;%1&apos;&gt;Llicencia Pública Xeneral GNU&lt;/a&gt;</translation>
+        <translation>Asoleyáu baxo la &lt;a href=&apos;%1&apos;&gt;Llicencia Pública Xeneral GNU&lt;/a&gt;</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduz %1 a la to llingua llariega usando %2</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Con llicencia pa: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Escriba los detalles de la llicencia</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>Corréu &amp;electrónicu:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Códigu:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Por favor, merca una llicencia de %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Esta demo caducó.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Ensin llicencia, l&apos;aplicación caducará en %1 díes.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Al comprar la versión completa, tamién sofites el duru trabayu que punxi pa crear %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Usar la demostración</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Escriba la llicencia</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Mercar una llicencia</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>La versión completa permite amestar más de %1 pistes a la llista de reproducción y sentir la música ensin cortes.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Lleer más</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artista</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Títulu</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Añu</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularidá</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Orde inversu</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordenar por</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Lleer más</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Númberu de pistes</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Númberu d&apos;álbumes</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Añu</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularidá</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Orde inversu</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordenar por</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -104,7 +216,7 @@
     </message>
     <message>
         <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
-        <translation>%1 coneutará colos servicios web de Last.fm y pasará-y los nomes d&apos;artistes y títulos d&apos;álbumes pa baxar portaes d&apos;álbumes, biografíes y muncho más.</translation>
+        <translation>%1 coneutará colos servicios web de Last.fm y pasará-y los nomes d&apos;artistes y títulos d&apos;álbumes pa baxar imaxes de portaes, biografíes y muncho más.</translation>
     </message>
     <message>
         <source>If you have privacy concerns about this you can quit now.</source>
@@ -134,14 +246,14 @@
     <name>CollectionScanner</name>
     <message>
         <source>A scanning task is already running</source>
-        <translation>Yá ta executándose una xera d&apos;escanéu</translation>
+        <translation>Yá ta executándose una xera d&apos;analís</translation>
     </message>
 </context>
 <context>
     <name>CollectionScannerView</name>
     <message>
         <source>%1 is scanning your music collection.</source>
-        <translation>%1 ta escaneando la to coleición de música.</translation>
+        <translation>%1 ta analizando la coleición de música.</translation>
     </message>
     <message>
         <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Esta demo caducó.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Esta demo caducará en %1 díes.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Usar la demostración</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation type="unfinished"/>
+        <source>Downloading update...</source>
+        <translation>Descargando l&apos;anovamientu…</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,34 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Falló la identificación</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Anicia sesión en %1</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>Nome d&apos;&amp;usuariu:</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>Contrase&amp;ña:</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>Crear una cuenta en %1</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>¿Escaecisti&apos;l &lt;a href=&apos;%1&apos;&gt;nome d&apos;usuariu&lt;/a&gt; o la &lt;a href=&apos;%2&apos;&gt;contraseña&lt;/a&gt;?</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Encaboxar</translation>
     </message>
 </context>
 <context>
@@ -366,7 +458,7 @@
     </message>
     <message>
         <source>&amp;Quit</source>
-        <translation type="unfinished"/>
+        <translation>Co&amp;lar</translation>
     </message>
     <message>
         <source>Bye</source>
@@ -390,7 +482,7 @@
     </message>
     <message>
         <source>Make a &amp;donation</source>
-        <translation>Facer un &amp;donativu</translation>
+        <translation>Facer una &amp;donación</translation>
     </message>
     <message>
         <source>Please support the continued development of %1</source>
@@ -482,7 +574,7 @@
     </message>
     <message>
         <source>Leave &amp;Full Screen</source>
-        <translation type="unfinished"/>
+        <translation>Dexar pan&amp;talla completa</translation>
     </message>
     <message>
         <source>Remaining time: %1</source>
@@ -502,7 +594,7 @@
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"/>
+        <translation>Consigui la versión completa</translation>
     </message>
     <message>
         <source>%1 version %2 is now available.</source>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Avisame más sero</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Update</source>
         <translation>Anovar</translation>
@@ -538,18 +626,34 @@
     </message>
     <message>
         <source>&amp;Stop After This Track</source>
-        <translation type="unfinished"/>
+        <translation>Parar dempué&amp;s d&apos;esta pista</translation>
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Scrobbling</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Unviar los títulos reproducíos a %1</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
+        <translation>Co&amp;lar de %1</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Informar d&apos;un problema...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Guetar</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 acabó d&apos;analizar la coleición de música.</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -580,11 +684,45 @@
         <translation>Consiguir la versión completa</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Hai disponible una versión nueva de %1.</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 yá ta disponible. Tienes %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>¿Quies descargala agora?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Saltar esta versión</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Recordámelo más sero </translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Instalar anovamientu</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Apegar</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
         <source>This demo is limited to only %1 tracks in the playlist.</source>
-        <translation type="unfinished"/>
+        <translation>La versión de prueba ta llendada a sólo %1 pistes na llista de reproducción.</translation>
     </message>
 </context>
 <context>
