@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Tradueix %1 al teu idioma utilitzant %2</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Llicenciat a: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Entra els detalls de la teva llicència</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Email:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Codi:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Si us plau, llicencia el %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Aquesta demo ha expirat.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Sense llicència, l&apos;aplicació caducarà en %1 dies</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Comprant la versió completa, també donarà suport al dur treball que he posat en la creació del %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Utilitza la demo</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Entra la lliçència </translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Comprar llicència</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>La versió completa us permet afegir més de %1 pistes a la llista de reproducció i escoltar la vostra música sense interrupcions</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Llegeix més</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artista</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Títol</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Any</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularitat</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordre invers</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordena per</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Llegeix més</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Ordena per pista</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Ordena per àlbum</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nom</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Any</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularitat</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordre invers</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordena per</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Benvinguts a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Benvinguts al &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Si us plau, llicencia el %1</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Aquesta demo ha expirat.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Aquesta demo expira en %1 dies.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Comprant la versió completa, també donarà suport al dur treball que he posat en la creació del %1.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Utilitza la demo</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Aconsegueix la versió completa</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation>La versió completa us permet afegir més de %1 pistes a la llista de reproducció i escoltar la vostra música sense interrupcions.</translation>
+        <source>Downloading update...</source>
+        <translation>Descarregant actualitzacions...</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,34 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Autentificació fallida</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Entra a %1</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>Nom d&apos;&amp;Usuari:</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Contrassenya:</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>Crea un compte de %1</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>Heu oblidat el vostre &lt;a href=&apos;%1&apos;&gt;Nom d&apos;Usuari&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;Contrassenya&lt;/a&gt;?</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancel·la</translation>
     </message>
 </context>
 <context>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Recorda&apos;m-ho més tard</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>Per aconseguir la versió actualitzada, descarregeu %1 de nou des del link que heu rebut via email i reinstal·leu.</translation>
-    </message>
     <message>
         <source>Update</source>
         <translation>Actualitza</translation>
@@ -542,15 +630,31 @@
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Scrobbling</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Envia les pistes reproduïdes a %1</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Surt de %1</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Informa d&apos;un problema...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Cerca</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 acaba d&apos;escanejar la vostra col·lecció de música</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation>T&apos;&amp;Agrada %1? Puntua&apos;l!</translation>
     </message>
 </context>
 <context>
@@ -580,6 +684,40 @@
         <translation>Aconsegueix la versió completa</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Una nova versió de %1 està disponible</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 estan disponibles. Tu tens %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>T&apos;agradaria descarregar-ho ara?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Omet aquesta versió</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Recorda-m&apos;ho després</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Instal·la Actualització</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Enganxar</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
