@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Übersetze %1 mit %2 in deine Muttersprache</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Lizensiert für: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Geben Sie die Details Ihrer Lizenz ein</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Email:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Code:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Bitte lizensiere %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Diese Testversion ist abgelaufen.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Ohne Lizenz wird die Testversion der Anwendung in %1 Tagen ablaufen.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Mit dem Kauf der Vollversion unterstützt Du auch die viele Arbeit, die ich in %1 gesteckt habe.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Die Testversion benutzen</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Lizenz eingeben</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Lizenz kaufen</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>In der Vollversion kannst du mehr als %1 Titel in die Abspielliste einfügen und ohne Unterbrechungen Musik hören.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Mehr erfahren</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artist</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Titel</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Jahr</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Beliebtheit</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Umgekehrte Reihenfolge</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sortieren nach</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Mehr erfahren</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Anzahl der Titel</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Anzahl der Alben</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Name</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Jahr</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Beliebheit</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Umgekehrte Reihenfolge</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sortieren nach</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Bitte %1 lizensieren</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Diese Demo ist abgelaufen.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Diese Demo läuft in %1 Tag ab.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Durch den Kauf der Vollversion unterstützt du auch die harte Arbeit, die ich in die Erstellung von %1 stecke.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Demo verwenden</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Vollversion bekommen</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation>In der Vollversion kannst du mehr als %1 Titel in die Abspielliste einfügen und ohne Unterbrechungen Musik hören.</translation>
+        <source>Downloading update...</source>
+        <translation>Lade Update herunter...</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,34 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Authentifizierung fehlgeschlagen</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Bei %1 einloggen</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Benutzername:</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Passwort:</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>Für einen %1 Account anmelden</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>&lt;a href=&apos;%1&apos;&gt;Benutzername&lt;/a&gt; oder &lt;a href=&apos;%2&apos;&gt;Passwort&lt;/a&gt; vergessen?</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Später erinnern</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>Um die aktuelle Version zu bekommen, lade %1 noch einmal über den Link herunter, den du per Email bekommen hast und installiere es erneut. </translation>
-    </message>
     <message>
         <source>Update</source>
         <translation>Updaten</translation>
@@ -542,14 +630,30 @@
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Scrobbling</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Gespielte Titel an %1 senden</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
+        <translation>Von %1 &amp;ausloggen</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>Ein Problem &amp;melden...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Suchen</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 hat die Musiksammlung vollständig eingelesen</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -580,6 +684,40 @@
         <translation>Hol dir die Vollversion</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Es ist eine neue Version von %1 verfügbar!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 ist jetzt verfügbar. Du hast aktuell %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Würdest Du diese jetzt gerne runterladen?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Diese Version überspringen</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Mich später erinnern</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Update installieren</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Einfügen</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
