@@ -32,11 +32,11 @@
     </message>
     <message>
         <source>You may want to try my other apps as well:</source>
-        <translation type="unfinished"/>
+        <translation>Μπορεί, επίσης, να θέλετε να δοκιμάσετε και τις άλλες μου εφαρμογές:</translation>
     </message>
     <message>
         <source>%1, a YouTube app</source>
-        <translation type="unfinished"/>
+        <translation>%1, μια εφαρμογή του Youtube</translation>
     </message>
     <message>
         <source>%1, a YouTube music player</source>
@@ -44,7 +44,61 @@
     </message>
     <message>
         <source>Translate %1 to your native language using %2</source>
-        <translation type="unfinished"/>
+        <translation>Μετάφραση %1 στην μητρική σας γλώσσα με την χρήση %2</translation>
+    </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Αδειοδοτημένο στον/ην: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Εισάγετε τις λεπτομέρειες της άδειας χρήσης</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Email:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Κωδικός:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Παρακαλώ αποκτήστε την άδεια χρήσης του %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Αυτή η δοκιμαστική έκδοση έληξε.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Χωρίς την άδεια χρήσης, η εφαρμογή θα λήξη σε %1 μέρες</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Αγοράζοντας την πλήρη έκδοση, υποστηρίζετε επίσης την σκληρή δουλειά που έχω κάνει για τη δημιουργία του %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Χρήση της δοκιμαστικής έκδοσης</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Εισαγωγή άδειας χρήσης</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Αγορά άδειας χρήσης</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>Η πλήρη έκδοση σας επιτρέπη να προσθέσετε περισσότερα απο %1 κομμάτια στην λίστα αναπαραγωγής και να ακούτε την μουσική σας χωρίς διακοπές.</translation>
     </message>
 </context>
 <context>
@@ -58,6 +112,33 @@
         <translation>Διαβάστε περισσότερα</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Καλλιτέχνης</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Τίτλος</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Έτος</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Δημοτικότητα</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Αντίστροφη Σειρά</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ταξινόμηση κατά ...</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Διαβάστε περισσότερα</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Αριθμός Κομματιών</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Αριθμός Άλμπουμ</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>όνομα</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Έτος</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Δημοτικότητα</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Αντίστροφη Σειρά</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ταξινόμηση κατά ...</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Καλώς ήρθατε στο &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Καλωσορίσατε στο &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Παρακαλώ αποκτήστε την άδεια χρήσης του %1</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Αυτή η δοκιμαστική έκδοση έληξε.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Αυτή η δοκιμαστική έκδοση θα λήξει σε %1 ημέρες.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Αγοράζοντας την πλήρη έκδοση, υποστηρίζετε επίσης την σκληρή δουλειά που έχω κάνει για τη δημιουργία του %1.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Χρήση της δοκιμαστικής έκδοσης</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Αποκτήστε την πλήρη έκδοση</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation type="unfinished"/>
+        <source>Downloading update...</source>
+        <translation>Μεταφόρτωση ενημερώσεων...</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,34 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Αποτυχία πιστοποίησης</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Είσοδος στο %1</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Όνομα Χρήστη:</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Κωδικός:</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>Κάντε εγγραφή στο %1 για ένα λογαριασμό</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>Ξεχάσατε το &lt;a href=&apos;%1&apos;&gt;Όνομα Χρήστη&lt;/a&gt; ή &lt;a href=&apos;%2&apos;&gt;Κωδικός Χρήστη&lt;/a&gt;;</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Ακύρωση</translation>
     </message>
 </context>
 <context>
@@ -506,15 +598,11 @@
     </message>
     <message>
         <source>%1 version %2 is now available.</source>
-        <translation type="unfinished"/>
+        <translation>%1 έκδοση %2 είναι τώρα διαθέσιμη.</translation>
     </message>
     <message>
         <source>Remind me later</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation type="unfinished"/>
+        <translation>Υπενθήμηση αργότερα</translation>
     </message>
     <message>
         <source>Update</source>
@@ -538,18 +626,34 @@
     </message>
     <message>
         <source>&amp;Stop After This Track</source>
-        <translation type="unfinished"/>
+        <translation>%Σταμάτημα Μετά Από Αυτό Το Κομμάτι</translation>
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Scrobbling</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Αποστολή τίτλων κομματιών, που έχουν αναπαραχθεί, στο %1</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
+        <translation>&amp;Αποσύνδεση από %1</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Αναφέρετε κάποιο σφάλμα...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Αναζήτηση</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 ολοκλήρωσε τη σάρωση της μουσικής σας συλλογής</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -580,11 +684,45 @@
         <translation>Αποκτήστε την πλήρη έκδοση</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Μια νέα έκδοση του %1 είναι διαθέσιμη!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>Η %1 %2 είναι διαθέσιμη. Έχετε την %3</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Θα θέλατε να την κατεβάσετε τώρα;</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Παράλειψη αυτής της έκδοσης</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Υπενθύμισε το μου αργότερα</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Εγκατάσταση Ενημερώσεων</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Επικόλληση</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
         <source>This demo is limited to only %1 tracks in the playlist.</source>
-        <translation type="unfinished"/>
+        <translation>Στην δοκιμαστική έκδοση μπορείτε να προσθέσετε μόνο %1 κομμάτια στην λίστα αναπαραγωγής.</translation>
     </message>
 </context>
 <context>
@@ -609,7 +747,7 @@
     <name>SearchView</name>
     <message>
         <source>Your search had no results.</source>
-        <translation type="unfinished"/>
+        <translation>Η αναζήτηση σας δεν είχε κανένα αποτέλεσμα.</translation>
     </message>
 </context>
 <context>
