@@ -44,7 +44,61 @@
     </message>
     <message>
         <source>Translate %1 to your native language using %2</source>
-        <translation>Traduce %1 a tu idioma utilizando %2</translation>
+        <translation>Traduzca %1 a tu idioma utilizando %2</translation>
+    </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Con licencia para %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Introduzca la información de su licencia</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>Corr&amp;eo electrónico:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Código:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Introduzca la licencia de %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Esta versión de prueba ha caducado.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>La aplicación caducará en %1 días si no dispone de una licencia.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Al comprar la versión completa, también apoya el trabajo empleado en la creación de %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Utilizar la versión de prueba</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Introducir licencia</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Comprar licencia</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>La versión completa permite añadir más de %1 pistas a la lista de reproducción y escuchar música sin interrupciones.</translation>
     </message>
 </context>
 <context>
@@ -55,14 +109,72 @@
     </message>
     <message>
         <source>Read more</source>
-        <translation>Leer más</translation>
+        <translation>Más información</translation>
+    </message>
+</context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Intérprete</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Título</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Año</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularidad</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Orden inverso</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sortear por</translation>
     </message>
 </context>
 <context>
     <name>ArtistInfo</name>
     <message>
         <source>Read more</source>
-        <translation>Leer más</translation>
+        <translation>Más información</translation>
+    </message>
+</context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Número de pista</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Número de álbum</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nombre</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Año</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularidad</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Orden inverso</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Clasificar por</translation>
     </message>
 </context>
 <context>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Bienvenidos a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -127,7 +239,7 @@
     <name>ClearButton</name>
     <message>
         <source>Clear</source>
-        <translation>Limpiar</translation>
+        <translation>Borrar</translation>
     </message>
 </context>
 <context>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Introduzca la licencia de %1</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Esta versión de prueba ha caducado.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Días en que caduca esta versión de prueba: %1.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Al adquirir la versión completa, también apoya el gran esfuerzo que pongo en la creación de %1.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Utilizar versión de prueba</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obtener la versión completa</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation>La versión completa permite añadir más de %1 pistas a la lista de reproducción y escuchar su música sin interrupciones.</translation>
+        <source>Downloading update...</source>
+        <translation>Descargando actualización...</translation>
     </message>
 </context>
 <context>
@@ -289,6 +377,10 @@
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
         <translation>¿Ha olvidado su &lt;a href=&apos;%1&apos;&gt;nombre de usuario&lt;/a&gt; o su &lt;a href=&apos;%2&apos;&gt;contraseña?</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -322,7 +414,7 @@
     </message>
     <message>
         <source>Skip to the next track</source>
-        <translation>Omitir pista y saltar a la siguiente</translation>
+        <translation>Pasar a la siguiente pista</translation>
     </message>
     <message>
         <source>&amp;Play</source>
@@ -506,15 +598,11 @@
     </message>
     <message>
         <source>%1 version %2 is now available.</source>
-        <translation>%1 versión %2 ya está disponible.</translation>
+        <translation>La versión %2 de %1 ya se encuentra disponible.</translation>
     </message>
     <message>
         <source>Remind me later</source>
-        <translation>Recordarme después</translation>
-    </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>Para obtener la versión actualizada, descargue %1 de nuevo desde el enlace que recibió por correo, y reinstale.</translation>
+        <translation>Recordarme más tarde</translation>
     </message>
     <message>
         <source>Update</source>
@@ -552,6 +640,22 @@
         <source>&amp;Log Out from %1</source>
         <translation>&amp;Cerrar sesión de %1</translation>
     </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Informar de un problema...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Buscar</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 ha terminado de analizar su colección de música</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -580,6 +684,40 @@
         <translation>Obtener la versión completa</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>¡Una nueva versión de %1 ya se encuentra disponible!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 ya se encuentra disponible. Su versión es la %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>¿Desea descargarla ahora?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Saltar esta versión</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Recordarme después</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Instalar actualización</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Pegar</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
