@@ -12,11 +12,11 @@
     </message>
     <message>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
-        <translation type="unfinished"/>
+        <translation>&lt;a href=&apos;%1&apos;&gt;Lahjoita&lt;/a&gt; tukeaksesi %2n jatkokehitystä.</translation>
     </message>
     <message>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
-        <translation type="unfinished"/>
+        <translation>Julkaistu &lt;a href=&apos;%1&apos;&gt;GNU-hankkeen yleisellä lisenssillä&lt;/a&gt;</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -28,7 +28,7 @@
     </message>
     <message>
         <source>What you always wanted to know about %1 and never dared to ask</source>
-        <translation type="unfinished"/>
+        <translation>Mitä olet aina halunnut tietää sovelluksesta %1, mutta et ole koskaan kysynyt</translation>
     </message>
     <message>
         <source>You may want to try my other apps as well:</source>
@@ -46,18 +46,99 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Käännä %1 omalle kielellesi %2-palvelussa</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Lisensoitu henkilölle: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Syötä tähän lisenssitietosi</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Sähköposti:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Koodi:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Lisensioi %1.</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Tämä demon kokeiluaika on päättynyt.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Ilman lisenssiä tämä sovellus vanhenee %1 päivässä.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Ostamalla täyden version tuet työtäni %1n parissa.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Käytä demoa</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Syötä lisenssi</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Osta lisenssi</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>Täysversio sallii sinun lisätä useamman kuin %1 kappaletta soittolistaan ja kuunnella musiikkia keskeytyksettä.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
     <message>
         <source>Buy on %1</source>
-        <translation type="unfinished"/>
+        <translation>Osta palvelusta %1</translation>
     </message>
     <message>
         <source>Read more</source>
         <translation>Lue lisää</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artisti</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Nimi</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Vuosi</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Suosio</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Käänteinen järjestys</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Järjestysperuste</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Lue lisää</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Kappalemäärä</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Levymäärä</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nimi</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Vuosi</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Suosio</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Käänteinen järjestys</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Järjestysperuste</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,15 +192,15 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Tervetuloa sovellukseen &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Tervetuloa, käytössäsi on &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
-        <translation>%1 haluaa skannata musiikkikokoelmasi.</translation>
+        <translation>%1 haluaa tutkia musiikkikokoelmasi.</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Use iTunes collection</source>
@@ -104,11 +216,11 @@
     </message>
     <message>
         <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
-        <translation type="unfinished"/>
+        <translation>%1 yhdistää Last.fm-verkkopalveluihin ja välittää esittäjän sekä levyn nimen noutaakseen kansitaiteen, biografian ja paljon muuta.</translation>
     </message>
     <message>
         <source>If you have privacy concerns about this you can quit now.</source>
-        <translation type="unfinished"/>
+        <translation>Jos sinua mietityttää tämän yksityisyys, voit lopettaa nyt.</translation>
     </message>
     <message>
         <source>Where&apos;s your music collection?</source>
@@ -116,7 +228,7 @@
     </message>
     <message>
         <source>Select the location of your music collection.</source>
-        <translation type="unfinished"/>
+        <translation>Valitse musiikkikokoelmasi sijainti.</translation>
     </message>
     <message>
         <source>Locate your collection</source>
@@ -134,14 +246,14 @@
     <name>CollectionScanner</name>
     <message>
         <source>A scanning task is already running</source>
-        <translation>Skannaus on jo käynnissä</translation>
+        <translation>Tutkinta on jo käynnissä</translation>
     </message>
 </context>
 <context>
     <name>CollectionScannerView</name>
     <message>
         <source>%1 is scanning your music collection.</source>
-        <translation>%1 skannaa musiikkikirjastoasi.</translation>
+        <translation>%1 tutkii musiikkikirjastoasi.</translation>
     </message>
     <message>
         <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
@@ -157,41 +269,17 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Lisensioi %1.</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Tämä demon kokeiluaika on päättynyt.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Tämän demon kokeiluaika päättyy %1 päivän kuluttua</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Ostamalla täyden version tuet kovaa työtäni sovelluksen %1 parissa.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Käytä demoa</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Hanki täysversio</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation type="unfinished"/>
+        <source>Downloading update...</source>
+        <translation>Ladataan päivitystä...</translation>
     </message>
 </context>
 <context>
     <name>DropArea</name>
     <message>
         <source>Drop here to append to the playlist</source>
-        <translation type="unfinished"/>
+        <translation>Pudota tähän lisätäksesi soittolistaan</translation>
     </message>
 </context>
 <context>
@@ -253,11 +341,11 @@
     </message>
     <message>
         <source>Seek forward</source>
-        <translation type="unfinished"/>
+        <translation>Hae eteenpäin</translation>
     </message>
     <message>
         <source>Seek backward</source>
-        <translation type="unfinished"/>
+        <translation>Hae taaksepäin</translation>
     </message>
 </context>
 <context>
@@ -271,7 +359,7 @@
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Kirjaudu palveluun %1</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
@@ -283,12 +371,16 @@
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>Rekisteröi %1-tunnus</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
         <translation>Unohditko &lt;a href=&apos;%1&apos;&gt;käyttäjätunnuksesi&lt;/a&gt; tai &lt;a href=&apos;%2&apos;&gt;salasanasi&lt;/a&gt;?</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Peruuta</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -298,7 +390,7 @@
     </message>
     <message>
         <source>Go to the previous view</source>
-        <translation type="unfinished"/>
+        <translation>Mene edelliseen näkymään</translation>
     </message>
     <message>
         <source>&amp;Info</source>
@@ -314,7 +406,7 @@
     </message>
     <message>
         <source>Go back to the previous track</source>
-        <translation type="unfinished"/>
+        <translation>Siirry edelliseen kappaleeseen</translation>
     </message>
     <message>
         <source>&amp;Next</source>
@@ -322,7 +414,7 @@
     </message>
     <message>
         <source>Skip to the next track</source>
-        <translation type="unfinished"/>
+        <translation>Siirry seuraavaan kappaleeseen</translation>
     </message>
     <message>
         <source>&amp;Play</source>
@@ -334,7 +426,7 @@
     </message>
     <message>
         <source>&amp;Full Screen</source>
-        <translation>&amp;Kokonäyttö</translation>
+        <translation>&amp;Koko näyttö</translation>
     </message>
     <message>
         <source>Go full screen</source>
@@ -414,11 +506,11 @@
     </message>
     <message>
         <source>&amp;Shuffle</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Sekoita</translation>
     </message>
     <message>
         <source>Random playlist mode</source>
-        <translation type="unfinished"/>
+        <translation>Satunnainen soittolistatila</translation>
     </message>
     <message>
         <source>&amp;Repeat</source>
@@ -426,7 +518,7 @@
     </message>
     <message>
         <source>Play first song again after all songs are played</source>
-        <translation type="unfinished"/>
+        <translation>Toista ensimmäinen kappale uudestaan, kun kaikki laulut on toistettu</translation>
     </message>
     <message>
         <source>Mute volume</source>
@@ -438,11 +530,11 @@
     </message>
     <message>
         <source>&amp;Playback</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Toisto</translation>
     </message>
     <message>
         <source>Play&amp;list</source>
-        <translation type="unfinished"/>
+        <translation>So&amp;ittolista</translation>
     </message>
     <message>
         <source>&amp;View</source>
@@ -454,7 +546,7 @@
     </message>
     <message>
         <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation type="unfinished"/>
+        <translation>Paina %1 nostaaksesi äänenvoimakkuutta, %2 laskeaksesi äänenvoimakkuutta</translation>
     </message>
     <message>
         <source>Opening %1</source>
@@ -482,11 +574,11 @@
     </message>
     <message>
         <source>Leave &amp;Full Screen</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Poistu koko näytön tilasta</translation>
     </message>
     <message>
         <source>Remaining time: %1</source>
-        <translation type="unfinished"/>
+        <translation>Aikaa jäljellä: %1</translation>
     </message>
     <message>
         <source>Volume at %1%</source>
@@ -498,7 +590,7 @@
     </message>
     <message>
         <source>Volume is unmuted</source>
-        <translation type="unfinished"/>
+        <translation>Ääni on palautettu</translation>
     </message>
     <message>
         <source>Get the full version</source>
@@ -506,16 +598,12 @@
     </message>
     <message>
         <source>%1 version %2 is now available.</source>
-        <translation type="unfinished"/>
+        <translation>%1 versio %2 on nyt saatavilla.</translation>
     </message>
     <message>
         <source>Remind me later</source>
         <translation>Muistuta myöhemmin</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Update</source>
         <translation>Päivitä</translation>
@@ -542,15 +630,31 @@
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Scrobblaus</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Lähetä soitetut kappalenimet palveluun %1</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Kirjaudu ulos palvelusta %1</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Ilmoita ongelmasta...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Etsi</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 sai valmiiksi musiikkikokoelmasi tutkimisen</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation>&amp;Pidätkö %1sta? Arvostele se!</translation>
     </message>
 </context>
 <context>
@@ -569,7 +673,7 @@
     </message>
     <message>
         <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
-        <translation type="unfinished"/>
+        <translation>Se sallii muutamien kappaleiden toistamisen, jotta voit testata sovellusta ja todeta sen toimivuuden itselläsi.</translation>
     </message>
     <message>
         <source>Continue</source>
@@ -580,11 +684,45 @@
         <translation>Hanki täysversio</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Uusi versio sovelluksesta %1 on saatavilla!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 on nyt saatavilla. Sinulla on %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Haluatko ladata sen nyt?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Ohita tämä versio</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Muistuta minua myöhemmin</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Asenna päivitys</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Liitä</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
         <source>This demo is limited to only %1 tracks in the playlist.</source>
-        <translation type="unfinished"/>
+        <translation>Tässä demossa soittolistan koko on rajoitettu %1 kappaleeseen.</translation>
     </message>
 </context>
 <context>
