@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduisez %1 dans votre langue maternelle en utilisant %2</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Licence accordée à : %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Entrez les details de votre licence</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Email :</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Code :</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Veuillez obtenir une licence pour %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Cette version de démo a expiré.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>En l&apos;absence de licence, l&apos;application expirera dans %1 jours.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>En achetant la version complète, vous supporterai aussi le grand travail que j&apos;ai investi dans la création de %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Utilisez la version de démo</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Entrer une licence</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Acheter une licence</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>La version complète vous permet d&apos;ajouter plus d&apos;un morceau à la playlist et d&apos;écouter votre musique sans interruptions.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>En savoir plus</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artiste</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Titre</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Année</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularité</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordre inversé</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Trier par</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>En savoir plus</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Nombre de morceaux</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Nombre d’albums</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nom</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Année</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularité</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordre inversé</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Trier par</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Bienvenue dans &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Bienvenue sur &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -104,7 +216,7 @@
     </message>
     <message>
         <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
-        <translation>%1 va se connecter à Last.fm et transmettre le nom de l&apos;artiste et les titres de l&apos;album pour récupérer la couverture, la biographie et bien plus.</translation>
+        <translation>%1 va se connecter à Last.fm et transmettre le nom des artistes et les titres d&apos;album pour récupérer la couverture, la biographie et bien plus</translation>
     </message>
     <message>
         <source>If you have privacy concerns about this you can quit now.</source>
@@ -112,7 +224,7 @@
     </message>
     <message>
         <source>Where&apos;s your music collection?</source>
-        <translation>Où est stockée votre musique?</translation>
+        <translation>Où est stockée votre musique </translation>
     </message>
     <message>
         <source>Select the location of your music collection.</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Veuillez obtenir une licence pour %1</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Cette version démo a expiré.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Cette version démo s&apos;expire dans %1 jours.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>En achetant la version complète, vous supporterais aussi le le grand travail que j&apos;ai investi à la création de %1.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Utilisez la version démo</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obtenir la version complète</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation type="unfinished"/>
+        <source>Downloading update...</source>
+        <translation>Téléchargement de la mise à jour...</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,35 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Échec de l&apos;autentification</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Se connnecter à %1</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Nom d&apos;utilisateur</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Mot de passe</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>S&apos;enregistrer pour un compte %1</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>Vous avez oublié votre &lt;a href=&apos;%1&apos;&gt;nom d&apos;utilisateur&lt;/a&gt; ou votre &lt;a href=&apos;%2&apos;&gt;mot de passe&lt;/a&gt;?
+</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
     </message>
 </context>
 <context>
@@ -512,10 +605,6 @@
         <source>Remind me later</source>
         <translation>Me le rappeler plus tard</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>Pour obtenir la version mise à jour, téléchargez à nouveau %1 à partir du lien que vous avez reçu par e-mail et réinstallez la.</translation>
-    </message>
     <message>
         <source>Update</source>
         <translation>Mettre à jour</translation>
@@ -542,15 +631,31 @@
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Scrobbling</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Envoyer les pistes jouées vers %1</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Se déconnecter de %1</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Signaler un problème...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Chercher</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 a fini de parcourir votre collection musicale</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation>&amp;Aimer %1? Notez-le !</translation>
     </message>
 </context>
 <context>
@@ -580,6 +685,40 @@
         <translation>Obtenir la version complète</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Une nouvelle version de %1 est disponible !</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 est maintenant disponible. Vous avez %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Voulez-vous la télécharger maintenant ?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Sauter Cette Version</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Me Le Rappeler Plus Tard</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Installer La Mise à jour</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Coller</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
