@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Fordítsa le a(z) %1 programot az anyanyelvére a(z) %2 segítségével.</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Licencelve: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Adja meg a licence részleteit</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;E-mail:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Kód:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Kérem licencelje %1  </translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Ez a demo már lejárt.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Licenc nélkül az alkalmazás lejár %1 nap múlva.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>A teljes verzió megvételével, támogatni fogja a kemény munkát amit belefektettem a(z) %1 fejlesztésébe.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Demo használata</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Licenc megadása:</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Licenc vásárlása</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>A teljes verzió engedi hogy a lejátszólistájához %1 számnál többet hozzáadjon, és a zenéit megszakítások nélkül hallgassa.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Tudjon meg többet</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Tudjon meg többet</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Üdv a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;-ban,</translation>
+        <translation>Üdvözöl a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -88,7 +200,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Vissza</translation>
+        <translation>Mégse</translation>
     </message>
     <message>
         <source>Use iTunes collection</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Kérem licencelje %1  </translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Ez a demo már lejárt.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Ez a demo le fog járni %1 nap múlva.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>A teljes verzió megvételével, támogatni fogja a kemény munkát amit belefektettem a(z) %1 fejlesztésébe.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Demo használata</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Teljes verzió beszerzése</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation>A teljes verzió engedélyezi önnek, hogy %1 számnál többet adjon a lejátszólistájához, és megszakítások nélkül hallgathatja a zenéit.</translation>
+        <source>Downloading update...</source>
+        <translation>Frissítés letöltése...</translation>
     </message>
 </context>
 <context>
@@ -289,6 +377,10 @@
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
         <translation>Elfelejtette a &lt;a href=&apos;%1&apos;&gt;felhasználónevét&lt;/a&gt; vagy a &lt;a href=&apos;%2&apos;&gt;jelszavát&lt;/a&gt;?</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Mégse</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Emlékeztess késöbb</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>A frissítéshez töltsd le a(z) %1 programot újra a link segítségével amit e-mailben kapott, és telepítse újra a programot.</translation>
-    </message>
     <message>
         <source>Update</source>
         <translation>Frissítés</translation>
@@ -552,6 +640,22 @@
         <source>&amp;Log Out from %1</source>
         <translation>&amp;Kijelentkezés ebből: %1</translation>
     </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Hiba jelentése...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Keresés</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -580,6 +684,40 @@
         <translation>Teljes verzió beszerzése</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>%1 új verziója elérhető!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 most elérhető. Önnek %3 van.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Szeretné letölteni most?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Verzió kihagyása</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Emlékeztessen később</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Frissítés telepítése</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Beillesztés</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
