@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduci %1 nella tua lingua usando %2</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Licenziato a: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Inserisci i dati della tua licenza:</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Email:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Codice:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Compra %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Questa demo è scaduta.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Senza una licenza, l&apos;applicazione scadrà in %1 giorni.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Acquistando la versione completa, supporterai anche il lavoro che ho fatto per creare %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Usa la demo</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Inserisci la tua licenza</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Compra una licenza</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>La versione completa ti permette di aggiungere più di %1 tracce alla playlist e di ascoltare la tua musica senza interruzioni.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Continua</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artista</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Titolo</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Anno</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popolarità</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordine invertito</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordina per</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Continua</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Contatore tracce</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Contatore Album</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Anno</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popolarità</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordine Invertito</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordina per</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Benvenuto su &lt;a href=&quot;%1&quot;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Benvenuto su &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -153,38 +265,14 @@
     </message>
     <message>
         <source>Go grab a coffee</source>
-        <translation>Vatti a prendere un caffé</translation>
+        <translation>Ti va un caffé?</translation>
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Compra %1</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Questa demo è scaduta.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Questa demo scadrà tra %1 giorni.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Acquistando la versione completa supporterai anche il lavoro fatto per creare %1.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Usa la demo</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Compra la versione completa</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation>La versione completa ti permette di aggiungere più di %1 tracce alla playlist e di ascoltare la tua musica senza interruzioni.</translation>
+        <source>Downloading update...</source>
+        <translation>Download dell&apos;aggiornamento in corso...</translation>
     </message>
 </context>
 <context>
@@ -289,6 +377,10 @@
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
         <translation>Hai dimenticato il &lt;a href=&apos;%1&apos;&gt;nome utente&lt;/a&gt; o la &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annulla</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Ricordamelo più tardi</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>Per ottenere la versione aggiornata, scarica di nuovo %1 dal link che hai ricevuto per email e installa.</translation>
-    </message>
     <message>
         <source>Update</source>
         <translation>Aggiorna</translation>
@@ -552,6 +640,22 @@
         <source>&amp;Log Out from %1</source>
         <translation>&amp;Esci da %1</translation>
     </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Segnala un problema...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Ricerca</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 ho finito di scannerizzare la tua collezione musicale</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation>Ti piace %1?</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -580,6 +684,40 @@
         <translation>Compra la versione completa</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Una nuova versione di %1 è disponibile!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 è ora disponibile. Tu hai la %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Vuoi scaricare ora?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Salta questa versione</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Ricordamelo più tardi</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Installa aggiornamento</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Incolla</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
