@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Lisensiert til: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Angi lisensdetaljer</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;E-post:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Kode:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Vennligst lisensier %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Demoen er utløpt.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Uten lisens, vil programmet utløper i %1 dager.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Ved å kjøpe fullversjonen, støtter du det harde arbeidet som ble lagt inn i å skape %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Bruk demoen</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Angi Lisens</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Kjøp Lisens</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Les mer</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sorter etter</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Les mer</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sorter etter</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Kjøp fullversjonen</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation type="unfinished"/>
+        <source>Downloading update...</source>
+        <translation>Laster ned oppdatering...</translation>
     </message>
 </context>
 <context>
@@ -289,6 +377,10 @@
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Avbryte</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -512,13 +604,9 @@
         <source>Remind me later</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Update</source>
-        <translation type="unfinished"/>
+        <translation>Oppdater</translation>
     </message>
     <message>
         <source>&amp;Window</source>
@@ -552,6 +640,22 @@
         <source>&amp;Log Out from %1</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Rapporter et Problem</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Søk</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -580,6 +684,40 @@
         <translation>Få den fulle versjonen</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>En ny versjon av %1 er tilgjengelig!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 er nå tilgjengelig. Du har %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Vil du last den ned nå?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Hopp Over Denne Versjonen</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Minn Meg Senere</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Installer Oppdatering</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Lim</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
