@@ -28,23 +28,77 @@
     </message>
     <message>
         <source>What you always wanted to know about %1 and never dared to ask</source>
-        <translation>Wszystko, co zawsze chcieliście wiedzieć o %1 , a baliście się zapytać</translation>
+        <translation>Wszystko, co zawsze chcieliście wiedzieć o %1, a baliście się zapytać</translation>
     </message>
     <message>
         <source>You may want to try my other apps as well:</source>
-        <translation type="unfinished"/>
+        <translation>Być może chciałbyś wypróbować moje inne aplikacje:</translation>
     </message>
     <message>
         <source>%1, a YouTube app</source>
-        <translation type="unfinished"/>
+        <translation>%1, aplikacja YouTube</translation>
     </message>
     <message>
         <source>%1, a YouTube music player</source>
-        <translation type="unfinished"/>
+        <translation>%1, odtwarzacz muzyki YouTube</translation>
     </message>
     <message>
         <source>Translate %1 to your native language using %2</source>
-        <translation type="unfinished"/>
+        <translation>Przetłumacz %1 na twój język ojczysty używając %2</translation>
+    </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Licencjonowane dla: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Wpisz szczegóły Twojej licencji</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Email:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Kod:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Proszę licencjonować  %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>To demo wygasło.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Bez licencji ta aplikacja wygaśnie za %1 dni.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Przez zakup pełnej wersji wesprzesz również ciężką pracę, którą włożyłem w stworzenie %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Użyj Dema</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Wprowadź Licencję</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Kup Licencję</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>Pełna wersja pozwala na dodanie więcej niż %1 utworów do playlisty oraz słuchanie muzyki bez przerw.</translation>
     </message>
 </context>
 <context>
@@ -58,6 +112,33 @@
         <translation>Czytaj więcej</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artysta</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Tytuł</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Rok</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularność</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Odwrócona kolejność</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sortuj według</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Czytaj więcej</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Ilość utworów</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Ilość albumów</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nazwa</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Rok</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularność</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Odwrócona kolejność</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sortuj według</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Witamy w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Witaj w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Pobierz pełną wersję</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation type="unfinished"/>
+        <source>Downloading update...</source>
+        <translation>Ściąganie aktualizacji...</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,34 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Autoryzacja nie powiodła się</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Zaloguj do %1</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Nazwa użytkownika:</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Hasło:</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>Załóż konto dla %1</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>Zapomniałeś &lt;a href=&apos;%1&apos;&gt;nazwę użytkownika&lt;/a&gt; albo &lt;a href=&apos;%2&apos;&gt;hasło&lt;/a&gt;?</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Anuluj</translation>
     </message>
 </context>
 <context>
@@ -302,7 +394,7 @@
     </message>
     <message>
         <source>&amp;Info</source>
-        <translation>&amp;informacje</translation>
+        <translation>&amp;Informacje</translation>
     </message>
     <message>
         <source>Show information about the current track</source>
@@ -454,7 +546,7 @@
     </message>
     <message>
         <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation>Wciśnij %1 , aby zwiększyć głośność, %2, aby ją zmniejszyć</translation>
+        <translation>Wciśnij %1, aby zwiększyć głośność, %2, aby ją zmniejszyć</translation>
     </message>
     <message>
         <source>Opening %1</source>
@@ -506,27 +598,23 @@
     </message>
     <message>
         <source>%1 version %2 is now available.</source>
-        <translation type="unfinished"/>
+        <translation>%1 wersja %2 jest teraz dostępna.</translation>
     </message>
     <message>
         <source>Remind me later</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation type="unfinished"/>
+        <translation>Przypomnij później</translation>
     </message>
     <message>
         <source>Update</source>
-        <translation type="unfinished"/>
+        <translation>Aktualizuj</translation>
     </message>
     <message>
         <source>&amp;Window</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Okno</translation>
     </message>
     <message>
         <source>&amp;Minimize</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Minimalizuj</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -534,23 +622,39 @@
     </message>
     <message>
         <source>Buy %1...</source>
-        <translation type="unfinished"/>
+        <translation>Kup %1</translation>
     </message>
     <message>
         <source>&amp;Stop After This Track</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Zatrzymaj po tym tytule</translation>
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Skroblowanie</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Wyślij odsłuchane tytuły do %1</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Wyloguj z %1</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Zgłoś problem...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Szukaj</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 zakończono przeszukiwanie twojej kolekcji muzyki</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation>&amp;Kochasz %1? Oceń to!</translation>
     </message>
 </context>
 <context>
@@ -580,11 +684,45 @@
         <translation>Pobierz pełną wersję</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Nowa wersja %1 jest dostępna!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 jest już dostępny, Ty masz %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Czy chcesz to teraz pobrać?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Pomiń Tą Wersję</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Przypomnij Mi Później</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Zainstaluj aktualizację</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Wklej</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
         <source>This demo is limited to only %1 tracks in the playlist.</source>
-        <translation type="unfinished"/>
+        <translation>Ta wersja demo jest ograniczone do tylko %1 tytułów na liście odtwarzania.</translation>
     </message>
 </context>
 <context>
@@ -609,7 +747,7 @@
     <name>SearchView</name>
     <message>
         <source>Your search had no results.</source>
-        <translation type="unfinished"/>
+        <translation>Twoje wyszukiwanie nie przyniosło rezultatów.</translation>
     </message>
 </context>
 <context>
