@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>Traduza %1 para o seu idioma nativo usando %2</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Licenciado a: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Entre com seus Detalhes de Licença</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>E-mail:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>Código:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Por favor, licença %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Esta demonstração expirou.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Sem licença, a aplicação irá expirar em %1 dias.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Ao comprar a versão completa, você também vai apoiar o trabalho duro eu dediquei em criar %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Usar Demonstração</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Entrar com a Licença.</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Comprar a Licença.</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>A versão completa permite que você baixe vídeos com mais de %1 minutos e assista-os sem interrupções.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Leia mais</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Artista</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Título</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Ano</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularidade</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordem Inversa</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordenar por</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Leia mais</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Contador De Faixa</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Contador De Álbum</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Ano</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popularidade</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ordem Inversa</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Ordenar por</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Bem-vindo à &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Por favor, licença %1</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Esta demonstração expirou.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Esta demonstração irá expirar em %1 dias.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Ao comprar a versão completa, você também vai apoiar o trabalho duro eu dediquei em criar %1.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Usar Demonstração</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Obter a versão completa</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation>A versão completa permite que você baixe vídeos com mais de %1 minutos e assista-os sem interrupções.</translation>
+        <source>Downloading update...</source>
+        <translation>Baixando atualização...</translation>
     </message>
 </context>
 <context>
@@ -289,6 +377,10 @@
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
         <translation>Esqueceu seu &lt;a href=&apos;%1&apos;&gt;nome de usuário&lt;/a&gt; ou &lt;a href=&apos;%2&apos;&gt;senha&lt;/a&gt;?</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Lembrar mais tarde</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>Para obter a versão atualizada, baixe %1 novamente do link que você recebeu via e-mail e reinstale-o.</translation>
-    </message>
     <message>
         <source>Update</source>
         <translation>Atualizar</translation>
@@ -552,6 +640,22 @@
         <source>&amp;Log Out from %1</source>
         <translation>&amp;Sair de %1</translation>
     </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>&amp;Relatar um problema...</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Pesquisar</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1 finalizou a busca de sua coleção de músicas</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -580,6 +684,40 @@
         <translation>Obter a versão completa</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Uma nova versão do %1 está disponível!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 está disponível. Você está usando %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Gostaria de fazer o download agora?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Pular esta versão.</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Me lembre mais tarde.</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Instalar atualização.</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Colar.</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
