@@ -46,6 +46,60 @@
         <source>Translate %1 to your native language using %2</source>
         <translation>%1&apos;i, %2 kullanarak kendi dilinize çevirin</translation>
     </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>%1 için lisanslanmıştır</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Lisans bilgilerini girin</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Eposta:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>Kod:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Lütfen lisans %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Deneme süresi bitti.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Lisans olmazsa, uygulama süresi %1 gün içinde dolacaktır.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Tam sürümü alarak, aynı zamanda %1 yaratmamdaki üstün çabamı destekleyebilirsiniz.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Demo kullan</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Lisans Girin</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Lisans Al</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>Tam sürüm, çalma listesine %1&apos;den fazla parça eklemenize ve müziğinizi kesintisiz olarak dinlemenize izin verir.</translation>
+    </message>
 </context>
 <context>
     <name>AlbumInfo</name>
@@ -58,6 +112,33 @@
         <translation>Devamı</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation>Sanatçı</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Başlık</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Yıl</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popülerlik</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ters Sırada</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sırala</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Devamı</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation>Parça Sayısı</translation>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation>Albüm Sayısı</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>İsim</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>Yıl</translation>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation>Popülerlik</translation>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation>Ters Sırada</translation>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Sırala</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -80,7 +192,7 @@
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;e Hoş geldiniz,</translation>
+        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;a Hoş Geldiniz,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -157,34 +269,10 @@
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Lütfen %1&apos;i kaydettirin</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Bu deneme sürümünün süresi dolmuş.</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Bu deneme sürümünün süresi %1 gün içinde dolacak.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Tam sürümü satın alarak, %1&apos;i oluşturmaya harcadığım emeği de desteklemiş olacaksınız.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Deneme Sürümü Kullan</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Tam sürüme geç</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation>Tam sürüm, çalma listesine %1&apos;den fazla parça eklemenize ve müziklerinizi kesintisiz olarak dinlemenize izin verir.</translation>
+        <source>Downloading update...</source>
+        <translation>Güncelleme indiriliyor...</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,34 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Kimlik kanıtlama başarısız oldu</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>%1&apos;de oturum aç</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Kullanıcı Adı:</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Parola:</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>%1 hesabı için oturum aç</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>&lt;a href=&apos;%1&apos;&gt;kullanıcı adı&lt;/a&gt; vaye &lt;a href=&apos;%2&apos;&gt;parolanızı&lt;/a&gt; mı unuttunuz?</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Vazgeç</translation>
     </message>
 </context>
 <context>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Daha sonra hatırlat</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation>Güncellenmiş sürümü edinmek için, e-posta yoluyla aldığınız bağlantı üzerinden %1&apos;i indirin ve yeniden kurun.</translation>
-    </message>
     <message>
         <source>Update</source>
         <translation>Güncelle</translation>
@@ -542,15 +630,31 @@
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Skropluyor</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Çalınan parçalar %1&apos;e gönderildi</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
-        <translation type="unfinished"/>
+        <translation>%1 &amp;oturumunu kapat</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>Bir Sorun Bildi&amp;r</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Arama</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
+        <translation>%1, müzik koleksiyonunuzu taramayı bitirdi</translation>
+    </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation>%1&apos;i &amp;seviyor musunuz? Değerlendirin!</translation>
     </message>
 </context>
 <context>
@@ -580,6 +684,40 @@
         <translation>Tam sürümü al</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>%1 e ait yeni sürüm kullanılabilir.</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 şimdi kullanılabilir. Siz %3</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Bunu şimdi indirmek istiyor musunuz?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Bu Sürümü Geç</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Daha sonra Hatırlat</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Güncellemeyi Yükle</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Yapıştır</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
