@@ -8,7 +8,7 @@
     </message>
     <message>
         <source>%1 is Free Software but its development takes precious time.</source>
-        <translation>%1 це вільне програмне забезпечення, проте його розвиток займає дорогоцінний час.</translation>
+        <translation>%1 - вільне програмне забезпечення, проте його розвиток займає дорогоцінний час.</translation>
     </message>
     <message>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
@@ -32,7 +32,7 @@
     </message>
     <message>
         <source>You may want to try my other apps as well:</source>
-        <translation>Спробуйте інші програми:</translation>
+        <translation>Спробуйте також:</translation>
     </message>
     <message>
         <source>%1, a YouTube app</source>
@@ -44,7 +44,61 @@
     </message>
     <message>
         <source>Translate %1 to your native language using %2</source>
-        <translation type="unfinished"/>
+        <translation>Перекласти %1 на вашу рідну мову використовуючи %2</translation>
+    </message>
+    <message>
+        <source>Licensed to: %1</source>
+        <translation>Ліцензія належить: %1</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationDialog</name>
+    <message>
+        <source>Enter your License Details</source>
+        <translation>Введіть дані вашої ліцензії</translation>
+    </message>
+    <message>
+        <source>&amp;Email:</source>
+        <translation>&amp;Email:</translation>
+    </message>
+    <message>
+        <source>&amp;Code:</source>
+        <translation>&amp;Код:</translation>
+    </message>
+</context>
+<context>
+    <name>ActivationView</name>
+    <message>
+        <source>Please license %1</source>
+        <translation>Ліцензуйте %1</translation>
+    </message>
+    <message>
+        <source>This demo has expired.</source>
+        <translation>Пробний період вичерпано.</translation>
+    </message>
+    <message>
+        <source>Without a license, the application will expire in %1 days.</source>
+        <translation>Програма буде заблокована через %1 днів, якщо ви не купите ліцензію.</translation>
+    </message>
+    <message>
+        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
+        <translation>Купуючи повну версію, Ви також подякуєте за зусилля, які я вклав в створення %1.</translation>
+    </message>
+    <message>
+        <source>Use Demo</source>
+        <translation>Демонстрація</translation>
+    </message>
+    <message>
+        <source>Enter License</source>
+        <translation>Ввести ліцензію</translation>
+    </message>
+    <message>
+        <source>Buy License</source>
+        <translation>Купити ліцензію</translation>
+    </message>
+    <message>
+        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
+        <translation>Повна версія дозволяє додавати більше %1 пісень до плейлістів та слухати вашу музику без переривань.</translation>
     </message>
 </context>
 <context>
@@ -58,6 +112,33 @@
         <translation>Детальніше</translation>
     </message>
 </context>
+<context>
+    <name>AlbumListView</name>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Сортувати по</translation>
+    </message>
+</context>
 <context>
     <name>ArtistInfo</name>
     <message>
@@ -65,6 +146,37 @@
         <translation>Детальніше</translation>
     </message>
 </context>
+<context>
+    <name>ArtistListView</name>
+    <message>
+        <source>Track Count</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Album Count</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Назва</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Popularity</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reversed Order</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sort by</source>
+        <translation>Сортувати по</translation>
+    </message>
+</context>
 <context>
     <name>BreadcrumbWidget</name>
     <message>
@@ -73,14 +185,14 @@
     </message>
     <message>
         <source>Go back</source>
-        <translation>Повернути</translation>
+        <translation>Повернутись</translation>
     </message>
 </context>
 <context>
     <name>ChooseFolderView</name>
     <message>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
-        <translation>Ласкаво просимо на &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
+        <translation>Ласкаво просимо до &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
         <source>%1 needs to scan your music collection.</source>
@@ -88,7 +200,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Відміна</translation>
+        <translation>Скасувати</translation>
     </message>
     <message>
         <source>Use iTunes collection</source>
@@ -104,7 +216,7 @@
     </message>
     <message>
         <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
-        <translation>%1 під’єднається до Last.fm щоб передати інформацію про імена виконавців та назви альбомів щоб отримати обкладинки дисків, біографію та інше.</translation>
+        <translation>%1 під’єднається до Last.fm і передасть інформацію про імена виконавців та назви альбомів, щоб отримати обкладинки дисків, біографію та інше.</translation>
     </message>
     <message>
         <source>If you have privacy concerns about this you can quit now.</source>
@@ -112,11 +224,11 @@
     </message>
     <message>
         <source>Where&apos;s your music collection?</source>
-        <translation>Де ваш музична колекція?</translation>
+        <translation>Де ваша музична колекція?</translation>
     </message>
     <message>
         <source>Select the location of your music collection.</source>
-        <translation>Виберіть розташування вашої музичної колекції.</translation>
+        <translation>Виберіть місце розташування вашої музичної колекції.</translation>
     </message>
     <message>
         <source>Locate your collection</source>
@@ -149,42 +261,18 @@
     </message>
     <message>
         <source>This will take time depending on your collection size and network speed.</source>
-        <translation>Це займе час, залежно від розміру вашої колекції та швидкості мережі.</translation>
+        <translation>Це займе деякий час, залежно від розміру вашої колекції та швидкості мережі.</translation>
     </message>
     <message>
         <source>Go grab a coffee</source>
-        <translation>Можна випити кави</translation>
+        <translation>Можете поки випити кави</translation>
     </message>
 </context>
 <context>
-    <name>DemoStartupView</name>
+    <name>DownloadWidget</name>
     <message>
-        <source>Please license %1</source>
-        <translation>Ліцензуйте %1</translation>
-    </message>
-    <message>
-        <source>This demo has expired.</source>
-        <translation>Пробний період вичерпано</translation>
-    </message>
-    <message>
-        <source>This demo will expire in %1 days.</source>
-        <translation>Пробний період завершується за %1 днів.</translation>
-    </message>
-    <message>
-        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation>Повна версія дозволяє додавати більше %1 треків у плейлист і слухати музику без перерви.</translation>
-    </message>
-    <message>
-        <source>Use Demo</source>
-        <translation>Демонстрація</translation>
-    </message>
-    <message>
-        <source>Get the full version</source>
-        <translation>Отримати повнофункціональну версію</translation>
-    </message>
-    <message>
-        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
-        <translation type="unfinished"/>
+        <source>Downloading update...</source>
+        <translation>Завантажую оновлення ...</translation>
     </message>
 </context>
 <context>
@@ -264,30 +352,34 @@
     <name>LastFm</name>
     <message>
         <source>Authentication failed</source>
-        <translation type="unfinished"/>
+        <translation>Помилка аутентифікації</translation>
     </message>
 </context>
 <context>
     <name>LastFmLoginDialog</name>
     <message>
         <source>Log in to %1</source>
-        <translation type="unfinished"/>
+        <translation>Ввійти на %1</translation>
     </message>
     <message>
         <source>&amp;Username:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Ім’я користувача:</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Пароль:</translation>
     </message>
     <message>
         <source>Signup for a %1 account</source>
-        <translation type="unfinished"/>
+        <translation>Зареєструвати %1 аккаунт</translation>
     </message>
     <message>
         <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
-        <translation type="unfinished"/>
+        <translation>Забули ваше &lt;a href=&apos;%1&apos;&gt;ім’я користувача&lt;/a&gt; чи &lt;a href=&apos;%2&apos;&gt;пароль&lt;/a&gt;?</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Відміна</translation>
     </message>
 </context>
 <context>
@@ -350,7 +442,7 @@
     </message>
     <message>
         <source>Move &amp;Up</source>
-        <translation>Перемістити &amp;вгору</translation>
+        <translation>Перемістити &amp;Вгору</translation>
     </message>
     <message>
         <source>Move up the selected tracks in the playlist</source>
@@ -390,11 +482,11 @@
     </message>
     <message>
         <source>Make a &amp;donation</source>
-        <translation>Зробити &amp;пожертву</translation>
+        <translation>Підтрима&amp;йте проект</translation>
     </message>
     <message>
         <source>Please support the continued development of %1</source>
-        <translation>Просимо підтримати подальший розвиток %1</translation>
+        <translation>Будь ласка, підтримайте подальший розвиток %1</translation>
     </message>
     <message>
         <source>&amp;About</source>
@@ -458,7 +550,7 @@
     </message>
     <message>
         <source>Opening %1</source>
-        <translation>Відкриття %1</translation>
+        <translation>Відкриваю %1</translation>
     </message>
     <message>
         <source>Updating collection...</source>
@@ -470,7 +562,7 @@
     </message>
     <message>
         <source>Collection updated</source>
-        <translation>Колекція оновлена</translation>
+        <translation>Колекцію оновлено</translation>
     </message>
     <message>
         <source>Fatal error: %1</source>
@@ -512,10 +604,6 @@
         <source>Remind me later</source>
         <translation>Нагадати мені пізніше</translation>
     </message>
-    <message>
-        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Update</source>
         <translation>Оновлення</translation>
@@ -538,20 +626,36 @@
     </message>
     <message>
         <source>&amp;Stop After This Track</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Зупинити після цього треку</translation>
     </message>
     <message>
         <source>&amp;Scrobbling</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Скроблінг</translation>
     </message>
     <message>
         <source>Send played tracks titles to %1</source>
-        <translation type="unfinished"/>
+        <translation>Надіслати треки, які грали до %1</translation>
     </message>
     <message>
         <source>&amp;Log Out from %1</source>
+        <translation>&amp;Вийти з %1</translation>
+    </message>
+    <message>
+        <source>&amp;Report an Issue...</source>
+        <translation>По&amp;відомити про помилку</translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation>Пошук</translation>
+    </message>
+    <message>
+        <source>%1 finished scanning your music collection</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>&amp;Love %1? Rate it!</source>
+        <translation>&amp;Подобається %1? Оцініть !</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -569,7 +673,7 @@
     </message>
     <message>
         <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
-        <translation>Це дозволяє відтворювати кілька треків, отже ви можете протестувати додаток і побачити, чи все правильно працює.</translation>
+        <translation>Це дозволяє відтворювати кілька треків, отже ви можете протестувати програму і побачити, чи вона вам підходить.</translation>
     </message>
     <message>
         <source>Continue</source>
@@ -580,18 +684,52 @@
         <translation>Отримати повну версію</translation>
     </message>
 </context>
+<context>
+    <name>MessageWidget</name>
+    <message>
+        <source>A new version of %1 is available!</source>
+        <translation>Доступна нова версія %1!</translation>
+    </message>
+    <message>
+        <source>%1 %2 is now available. You have %3.</source>
+        <translation>%1 %2 доступна. Ви маєте %3.</translation>
+    </message>
+    <message>
+        <source>Would you like to download it now?</source>
+        <translation>Ви бажаєте завантажити зараз?</translation>
+    </message>
+    <message>
+        <source>Skip This Version</source>
+        <translation>Пропустити цю версію</translation>
+    </message>
+    <message>
+        <source>Remind Me Later</source>
+        <translation>Нагадати пізніше</translation>
+    </message>
+    <message>
+        <source>Install Update</source>
+        <translation>Встановити оновлення</translation>
+    </message>
+</context>
+<context>
+    <name>PasteLineEdit</name>
+    <message>
+        <source>Paste</source>
+        <translation>Вставити</translation>
+    </message>
+</context>
 <context>
     <name>PlaylistModel</name>
     <message>
         <source>This demo is limited to only %1 tracks in the playlist.</source>
-        <translation type="unfinished"/>
+        <translation>Демо обмежене до %1 треків в плейлісті.</translation>
     </message>
 </context>
 <context>
     <name>PlaylistView</name>
     <message>
         <source>Playlist is empty</source>
-        <translation>Порожній плейлист</translation>
+        <translation>Плейлист порожній</translation>
     </message>
     <message>
         <source>%1 tracks - Total length is %2</source>
