@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "basefinderview.h"
 #include "finderitemdelegate.h"
 #include "basesqlmodel.h"
@@ -7,39 +27,35 @@
 
 BaseFinderView::BaseFinderView(QWidget *parent) : QListView(parent) {
 
-    this->setItemDelegate(new FinderItemDelegate(this));
-    this->setSelectionMode(QAbstractItemView::ExtendedSelection);
+    setItemDelegate(new FinderItemDelegate(this));
+    setSelectionMode(QAbstractItemView::ExtendedSelection);
 
     // layout
-    this->setGridSize(QSize(151, 151));
-    // this->setViewMode(QListView::IconMode);
-    // this->setSpacing(1);
-    this->setFlow(QListView::LeftToRight);
-    this->setWrapping(true);
-    this->setResizeMode(QListView::Adjust);
-    this->setMovement(QListView::Static);
-    this->setUniformItemSizes(true);
+    setGridSize(QSize(151, 151));
+    setFlow(QListView::LeftToRight);
+    setWrapping(true);
+    setResizeMode(QListView::Adjust);
+    setMovement(QListView::Static);
+    setUniformItemSizes(true);
 
     // colors
     QPalette p = palette();
     p.setBrush(QPalette::Base, Qt::black);
     p.setBrush(QPalette::Text, Qt::white);
     p.setColor(QPalette::Background, Qt::transparent);
-    this->setPalette(p);
+    setPalette(p);
 
     // dragndrop
-    this->setDragEnabled(true);
-    this->setDragDropMode(QAbstractItemView::DragOnly);
+    setDragEnabled(true);
+    setDragDropMode(QAbstractItemView::DragOnly);
 
     // cosmetics
-    this->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
-    this->setFrameShape( QFrame::NoFrame );
-    this->setAttribute(Qt::WA_MacShowFocusRect, false);
-    // setStyleSheet("background:transparent");
+    setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
+    setFrameShape(QFrame::NoFrame);
+    setAttribute(Qt::WA_MacShowFocusRect, false);
 
     verticalScrollBar()->setPageStep(3);
     verticalScrollBar()->setSingleStep(1);
-
 }
 
 void BaseFinderView::appear() {
@@ -47,8 +63,7 @@ void BaseFinderView::appear() {
     setMouseTracking(true);
     BaseSqlModel *baseSqlModel = dynamic_cast<BaseSqlModel*>(model());
     if (baseSqlModel) {
-        QSqlQuery query = baseSqlModel->query();
-        baseSqlModel->setQuery(QSqlQuery(query.lastQuery(), Database::instance().getConnection()));
+        baseSqlModel->restoreQuery();
         while (baseSqlModel->canFetchMore())
             baseSqlModel->fetchMore();
     }
@@ -57,15 +72,12 @@ void BaseFinderView::appear() {
 void BaseFinderView::disappear() {
     setEnabled(false);
     setMouseTracking(false);
-    // BaseSqlModel *baseSqlModel = dynamic_cast<BaseSqlModel*>(model());
-    // if (baseSqlModel) baseSqlModel->clear();
+    BaseSqlModel *baseSqlModel = dynamic_cast<BaseSqlModel*>(model());
+    if (baseSqlModel) baseSqlModel->clear();
 }
 
 void BaseFinderView::leaveEvent(QEvent * /* event */) {
-    BaseSqlModel *baseModel = dynamic_cast<BaseSqlModel *>(model());
-    if (baseModel) {
-        baseModel->clearHover();
-    }
+    QMetaObject::invokeMethod(model(), "clearHover");
 }
 
 void BaseFinderView::mouseMoveEvent(QMouseEvent *event) {
@@ -74,10 +86,10 @@ void BaseFinderView::mouseMoveEvent(QMouseEvent *event) {
     // qDebug() << "BaseFinderView::mouseMoveEvent" << event->pos();
 
     if (isHoveringPlayIcon(event)) {
-        QMetaObject::invokeMethod(model(), "enterPlayIconHover", Qt::DirectConnection);
+        QMetaObject::invokeMethod(model(), "enterPlayIconHover");
         setCursor(Qt::PointingHandCursor);
     } else {
-        QMetaObject::invokeMethod(model(), "exitPlayIconHover", Qt::DirectConnection);
+        QMetaObject::invokeMethod(model(), "exitPlayIconHover");
         unsetCursor();
     }
 
