@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "collectionscanner.h"
 #include "database.h"
 #include "model/track.h"
@@ -19,11 +39,12 @@ CollectionScanner::CollectionScanner(QObject *parent) :
 #endif
 
     fileExtensionsBlacklist
-            << "jpg" << "png" << "gif" << "bmp"
-            << "txt" << "doc" << "rtf" << "pdf"
-            << "db" << "log"
+            << "jpg" << "jpeg" << "png" << "gif" << "bmp" << "tif" << "tiff"
+            << "txt" << "doc" << "rtf" << "pdf" << "html" << "htm" << "ps" << "xls" << "js" << "css"
+            << "db" << "log" << "url" << "nfo" << "ini" << "dat" << "md5" << "sfv" << "DS_Store"
             << "zip" << "rar" << "dmg" << "iso"
-            << "m3u" << "pls" << "cue";
+            << "m3u" << "pls" << "cue"
+            << "avi" << "flv" << "mpg" << "wmv" << "swf";
 }
 
 void CollectionScanner::reset() {
@@ -51,14 +72,22 @@ void CollectionScanner::run() {
 
     if (incremental) {
 
-        // quickly check if anythingchanged since the last time
-        // by building a hash from filenames and mtimes
-        QString hash = directoryHash(rootDirectory);
-        QSettings settings;
-        QString previousHash = settings.value("collectionHash").toString();
-        // qDebug() << hash << previousHash;
-        if (hash == previousHash) {
-            // qDebug() << "Nothing changed since the last time";
+        // check wheter dir exists, is readable and isn't empty
+        // we don't want to wipe out a collection because of an unmounted disk or remote share
+        bool proceed = rootDirectory.exists() &&
+                rootDirectory.isReadable() &&
+                rootDirectory.entryInfoList(QDir::NoDotAndDotDot|QDir::AllEntries).count();
+
+        if (proceed) {
+            // quickly check if anything changed since the last time
+            // by building a hash from filenames and mtimes
+            QString hash = directoryHash(rootDirectory);
+            QSettings settings;
+            QString previousHash = settings.value("collectionHash").toString();
+            proceed = hash != previousHash;
+        }
+
+        if (!proceed) {
             stopped = false;
             working = false;
             Database::instance().closeConnection();
@@ -74,8 +103,8 @@ void CollectionScanner::run() {
 
     } else {
 
-        // drop the previous, if any
-        Database::instance().drop();
+        // delete any existing data
+        Database::instance().clear();
 
         // invalidate caches
         Artist::clearCache();
@@ -116,8 +145,14 @@ void CollectionScanner::popFromQueue() {
     // qDebug() << "Processing " << fileInfo.absoluteFilePath();
 
     // parse metadata with TagLib
-    TagLib::FileRef fileref((TagLib::FileName)fileInfo.absoluteFilePath().toUtf8());
-    // or maybe QFile::encodeName(p_FilePath).data()
+    QString filename = fileInfo.absoluteFilePath();
+#ifdef Q_OS_WIN
+    const wchar_t * encodedName = reinterpret_cast<const wchar_t*>(filename.utf16());
+    TagLib::FileRef fileref(encodedName);
+#else
+    // const char * encodedName = QFile::encodeName(filename).constData();
+    TagLib::FileRef fileref((TagLib::FileName)filename.toUtf8());
+#endif
 
     // if taglib cannot parse the file, drop it
     if (fileref.isNull()) {
@@ -197,6 +232,8 @@ void CollectionScanner::complete() {
         trackPaths.clear();
     }
 
+    QSqlQuery("vacuum", Database::instance().getConnection());
+
     stopped = false;
     working = false;
 
@@ -469,7 +506,7 @@ void CollectionScanner::giveThisFileAnAlbum(FileInfo *file) {
     const QString albumTag = DataUtils::cleanTag(file->getTags()->album);
 
     // try to normalize the album title to a simpler form
-    const QString albumHash = DataUtils::normalizeTag(albumTag);
+    const QString albumHash = Album::getHash(albumTag, file->getArtist());
 
     if (albumTag.isEmpty()) {
         processTrack(file);
@@ -502,6 +539,15 @@ void CollectionScanner::processAlbum(FileInfo *file) {
     const QString albumTag = file->getTags()->album;
     album->setTitle(DataUtils::cleanTag(albumTag));
     album->setYear(file->getTags()->year);
+
+    Artist *artist = file->getArtist();
+    if (artist) album->setArtist(artist); // && artist->getId() > 0
+    else qDebug() << "Album" << album->getTitle() << "lacks an artist";
+
+    if (artist && artist->getId() <= 0) qWarning() << "artist id" << artist->getId() << artist->getName();
+
+    // qDebug() << "Processing album:" << album->getTitle() << album->getHash();
+
     album->setProperty("originalHash", album->getHash());
 
     // local covers
@@ -509,20 +555,15 @@ void CollectionScanner::processAlbum(FileInfo *file) {
     if (!QFile::exists(imageLocation)) {
         const QString filePath = file->getFileInfo().absolutePath();
         bool localCover = false;
-        localCover = CoverUtils::coverFromFile(filePath, imageLocation);
+        localCover = CoverUtils::coverFromFile(filePath, album);
         if (!localCover) {
-            localCover = CoverUtils::coverFromTags(filePath, imageLocation);
+            localCover = CoverUtils::coverFromTags(filePath, album);
             if (localCover)
                 qDebug() << "Found embedded cover for" << filePath;
         }
         if (localCover) album->setProperty("localCover", true);
     }
 
-    Artist *artist = file->getArtist();
-    if (artist && artist->getId() > 0) album->setArtist(artist);
-    else qDebug() << "Album" << album->getTitle() << "lacks an artist";
-    // qDebug() << "Processing album:" << album->getTitle() << album->getHash();
-
     if (loadedAlbums.contains(album->getHash())) {
         qDebug() << "ERROR Album already processed!" << album->getTitle() << album->getHash();
         return;
@@ -562,13 +603,13 @@ void CollectionScanner::gotAlbumInfo() {
     // if (hash != album->getHash())
     loadedAlbums.insert(album->getHash(), album);
 
-    int albumId = Album::idForName(album->getTitle());
+    int albumId = Album::idForHash(album->getHash());
     album->setId(albumId);
     if (albumId < 0) {
         // qDebug() << "We have a new cool album:" << album->getTitle();
         album->insert();
         // TODO last insert id
-        albumId = Album::idForName(album->getTitle());
+        albumId = Album::idForHash(album->getHash());
     } else {
         qDebug() << "Updating album" << album->getTitle();
         album->update();
