@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #ifndef COLLECTIONSCANNER_H
 #define COLLECTIONSCANNER_H
 
@@ -32,7 +52,7 @@ public:
 class FileInfo {
 
 public:
-    FileInfo() : artist(0), album(0), tags(0) { };
+    FileInfo() : artist(0), album(0), tags(0) { }
     ~FileInfo() {
         if (artist) delete artist;
         if (album) delete album;
