@@ -1,51 +1,86 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "database.h"
 #include "constants.h"
 #include <QDesktopServices>
 
-static const QString dbName = QLatin1String(Constants::UNIX_NAME) + ".db";
 static Database *databaseInstance = 0;
 
 Database::Database() {
-
-    QString dataLocation = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-    QDir().mkpath(dataLocation);
-    dbLocation = dataLocation + "/" + dbName;
-
     QMutexLocker locker(&lock);
 
-    if(QFile::exists(dbLocation)) {
+    const QString dataLocation = getDataLocation();
+    const QString dbLocation = getDbLocation();
 
-        // qDebug() << "Database found in" << dbLocation;
+    if(QFile::exists(dbLocation)) {
 
         // check db version
         int databaseVersion = getAttribute("version").toInt();
         if (databaseVersion != Constants::DATABASE_VERSION) {
-            qDebug("Wrong database version: %d", databaseVersion);
+            qWarning("Updating database version: %d to %d", databaseVersion, Constants::DATABASE_VERSION);
+            updateRoot = collectionRoot();
+            drop();
+            removeRecursively(dataLocation);
+            create();
         }
 
-    } else createDatabase();
-
-    maybeCreateDownloadsTable();
-
+    } else create();
 }
 
 Database::~Database() {
     closeConnections();
 }
 
-void Database::createDatabase() {
+const QString &Database::getDataLocation() {
+    static const QString location = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+    return location;
+}
 
+const QString &Database::getFilesLocation() {
+    static const QString location = getDataLocation() + QLatin1String("/files/");
+    return location;
+}
+
+const QString &Database::getDbLocation() {
+    static const QString location = getDataLocation() + QLatin1String("/") +
+            QLatin1String(Constants::UNIX_NAME) + QLatin1String(".db");
+    return location;
+}
+
+void Database::create() {
     qDebug() << "Creating the database";
 
+    QDir().mkpath(getDataLocation());
+
     const QSqlDatabase db = getConnection();
 
+    createAttributes();
+
     QSqlQuery("create table artists ("
               "id integer primary key autoincrement,"
               "hash varchar(32),"
               "name varchar(255),"
-              // "mbid varchar(50),"
-              // "lifeBegin integer,"
-              // "lifeEnd integer,"
+              "yearFrom integer,"
+              "yearTo integer,"
+              "listeners integer,"
               "albumCount integer,"
               "trackCount integer)", db);
 
@@ -54,61 +89,62 @@ void Database::createDatabase() {
               "hash varchar(32),"
               "title varchar(255),"
               "year integer,"
-              // "language varchar(5),"
               "artist integer,"
-              "trackCount integer)"
-              , db);
+              "listeners integer,"
+              "trackCount integer)", db);
 
-    QSqlQuery(
-            "create table tracks ("
-            "id integer primary key autoincrement,"
-            "path varchar(255)," // path is NOT unique: .cue files
-            "title varchar(255),"
-            // "start integer, end integer," // cue files
-            "duration integer,"
-            "track integer,"
-            "year integer,"
-            "artist integer,"
-            "album integer,"
-            "tstamp integer)"
-            , db);
+    QSqlQuery("create table tracks ("
+              "id integer primary key autoincrement,"
+              "path varchar(255)," // path is NOT unique: .cue files
+              "title varchar(255),"
+              // TODO "start integer, end integer," // cue files
+              "duration integer,"
+              "track integer,"
+              "year integer,"
+              "artist integer,"
+              "album integer,"
+              "tstamp integer)", db);
 
-    QSqlQuery(
-            "create table nontracks ("
-            "path varchar(255),"
-            "tstamp integer)"
-            , db);
-    QSqlQuery("create unique index idx_path on nontracks(path)", db);
-
-    QSqlQuery("create table attributes (name varchar(255), value)", db);
-    QSqlQuery("insert into attributes (name, value) values ('version', " + QString::number(Constants::DATABASE_VERSION) + ")", db);
-    QSqlQuery("insert into attributes (name, value) values ('status', " + QString::number(ScanIncomplete) + ")", db);
-    QSqlQuery("insert into attributes (name, value) values ('lastUpdate', 0)", db);
-    QSqlQuery("insert into attributes (name, value) values ('root', '')", db);
-
-}
-
-void Database::maybeCreateDownloadsTable() {
-    const QSqlDatabase db = getConnection();
-
-    bool createTable = false;
-
-    QSqlQuery query(db);
-    if (!query.exec("SELECT name FROM sqlite_master WHERE type='table' AND name='downloads'")) {
-        qWarning() << query.lastQuery() << query.lastError().text();
-        createTable = true;
-    } else if (query.next()) return;
+    QSqlQuery("create table nontracks ("
+              "path varchar(255),"
+              "tstamp integer)", db);
+    QSqlQuery("create unique index unique_nontracks_path on nontracks(path)", db);
 
     QSqlQuery("create table downloads ("
               "id integer primary key autoincrement,"
               "objectid integer,"
               "type integer,"
-              "status integer,"
               "errors integer,"
-              "url varchar(255))"
-              , db);
+              "url varchar(255))", db);
 
-    qDebug() << "Downloads table created";
+    /* TODO tags
+    QSqlQuery("create table tags ("
+              "id integer primary key autoincrement,"
+              "name varchar,"
+              "artistCount integer,"
+              "albumCount integer)", db);
+    QSqlQuery("create unique index unique_tags_name on tags(name)", db);
+
+    QSqlQuery("create table artisttags ("
+              "artist integer,"
+              "tag integer)", db);
+    QSqlQuery("create unique index unique_artisttags on artisttags(artist,tag)", db);
+
+    QSqlQuery("create table albumtags ("
+              "album integer,"
+              "tag integer)", db);
+    QSqlQuery("create unique index unique_albumtags on albumtags(album,tag)", db);
+    */
+}
+
+void Database::createAttributes() {
+    const QSqlDatabase db = getConnection();
+    QSqlQuery("create table attributes (name varchar(255), value)", db);
+    QSqlQuery("create unique index unique_attributes_name on attributes(name)", db);
+    QSqlQuery("insert into attributes (name, value) values ('version', " + QString::number(Constants::DATABASE_VERSION) + ")", db);
+    QSqlQuery("insert into attributes (name, value) values ('status', " + QString::number(ScanIncomplete) + ")", db);
+    QSqlQuery("insert into attributes (name, value) values ('lastUpdate', 0)", db);
+    QSqlQuery("insert into attributes (name, value) values ('root', '')", db);
 }
 
 Database& Database::instance() {
@@ -132,9 +168,10 @@ QSqlDatabase Database::getConnection() {
     } else {
         qDebug() << "Creating db connection for" << threadName;
         QSqlDatabase connection = QSqlDatabase::addDatabase("QSQLITE", threadName);
-        connection.setDatabaseName(dbLocation);
+        connection.setDatabaseName(getDbLocation());
         if(!connection.open()) {
-            qWarning() << QString("Cannot connect to database %1 in thread %2").arg(dbLocation, threadName);
+            qWarning() << QString("Cannot connect to database %1 in thread %2")
+                          .arg(connection.databaseName(), threadName);
         }
         connections.insert(currentThread, connection);
         return connection;
@@ -187,14 +224,11 @@ void Database::setAttribute(QString name, QVariant value) {
     if (!success) qDebug() << query.lastError().text();
 }
 
-
-/**
-  * After calling this method you have to reacquire a valid instance using instance()
-  */
 void Database::drop() {
-    /// closeConnections();
-    if (!QFile::remove(dbLocation)) {
-        qWarning() << "Cannot delete database" << dbLocation;
+    qDebug() << "Dropping the database";
+
+    if (!QFile::remove(getDbLocation())) {
+        qWarning() << "Cannot delete database" << getDbLocation();
 
         // fallback to delete records in tables
         const QSqlDatabase db = getConnection();
@@ -203,11 +237,15 @@ void Database::drop() {
             qWarning() << query.lastQuery() << query.lastError().text();
         }
 
+        QStringList tableNames;
         while (query.next()) {
             QString tableName = query.value(0).toString();
-            if (tableName.startsWith("sqlite_") || tableName == "attributes") continue;
-            QString dropSQL = "delete from " + tableName;
-            qWarning() << "dropSQL" << dropSQL;
+            if (tableName.startsWith("sqlite_")) continue;
+            tableNames << tableName;
+        }
+
+        foreach (QString tableName, tableNames) {
+            QString dropSQL = "drop table " + tableName;
             QSqlQuery query2(db);
             if (!query2.exec(dropSQL)) {
                 qWarning() << query2.lastQuery() << query2.lastError().text();
@@ -215,10 +253,32 @@ void Database::drop() {
         }
 
         query.exec("delete from sqlite_sequence");
-
+        query.exec("vacuum");
     }
-    if (databaseInstance) delete databaseInstance;
-    databaseInstance = 0;
+
+    closeConnections();
+}
+
+void Database::clear() {
+    const QSqlDatabase db = getConnection();
+    QSqlQuery query(db);
+    if (!query.exec("select name from sqlite_master where type='table'")) {
+        qWarning() << query.lastQuery() << query.lastError().text();
+    }
+
+    while (query.next()) {
+        QString tableName = query.value(0).toString();
+        if (tableName.startsWith("sqlite_")) continue;
+        QString dropSQL = "delete from " + tableName;
+        QSqlQuery query2(db);
+        if (!query2.exec(dropSQL)) {
+            qWarning() << query2.lastQuery() << query2.lastError().text();
+        }
+    }
+
+    query.exec("delete from sqlite_sequence");
+    query.exec("vacuum");
+    createAttributes();
 }
 
 void Database::closeConnections() {
@@ -236,3 +296,23 @@ void Database::closeConnection() {
     qDebug() << "Closing connection" << connection;
     connection.close();
 }
+
+bool Database::removeRecursively(const QString & dirName) {
+    bool result = false;
+    QDir dir(dirName);
+    if (dir.exists(dirName)) {
+        Q_FOREACH(QFileInfo info, dir.entryInfoList(
+                      QDir::NoDotAndDotDot | QDir::System | QDir::Hidden |
+                      QDir::AllDirs | QDir::Files, QDir::DirsFirst)) {
+            if (info.isDir())
+                result = removeRecursively(info.absoluteFilePath());
+            else
+                result = QFile::remove(info.absoluteFilePath());
+
+            if (!result)
+                return result;
+        }
+        result = dir.rmdir(dirName);
+    }
+    return result;
+}
