@@ -1,6 +1,29 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 #include "droparea.h"
-#include "iconloader/qticonloader.h"
+#include "iconutils.h"
 #include "trackmimedata.h"
 #include "model/track.h"
 #include "playlistmodel.h"
@@ -42,7 +65,7 @@ void DropArea::dragLeaveEvent(QDragLeaveEvent *event) {
 
 void DropArea::clear() {
     setText("<b>" + tr("Drop here to append to the playlist") + "</b>");
-    setPixmap(QtIconLoader::icon("list-add").pixmap(24, 24));
+    setPixmap(IconUtils::icon("list-add").pixmap(24, 24));
     setBackgroundRole(QPalette::Base);
     setForegroundRole(QPalette::Text);
 
