@@ -1,16 +1,28 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "filesystemmodel.h"
 #include "trackmimedata.h"
 #include "database.h"
 
-FileSystemModel::FileSystemModel(QObject *parent) : QFileSystemModel(parent) {
-    hoveredRow = -1;
-    playIconHovered = false;
-
-    timeLine = new QTimeLine(250, this);
-    timeLine->setFrameRange(1000, 0);
-    connect(timeLine, SIGNAL(frameChanged(int)), SLOT(updatePlayIcon()));
-
-}
+FileSystemModel::FileSystemModel(QObject *parent) : QFileSystemModel(parent) { }
 
 QVariant FileSystemModel::data(const QModelIndex &index, int role) const {
 
@@ -38,15 +50,6 @@ QVariant FileSystemModel::data(const QModelIndex &index, int role) const {
             return QVariant::fromValue(QPointer<Track>(track));
         }
 
-    case Finder::HoveredItemRole:
-        return hoveredRow == index.row();
-
-    case Finder::PlayIconAnimationItemRole:
-        return timeLine->currentFrame() / 1000.;
-
-    case Finder::PlayIconHoveredRole:
-        return playIconHovered;
-
     case Qt::StatusTipRole:
         if (!isDir(index)) {
             path = QFileSystemModel::data(index, QFileSystemModel::FilePathRole).toString();
@@ -64,46 +67,10 @@ QVariant FileSystemModel::data(const QModelIndex &index, int role) const {
     return QVariant();
 }
 
-void FileSystemModel::setHoveredRow(int row) {
-    int oldRow = hoveredRow;
-    hoveredRow = row;
-    emit dataChanged( createIndex( oldRow, 0 ), createIndex( oldRow, columnCount() - 1 ) );
-    emit dataChanged( createIndex( hoveredRow, 0 ), createIndex( hoveredRow, columnCount() - 1 ) );
-}
-
-void FileSystemModel::clearHover() {
-    emit dataChanged( createIndex( hoveredRow, 0 ), createIndex( hoveredRow, columnCount() - 1 ) );
-    hoveredRow = -1;
-}
-
-void FileSystemModel::enterPlayIconHover() {
-    if (playIconHovered) return;
-    playIconHovered = true;
-    if (timeLine->state() != QTimeLine::Running) {
-        timeLine->setDirection(QTimeLine::Forward);
-        timeLine->start();
-    }
-}
-
-void FileSystemModel::exitPlayIconHover() {
-    if (!playIconHovered) return;
-    playIconHovered = false;
-    if (timeLine->state() == QTimeLine::Running) {
-        timeLine->stop();
-        timeLine->setDirection(QTimeLine::Backward);
-        timeLine->start();
-    }
-    setHoveredRow(hoveredRow);
-}
-
-void FileSystemModel::updatePlayIcon() {
-    emit dataChanged( createIndex( hoveredRow, 0 ), createIndex( hoveredRow, columnCount() - 1 ) );
-}
-
 // --- Sturm und drang ---
 
 Qt::DropActions FileSystemModel::supportedDropActions() const {
-    return Qt::MoveAction;
+    return Qt::CopyAction;
 }
 
 Qt::ItemFlags FileSystemModel::flags(const QModelIndex &index) const {
