@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #ifndef FILESYSTEMMODEL_H
 #define FILESYSTEMMODEL_H
 
@@ -11,6 +31,7 @@ class FileSystemModel : public QFileSystemModel {
 
 public:
     FileSystemModel(QObject *parent = 0);
+    int columnCount(const QModelIndex & = QModelIndex()) const { return 1; }
     QVariant data(const QModelIndex &item, int role) const;
     Item* itemAt(const QModelIndex &index) const {
         if (isDir(index)) {
@@ -27,12 +48,6 @@ public:
     void clear() {
         //reset();
     }
-    void setHoveredRow(int row);
-
-public slots:
-    void clearHover();
-    void enterPlayIconHover();
-    void exitPlayIconHover();
 
 protected:
     // drag and drop
@@ -41,13 +56,6 @@ protected:
     Qt::DropActions supportedDropActions() const;
     QMimeData* mimeData( const QModelIndexList &indexes ) const;
 
-    int hoveredRow;
-    QTimeLine * timeLine;
-    bool playIconHovered;
-
-private slots:
-    void updatePlayIcon();
-
 };
 
 #endif // FILESYSTEMMODEL_H
