@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "finderitemdelegate.h"
 #include "basesqlmodel.h"
 #include "finderwidget.h"
@@ -209,7 +229,7 @@ void FinderItemDelegate::paintAlbum(QPainter* painter,
     const bool isSelected = option.state & QStyle::State_Selected;
 
     // thumb
-    QPixmap pixmap = getAlbumPixmap(album);
+    QPixmap pixmap = album->getThumb();
     if (pixmap.isNull()) pixmap = getMissingAlbumPixmap();
     painter->drawPixmap(0, 0, pixmap);
 
@@ -348,38 +368,44 @@ void FinderItemDelegate::paintPlayIcon(QPainter *painter, const QRect& rect, dou
 
 void FinderItemDelegate::drawName(QPainter *painter, const QStyleOptionViewItem &option, QString name, const QRect& rect, bool isSelected) const {
 
-    QRect textBox = rect;
-    // add padding
-    textBox.adjust(0, 0, 0, -ITEM_HEIGHT*2/3);
-    // move to the bottom
-    textBox.translate(0, ITEM_HEIGHT - textBox.height());
+    QRect nameBox = rect;
+    nameBox.adjust(0, 0, 0, -ITEM_HEIGHT*2/3);
+    nameBox.translate(0, ITEM_HEIGHT - nameBox.height());
 
     painter->save();
     painter->setPen(Qt::NoPen);
     if (isSelected) {
         painter->setOpacity(.9);
-#if defined(APP_MAC) | defined(APP_WIN)
-        QColor color1 = QColor::fromRgb(0x69, 0xa6, 0xd9);
-        QColor color2 = QColor::fromRgb(0x14, 0x6b, 0xd4);
-        QLinearGradient linearGradient(textBox.x(), textBox.y(), textBox.x(), textBox.y() + textBox.height());
-        linearGradient.setColorAt(0.0, color1);
-        linearGradient.setColorAt(1.0, color2);
-        painter->setBrush(linearGradient);
-#else
         painter->setBrush(option.palette.highlight());
-#endif
     } else {
         painter->setBrush(QColor(0, 0, 0, 128));
     }
 
-    painter->drawRect(textBox);
+    painter->drawRect(nameBox);
     painter->restore();
 
     painter->save();
+
+    bool tooBig = false;
+    QRect textBox = painter->boundingRect(nameBox, Qt::AlignCenter | Qt::TextWordWrap, name);
+    if (textBox.height() >= nameBox.height()) {
+        painter->setFont(FontUtils::smaller());
+        textBox = painter->boundingRect(nameBox, Qt::AlignCenter | Qt::TextWordWrap, name);
+        if (textBox.height() > nameBox.height()) {
+            // it's still too big
+            painter->setClipRect(nameBox);
+            tooBig = true;
+        }
+    }
+
     if (isSelected)
         painter->setPen(QPen(option.palette.highlightedText(), 0));
 
-    painter->drawText(textBox, Qt::AlignCenter | Qt::TextWordWrap, name);
+    if (tooBig)
+        painter->drawText(nameBox, Qt::AlignHCenter | Qt::AlignTop | Qt::TextWordWrap, name);
+    else
+        painter->drawText(textBox, Qt::AlignCenter | Qt::TextWordWrap, name);
+
     painter->restore();
 }
 
@@ -387,7 +413,7 @@ void FinderItemDelegate::drawBadge(QPainter *painter, QString text,  const QRect
     static const int PADDING = 4;
 
     painter->save();
-    painter->setFont(FontUtils::small());
+    painter->setFont(FontUtils::smaller());
     QRectF textBox = painter->boundingRect(rect, Qt::AlignLeft | Qt::AlignTop, text);
     textBox.adjust(0, 0, PADDING, 0);
 
@@ -404,7 +430,7 @@ void FinderItemDelegate::drawCentralLabel(QPainter *painter, QString text,  cons
     static const int PADDING = 10;
 
     painter->save();
-    painter->setFont(FontUtils::smallBold());
+    painter->setFont(FontUtils::smallerBold());
     QSizeF textSize(QFontMetrics(painter->font()).size( Qt::TextSingleLine, text));
     QRect textBox((rect.width() - textSize.width()) / 2 , (rect.height() - textSize.height()) / 3 + 4, textSize.width(), textSize.height());
 
@@ -424,14 +450,14 @@ QPixmap FinderItemDelegate::getArtistPixmap(Artist *artist) const {
     QPixmap pixmap = artist->property("pixmap").value<QPixmap>();
     if (pixmap.isNull()) {
         // qDebug() << "Creating pixmap for" << artist;
-        QImage p = artist->getPhoto();
+        QPixmap p = artist->getPhoto();
         int xOffset = 0;
         int wDiff = p.width() - ITEM_WIDTH;
         if (wDiff > 0) xOffset = wDiff / 2;
         int yOffset = 0;
         int hDiff = p.height() - ITEM_HEIGHT;
         if (hDiff > 0) yOffset = hDiff / 4;
-        pixmap = QPixmap::fromImage(p.copy(xOffset, yOffset, ITEM_WIDTH, ITEM_HEIGHT));
+        pixmap = p.copy(xOffset, yOffset, ITEM_WIDTH, ITEM_HEIGHT);
         artist->setProperty("pixmap", pixmap);
     }
     return pixmap;
@@ -453,16 +479,3 @@ QPixmap FinderItemDelegate::getFolderPixmap(Folder *folder) const {
     }
     return pixmap;
 }
-
-QPixmap FinderItemDelegate::getAlbumPixmap(Album *album) const {
-    QPixmap pixmap = album->property("pixmap").value<QPixmap>();
-    if (pixmap.isNull()) {
-        // qDebug() << "Creating pixmap for" << album;
-        QImage p = album->getPhoto();
-        if (!p.isNull())
-            p = album->getPhoto().scaled(ITEM_WIDTH, ITEM_HEIGHT);
-        pixmap = QPixmap::fromImage(p);
-        album->setProperty("pixmap", pixmap);
-    }
-    return pixmap;
-}
