@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "finderwidget.h"
 
 #include "segmentedcontrol.h"
@@ -84,20 +104,12 @@ FinderWidget::FinderWidget(QWidget *parent) : QWidget(parent) {
 
 }
 
-void FinderWidget::paintEvent(QPaintEvent*) {
+void FinderWidget::paintEvent(QPaintEvent *e) {
+    Q_UNUSED(e);
 
     QPainter painter(this);
     painter.translate(0, stackedWidget->y());
-
-    const int hCenter = width() * .5;
-    QRadialGradient gradient(hCenter, 0,
-                             width(),
-                             hCenter, 0);
-    gradient.setColorAt(1, QColor(0x00, 0x00, 0x00));
-    gradient.setColorAt(0, QColor(0x2c, 0x2c, 0x2c));
-
     QRect rect = visibleRegion().boundingRect();
-    painter.fillRect(rect, QBrush(gradient));
 
     QLinearGradient shadow;
     shadow.setColorAt(0, QColor(0x00, 0x00, 0x00, 64));
@@ -112,7 +124,6 @@ void FinderWidget::paintEvent(QPaintEvent*) {
     shadow.setStart(shadowRect.topRight());
     shadow.setFinalStop(shadowRect.topLeft());
     painter.fillRect(shadowRect, QBrush(shadow));
-
 }
 
 void FinderWidget::restoreSavedView() {
@@ -187,7 +198,6 @@ void FinderWidget::setupTracks() {
     trackListModel = new TrackSqlModel(this);
     trackListView = new TrackListView(this);
     connect(trackListView, SIGNAL(activated(const QModelIndex &)), SLOT(trackActivated(const QModelIndex &)));
-    connect(trackListView, SIGNAL(play(const QModelIndex &)), SLOT(trackPlayed(const QModelIndex &)));
     connect(trackListView, SIGNAL(entered(const QModelIndex &)), SLOT(trackEntered(const QModelIndex &)));
     connect(trackListView, SIGNAL(viewportEntered()), trackListModel, SLOT(clearHover()));
     trackListView->setModel(trackListModel);
@@ -198,15 +208,15 @@ void FinderWidget::setupFolders() {
     fileSystemModel = new FileSystemModel(this);
     fileSystemModel->setResolveSymlinks(true);
     fileSystemModel->setFilter(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot);
-    FilteringFileSystemModel *proxyModel = new FilteringFileSystemModel(this);
-    proxyModel->setSourceModel(fileSystemModel);
+    filteringFileSystemModel = new FilteringFileSystemModel(this);
+    filteringFileSystemModel->setSourceModel(fileSystemModel);
 
     fileSystemView = new FileSystemFinderView(this);
     connect(fileSystemView, SIGNAL(activated(const QModelIndex &)), SLOT(folderActivated(const QModelIndex &)));
     connect(fileSystemView, SIGNAL(play(const QModelIndex &)), SLOT(folderPlayed(const QModelIndex &)));
     connect(fileSystemView, SIGNAL(entered(const QModelIndex &)), SLOT(folderEntered(const QModelIndex &)));
-    connect(fileSystemView, SIGNAL(viewportEntered()), fileSystemModel, SLOT(clearHover()));
-    fileSystemView->setModel(proxyModel);
+    connect(fileSystemView, SIGNAL(viewportEntered()), filteringFileSystemModel, SLOT(clearHover()));
+    fileSystemView->setModel(filteringFileSystemModel);
     fileSystemView->setFileSystemModel(fileSystemModel);
     stackedWidget->addWidget(fileSystemView);
 }
@@ -227,12 +237,7 @@ void FinderWidget::setupSearch() {
 
 void FinderWidget::showArtists() {
     if (!artistListView) setupArtists();
-
-    artistListModel->setQuery("select id from artists where trackCount>1 order by trackCount desc",
-                              Database::instance().getConnection());
-    if (artistListModel->lastError().isValid())
-        qDebug() << artistListModel->lastError();
-
+    artistListView->updateQuery();
     showWidget(artistListView, true);
     finderBar->setCheckedAction(artistsAction);
     QSettings settings;
@@ -241,13 +246,8 @@ void FinderWidget::showArtists() {
 
 void FinderWidget::showAlbums() {
     if (!albumListView) setupAlbums();
-
-    albumListModel->setQuery(
-                "select id from albums where trackCount>1 order by artist, year desc, trackCount desc",
-                Database::instance().getConnection());
-    if (albumListModel->lastError().isValid())
-        qDebug() << albumListModel->lastError();
-
+    albumListView->updateQuery();
+    albumListView->setShowToolBar(true);
     showWidget(albumListView, true);
     finderBar->setCheckedAction(albumsAction);
     QSettings settings;
@@ -349,6 +349,14 @@ void FinderWidget::appear() {
     }
 }
 
+void FinderWidget::disappear() {
+    QWidget *currentWidget = stackedWidget->currentWidget();
+    if (currentWidget) {
+        bool success = QMetaObject::invokeMethod(stackedWidget->currentWidget(), "disappear", Qt::DirectConnection);
+        if (!success) qDebug() << "Error invoking disappear() on" << stackedWidget->currentWidget();
+    }
+}
+
 void FinderWidget::artistEntered ( const QModelIndex & index ) {
     artistListModel->setHoveredRow(index.row());
 }
@@ -372,6 +380,7 @@ void FinderWidget::artistActivated(Artist *artist) {
 
     albumListView->setWindowTitle(artist->getName());
     albumListView->scrollToTop();
+    albumListView->setShowToolBar(false);
     showWidget(albumListView, false);
 }
 
@@ -431,7 +440,7 @@ void FinderWidget::trackActivated ( const QModelIndex & index ) {
 }
 
 void FinderWidget::folderEntered ( const QModelIndex & index ) {
-    fileSystemModel->setHoveredRow(index.row());
+    filteringFileSystemModel->setHoveredRow(index.row());
 }
 
 void FinderWidget::folderActivated(const QModelIndex & index) {
