@@ -1,16 +1,42 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #ifndef FINDERWIDGET_H
 #define FINDERWIDGET_H
 
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 
 class BreadcrumbWidget;
 class PlaylistModel;
 class PlaylistView;
 class SegmentedControl;
+class ArtistListView;
 class ArtistSqlModel;
+class AlbumListView;
 class AlbumSqlModel;
 class TrackSqlModel;
 class FileSystemModel;
+class FilteringFileSystemModel;
 class FileSystemFinderView;
 class Track;
 class SearchModel;
@@ -52,6 +78,7 @@ public:
         this->playlistView = playlistView;
     }
     void appear();
+    void disappear();
     void showSearch(QString query);
     void addTracksAndPlay(QList<Track*> tracks);
     void artistActivated(Artist *artist);
@@ -59,7 +86,7 @@ public:
     void trackActivated(Track *track);
 
 protected:
-    void paintEvent(QPaintEvent *);
+    void paintEvent(QPaintEvent *e);
 
 private slots:
     void goBack();
@@ -108,11 +135,12 @@ private:
 
     FileSystemFinderView *fileSystemView;
     FileSystemModel *fileSystemModel;
+    FilteringFileSystemModel *filteringFileSystemModel;
 
-    QListView *artistListView;
+    ArtistListView *artistListView;
     ArtistSqlModel *artistListModel;
 
-    QListView *albumListView;
+    AlbumListView *albumListView;
     AlbumSqlModel *albumListModel;
 
     QListView *trackListView;
