@@ -1,8 +1,28 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "fontutils.h"
 
 static const int MIN_PIXEL_SIZE = 11;
 
-const QFont FontUtils::small() {
+const QFont &FontUtils::smaller() {
     static QFont font;
     static bool initialized = false;
     if (!initialized) {
@@ -13,7 +33,7 @@ const QFont FontUtils::small() {
     return font;
 }
 
-const QFont FontUtils::smallBold() {
+const QFont &FontUtils::smallerBold() {
     static QFont font;
     static bool initialized = false;
     if (!initialized) {
@@ -25,7 +45,7 @@ const QFont FontUtils::smallBold() {
     return font;
 }
 
-const QFont FontUtils::big() {
+const QFont &FontUtils::bigger() {
     static QFont font;
     static bool initialized = false;
     if (!initialized) {
@@ -35,7 +55,7 @@ const QFont FontUtils::big() {
     return font;
 }
 
-const QFont FontUtils::bigBold() {
+const QFont &FontUtils::biggerBold() {
     static QFont font;
     static bool initialized = false;
     if (!initialized) {
