@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #ifndef IMAGEDOWNLOADER_H
 #define IMAGEDOWNLOADER_H
 
@@ -16,17 +36,10 @@ public:
 
     enum ImageDownloadTypes {
         ArtistType = 0,
-        AlbumType = 1
-    };
-
-    enum ImageDownloadStatuses {
-        WaitingStatus = 0,
-        ProcessingStatus = 1,
-        FailedStatus = 2
+        AlbumType
     };
 
     static void enqueue(int objectId, int objectType, QString url);
-    static void clearQueue();
 
 public slots:
     void imageDownloaded(QByteArray bytes);
