@@ -1,12 +1,31 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "mainwindow.h"
 #include "spacer.h"
 #include "constants.h"
-#include "iconloader/qticonloader.h"
+#include "iconutils.h"
 #include "global.h"
 #include "database.h"
 #include <QtSql>
 #include "contextualview.h"
-#include "faderwidget/faderwidget.h"
 #ifdef APP_MAC
 #include "searchlineedit_mac.h"
 #else
@@ -21,38 +40,29 @@
 #include "updatechecker.h"
 #include "fontutils.h"
 #include "globalshortcuts.h"
-#ifdef Q_WS_X11
+#ifdef Q_OS_X11
 #include "gnomeglobalshortcutbackend.h"
 #endif
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 #include "mac_startup.h"
 #include "macfullscreen.h"
 #include "macsupport.h"
 #include "macutils.h"
 #endif
 #include "collectionsuggester.h"
-#ifdef APP_DEMO
-#include "demostartupview.h"
-#endif
 #include "lastfm.h"
 #include "lastfmlogindialog.h"
 #include "imagedownloader.h"
-
-/*
-class CentralWidget : public QWidget {
-
-public:
-    CentralWidget(QWidget *message, QWidget *views, QWidget* parent) : QWidget(parent) {
-        QBoxLayout *layout = new QVBoxLayout();
-        layout->setMargin(0);
-        layout->setSpacing(0);
-        layout->addWidget(message);
-        layout->addWidget(views);
-        setLayout(layout);
-    }
-
-};
-*/
+#include <iostream>
+#ifdef APP_EXTRA
+#include "extra.h"
+#include "updatedialog.h"
+#endif
+#ifdef APP_ACTIVATION
+#include "activation.h"
+#include "activationview.h"
+#include "activationdialog.h"
+#endif
 
 static MainWindow *singleton = 0;
 
@@ -66,13 +76,14 @@ MainWindow::MainWindow() : updateChecker(0) {
 
     singleton = this;
 
+    setWindowTitle(Constants::NAME);
+
     // lazily initialized views
     mediaView = 0;
     collectionScannerView = 0;
     chooseFolderView = 0;
     aboutView = 0;
     contextualView = 0;
-    faderWidget = 0;
 
     // build ui
     createActions();
@@ -83,29 +94,43 @@ MainWindow::MainWindow() : updateChecker(0) {
     // views mechanism
     history = new QStack<QWidget*>();
     views = new QStackedWidget(this);
+    views->hide();
+    setCentralWidget(views);
 
     // remove that useless menu/toolbar context menu
     setContextMenuPolicy(Qt::NoContextMenu);
 
-    setCentralWidget(views);
+#ifdef APP_EXTRA
+    Extra::windowSetup(this);
+#endif
 
     // restore window position
     readSettings();
 
-#ifdef APP_DEMO
-        QWidget *demoStartupView = new DemoStartupView(this);
-        views->addWidget(demoStartupView);
-        showView(demoStartupView);
-#else
     showInitialView();
+
+#ifdef APP_ACTIVATION
+    if (!Activation::instance().isActivated())
+        showActivationView(false);
 #endif
 
+    views->show();
+
     // event filter to block ugly toolbar tooltips
     qApp->installEventFilter(this);
 
+    qApp->processEvents();
+    QTimer::singleShot(50, this, SLOT(lazyInit()));
+}
+
+MainWindow::~MainWindow() {
+    delete history;
+}
+
+void MainWindow::lazyInit() {
     // Global shortcuts
     GlobalShortcuts &shortcuts = GlobalShortcuts::instance();
-#ifdef Q_WS_X11
+#ifdef Q_OS_X11
     if (GnomeGlobalShortcutBackend::IsGsdAvailable())
         shortcuts.setBackend(new GnomeGlobalShortcutBackend(&shortcuts));
 #endif
@@ -114,11 +139,6 @@ MainWindow::MainWindow() : updateChecker(0) {
 #endif
     connect(&shortcuts, SIGNAL(PlayPause()), playAct, SLOT(trigger()));
     connect(&shortcuts, SIGNAL(Stop()), this, SLOT(stop()));
-
-}
-
-MainWindow::~MainWindow() {
-    delete history;
 }
 
 void MainWindow::showInitialView() {
@@ -126,17 +146,21 @@ void MainWindow::showInitialView() {
     Database &db = Database::instance();
     if (db.status() == ScanComplete) {
 
-        showMediaView();
+        showMediaView(false);
         QTimer::singleShot(0, this, SLOT(loadPlaylist()));
 
         // update the collection when idle
-        QTimer::singleShot(0, this, SLOT(startIncrementalScan()));
+        QTimer::singleShot(500, this, SLOT(startIncrementalScan()));
 
-        QTimer::singleShot(0, this, SLOT(checkForUpdate()));
+        QTimer::singleShot(1000, this, SLOT(checkForUpdate()));
 
     } else {
         // no db, do the first scan dance
-        showChooseFolderView();
+        QString root = db.needsUpdate();
+        if (!root.isEmpty() && QDir().exists(root))
+            startFullScan(root);
+        else
+            showChooseFolderView(false);
     }
 }
 
@@ -159,7 +183,7 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *event) {
 
 void MainWindow::createActions() {
 
-    QMap<QString, QAction*> *actions = The::globalActions();
+    QHash<QString, QAction*> *actions = The::globalActions();
 
     backAct = new QAction(tr("&Back"), this);
     backAct->setEnabled(false);
@@ -168,12 +192,7 @@ void MainWindow::createActions() {
     actions->insert("back", backAct);
     connect(backAct, SIGNAL(triggered()), SLOT(goBack()));
 
-    QIcon icon = QtIconLoader::icon("gtk-info");
-#ifdef Q_WS_X11
-    if (icon.isNull()) {
-        icon = QtIconLoader::icon("help-about");
-    }
-#endif
+    QIcon icon = IconUtils::icon(QStringList() << "audio-headphones" << "gtk-info" << "help-about");
     contextualAct = new QAction(icon, tr("&Info"), this);
     contextualAct->setStatusTip(tr("Show information about the current track"));
     contextualAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_I));
@@ -184,7 +203,7 @@ void MainWindow::createActions() {
 
     /*
     stopAct = new QAction(
-            QtIconLoader::icon("media-playback-stop"),
+            IconUtils::icon("media-playback-stop"),
             tr("&Stop"), this);
     stopAct->setStatusTip(tr("Stop playback and go back to the search view"));
     stopAct->setShortcuts(QList<QKeySequence>() << QKeySequence(Qt::Key_Escape) << QKeySequence(Qt::Key_MediaStop));
@@ -194,7 +213,7 @@ void MainWindow::createActions() {
     */
 
     skipBackwardAct = new QAction(
-                QtIconLoader::icon("media-skip-backward"),
+                IconUtils::icon("media-skip-backward"),
                 tr("P&revious"), this);
     skipBackwardAct->setStatusTip(tr("Go back to the previous track"));
     skipBackwardAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Left));
@@ -205,7 +224,7 @@ void MainWindow::createActions() {
     actions->insert("previous", skipBackwardAct);
 
     skipForwardAct = new QAction(
-                QtIconLoader::icon("media-skip-forward"),
+                IconUtils::icon("media-skip-forward"),
                 tr("&Next"), this);
     skipForwardAct->setStatusTip(tr("Skip to the next track"));
     skipForwardAct->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Right));
@@ -216,7 +235,7 @@ void MainWindow::createActions() {
     actions->insert("skip", skipForwardAct);
 
     playAct = new QAction(
-                QtIconLoader::icon("media-playback-start"),
+                IconUtils::icon("media-playback-start"),
                 tr("&Play"), this);
     playAct->setStatusTip(tr("Start playback"));
     playAct->setShortcuts(QList<QKeySequence>()
@@ -230,7 +249,7 @@ void MainWindow::createActions() {
     actions->insert("play", playAct);
 
     fullscreenAct = new QAction(
-                QtIconLoader::icon("view-restore"),
+                IconUtils::icon("view-fullscreen"),
                 tr("&Full Screen"), this);
     fullscreenAct->setStatusTip(tr("Go full screen"));
     QList<QKeySequence> fsShortcuts;
@@ -295,14 +314,18 @@ void MainWindow::createActions() {
     // Anon
     QAction *action;
 
-    action = new QAction(QtIconLoader::icon("edit-clear"), tr("&Clear"), this);
+    action = new QAction(tr("&Report an Issue..."), this);
+    actions->insert("report-issue", action);
+    connect(action, SIGNAL(triggered()), SLOT(reportIssue()));
+
+    action = new QAction(IconUtils::icon("edit-clear"), tr("&Clear"), this);
     action->setShortcut(QKeySequence::New);
     action->setStatusTip(tr("Remove all tracks from the playlist"));
     action->setEnabled(false);
     actions->insert("clearPlaylist", action);
 
     action = new QAction(
-                QtIconLoader::icon("media-playlist-shuffle"), tr("&Shuffle"), this);
+                IconUtils::icon("media-playlist-shuffle"), tr("&Shuffle"), this);
     action->setStatusTip(tr("Random playlist mode"));
     action->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_S));
     action->setCheckable(true);
@@ -310,7 +333,7 @@ void MainWindow::createActions() {
     actions->insert("shufflePlaylist", action);
 
     action = new QAction(
-                QtIconLoader::icon("media-playlist-repeat"),
+                IconUtils::icon("media-playlist-repeat"),
                 tr("&Repeat"), this);
     action->setStatusTip(tr("Play first song again after all songs are played"));
     action->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
@@ -323,7 +346,12 @@ void MainWindow::createActions() {
     actions->insert("close", action);
     connect(action, SIGNAL(triggered()), SLOT(close()));
 
-    action = new QAction(QtIconLoader::icon("media-playback-stop"),
+    action = new QAction(Constants::NAME, this);
+    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_1));
+    actions->insert("restore", action);
+    connect(action, SIGNAL(triggered()), SLOT(restore()));
+
+    action = new QAction(IconUtils::icon("media-playback-stop"),
                          tr("&Stop After This Track"), this);
     action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Escape));
     action->setCheckable(true);
@@ -345,10 +373,17 @@ void MainWindow::createActions() {
     actions->insert("lastFmLogout", action);
     connect(action, SIGNAL(triggered()), SLOT(lastFmLogout()));
 
+#ifdef APP_MAC_STORE
+    action = new QAction(tr("&Love %1? Rate it!").arg(Constants::NAME), this);
+    actions->insert("app-store", action);
+    connect(action, SIGNAL(triggered()), SLOT(rateOnAppStore()));
+#endif
+
     // Invisible actions
 
     searchFocusAct = new QAction(this);
     searchFocusAct->setShortcut(QKeySequence::Find);
+    searchFocusAct->setStatusTip(tr("Search"));
     actions->insert("search", searchFocusAct);
     connect(searchFocusAct, SIGNAL(triggered()), SLOT(searchFocus()));
     addAction(searchFocusAct);
@@ -366,13 +401,17 @@ void MainWindow::createActions() {
     addAction(volumeDownAct);
 
     volumeMuteAct = new QAction(this);
-    volumeMuteAct->setIcon(QtIconLoader::icon("audio-volume-high"));
+    volumeMuteAct->setIcon(IconUtils::icon("audio-volume-high"));
     volumeMuteAct->setStatusTip(tr("Mute volume"));
     volumeMuteAct->setShortcuts(QList<QKeySequence>() << QKeySequence(Qt::CTRL + Qt::Key_E));
     actions->insert("volume-mute", volumeMuteAct);
     connect(volumeMuteAct, SIGNAL(triggered()), SLOT(volumeMute()));
     addAction(volumeMuteAct);
 
+#ifdef APP_ACTIVATION
+    Extra::createActivationAction(tr("Buy %1...").arg(Constants::NAME));
+#endif
+
     // common action properties
     foreach (QAction *action, actions->values()) {
 
@@ -394,24 +433,21 @@ void MainWindow::createActions() {
         if (!action->shortcut().isEmpty())
             action->setStatusTip(action->statusTip() +
                                  " (" + action->shortcut().toString(QKeySequence::NativeText) + ")");
-
-        // no icons in menus
-        action->setIconVisibleInMenu(false);
-
     }
 
 }
 
 void MainWindow::createMenus() {
 
-    QMap<QString, QMenu*> *menus = The::globalMenus();
+    QHash<QString, QMenu*> *menus = The::globalMenus();
 
     fileMenu = menuBar()->addMenu(tr("&Application"));
-#ifdef APP_DEMO
-    QAction* action = new QAction(tr("Buy %1...").arg(Constants::NAME), this);
-    action->setMenuRole(QAction::ApplicationSpecificRole);
-    connect(action, SIGNAL(triggered()), SLOT(buy()));
-    fileMenu->addAction(action);
+#ifdef APP_ACTIVATION
+    QAction *buyAction = The::globalActions()->value("buy");
+    if (buyAction) fileMenu->addAction(buyAction);
+#ifndef APP_MAC
+    fileMenu->addSeparator();
+#endif
 #endif
     fileMenu->addAction(chooseFolderAct);
     fileMenu->addAction(The::globalActions()->value("lastFmLogout"));
@@ -437,6 +473,7 @@ void MainWindow::createMenus() {
     playlistMenu = menuBar()->addMenu(tr("Play&list"));
     menus->insert("playlist", playlistMenu);
     playlistMenu->addAction(The::globalActions()->value("clearPlaylist"));
+    playlistMenu->addSeparator();
     playlistMenu->addAction(The::globalActions()->value("shufflePlaylist"));
     playlistMenu->addAction(The::globalActions()->value("repeatPlaylist"));
     playlistMenu->addSeparator();
@@ -458,18 +495,20 @@ void MainWindow::createMenus() {
 #if !defined(APP_MAC) && !defined(APP_WIN)
     helpMenu->addAction(donateAct);
 #endif
+    helpMenu->addAction(The::globalActions()->value("report-issue"));
     helpMenu->addAction(aboutAct);
+
+#ifdef APP_MAC_STORE
+    helpMenu->addSeparator();
+    helpMenu->addAction(The::globalActions()->value("app-store"));
+#endif
 }
 
 void MainWindow::createToolBars() {
 
     setUnifiedTitleAndToolBarOnMac(true);
     mainToolBar = new QToolBar(this);
-#if QT_VERSION < 0x040600
-    mainToolBar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-#else
-    mainToolBar->setToolButtonStyle(Qt::ToolButtonFollowStyle);
-#endif
+    mainToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
     mainToolBar->setFloatable(false);
     mainToolBar->setMovable(false);
 
@@ -485,7 +524,7 @@ void MainWindow::createToolBars() {
 
     mainToolBar->addWidget(new Spacer());
 
-    QFont smallerFont = FontUtils::small();
+    QFont smallerFont = FontUtils::smaller();
     currentTime = new QLabel(mainToolBar);
     currentTime->setFont(smallerFont);
     mainToolBar->addWidget(currentTime);
@@ -497,15 +536,20 @@ void MainWindow::createToolBars() {
     seekSlider->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     mainToolBar->addWidget(seekSlider);
 
+    /*
     mainToolBar->addWidget(new Spacer());
-
     totalTime = new QLabel(mainToolBar);
     totalTime->setFont(smallerFont);
     mainToolBar->addWidget(totalTime);
+    */
 
     mainToolBar->addWidget(new Spacer());
 
     mainToolBar->addAction(volumeMuteAct);
+#ifdef Q_WS_X11
+    QToolButton *volumeMuteButton = qobject_cast<QToolButton *>(mainToolBar->widgetForAction(volumeMuteAct));
+    volumeMuteButton->setIcon(volumeMuteButton->icon().pixmap(16));
+#endif
 
     volumeSlider = new Phonon::VolumeSlider(this);
     volumeSlider->setMuteVisible(false);
@@ -534,7 +578,7 @@ void MainWindow::createToolBars() {
     toolbarSearch->setSuggester(new CollectionSuggester(this));
     connect(toolbarSearch, SIGNAL(search(const QString&)), SLOT(search(const QString&)));
     connect(toolbarSearch, SIGNAL(cleared()), SLOT(searchCleared()));
-    connect(toolbarSearch, SIGNAL(suggestionAccepted(const QString&)), SLOT(search(const QString&)));
+    connect(toolbarSearch, SIGNAL(suggestionAccepted(Suggestion*)), SLOT(suggestionAccepted(Suggestion*)));
     toolbarSearch->setStatusTip(searchFocusAct->statusTip());
 #ifdef APP_MAC
     mainToolBar->addWidget(searchWrapper);
@@ -549,20 +593,22 @@ void MainWindow::createToolBars() {
 }
 
 void MainWindow::createStatusBar() {
-
-    // remove ugly borders on OSX
-    statusBar()->setStyleSheet("::item{border:0 solid} QToolBar {padding:0;spacing:0;margin:0;border:0} QToolButton {padding:0;spacing:0;margin:0}");
-
     statusToolBar = new QToolBar(this);
     statusToolBar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-
-#ifdef APP_MAC
-    int iconHeight = 17;
+    statusToolBar->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
+#ifdef Q_OS_X11
+    int iconHeight = 16;
+    int iconWidth = iconHeight;
 #else
-    int iconHeight = 24;
-#endif
+    int iconHeight = 17;
     int iconWidth = iconHeight * 3 / 2;
+#endif
     statusToolBar->setIconSize(QSize(iconWidth, iconHeight));
+
+    QWidget *spring = new QWidget();
+    spring->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+    statusToolBar->addWidget(spring);
+
     statusToolBar->addAction(The::globalActions()->value("shufflePlaylist"));
     statusToolBar->addAction(The::globalActions()->value("repeatPlaylist"));
     statusToolBar->addAction(The::globalActions()->value("clearPlaylist"));
@@ -600,8 +646,9 @@ void MainWindow::writeSettings() {
         settings.setValue("geometry", saveGeometry());
 
     if (mediaView) {
-        settings.setValue("volume", audioOutput->volume());
-        settings.setValue("volumeMute", audioOutput->isMuted());
+        if (audioOutput->volume() > 0.1)
+            settings.setValue("volume", audioOutput->volume());
+        // settings.setValue("volumeMute", audioOutput->isMuted());
         mediaView->saveSplitterState();
     }
 
@@ -611,63 +658,40 @@ void MainWindow::goBack() {
     if (history->size() > 1) {
         history->pop();
         QWidget *widget = history->pop();
-        showView(widget);
+        showWidget(widget);
     }
 }
 
-void MainWindow::showView(QWidget* widget) {
+void MainWindow::showWidget(QWidget* widget, bool transition) {
 
     setUpdatesEnabled(false);
 
-    // call disappear() method on the old view
     View* oldView = dynamic_cast<View *> (views->currentWidget());
-    if (oldView) {
-        oldView->disappear();
-    }
 
-    // call appear() method on the new view
     View* newView = dynamic_cast<View *> (widget);
     if (newView) {
         newView->appear();
-
-        QMap<QString,QVariant> metadata = newView->metadata();
-        /*
-        QString windowTitle = metadata.value("title").toString();
-        if (windowTitle.length())
-            windowTitle += " - ";
-        setWindowTitle(windowTitle + Constants::NAME);
-        */
-        statusBar()->showMessage((metadata.value("description").toString()));
+        QHash<QString,QVariant> metadata = newView->metadata();
+        QString desc = metadata.value("description").toString();
+        if (!desc.isEmpty()) showMessage(desc);
     }
 
-    // fullscreenAct->setEnabled(widget == mediaView || widget == contextualView);
     aboutAct->setEnabled(widget != aboutView);
     chooseFolderAct->setEnabled(widget == mediaView || widget == contextualView);
     toolbarSearch->setEnabled(widget == mediaView || widget == contextualView);
 
-    // toolbar only for the mediaView
-    /*
-    bool showBars = widget == mediaView || widget == contextualView;
-    mainToolBar->setVisible(showBars);
-    statusBar()->setVisible(showBars);
-    */
-
-    setUpdatesEnabled(true);
-
-    /*
-    mainToolBar->setVisible(true);
-    statusBar()->setVisible(true);
-    */
-
     QWidget *oldWidget = views->currentWidget();
     views->setCurrentWidget(widget);
 
-#if defined(APP_MAC) || defined(APP_WIN)
-    // crossfade only on OSX
-    // where we can be sure of video performance
-    crossfadeViews(oldWidget, widget);
+    setUpdatesEnabled(true);
+
+#ifdef APP_EXTRA
+    if (transition)
+        Extra::fadeInWidget(oldWidget, widget);
 #endif
 
+    if (oldView) oldView->disappear();
+
     history->push(widget);
 
 #ifdef APP_MAC
@@ -676,26 +700,12 @@ void MainWindow::showView(QWidget* widget) {
 
 }
 
-void MainWindow::crossfadeViews(QWidget *oldWidget, QWidget *newWidget) {
-    if (faderWidget) faderWidget->close();
-    if (!oldWidget || !newWidget) {
-        // qDebug() << "no widgets";
-        return;
-    }
-    if (oldWidget == newWidget && history->isEmpty()) {
-        // qDebug() << "oldWidget == newWidget";
-        return;
-    }
-    faderWidget = new FaderWidget(newWidget);
-    faderWidget->start(QPixmap::grabWidget(oldWidget));
-}
-
 void MainWindow::about() {
     if (!aboutView) {
         aboutView = new AboutView(this);
         views->addWidget(aboutView);
     }
-    showView(aboutView);
+    showWidget(aboutView);
 }
 
 void MainWindow::visitSite() {
@@ -733,19 +743,20 @@ void MainWindow::closeEvent(QCloseEvent *event) {
 #endif
 }
 
-void MainWindow::showChooseFolderView() {
+void MainWindow::showChooseFolderView(bool transition) {
     if (!chooseFolderView) {
         chooseFolderView = new ChooseFolderView(this);
         connect(chooseFolderView, SIGNAL(locationChanged(QString)), SLOT(startFullScan(QString)));
         views->addWidget(chooseFolderView);
     }
-    showView(chooseFolderView);
+    showWidget(chooseFolderView, transition);
 }
 
-void MainWindow::showMediaView() {
-    if(!mediaView) {
+void MainWindow::showMediaView(bool transition) {
+    if (!mediaView) {
         initPhonon();
         mediaView = new MediaView(this);
+        mediaView->hide();
         mediaView->setMediaObject(mediaObject);
         connect(playAct, SIGNAL(triggered()), mediaView, SLOT(playPause()));
         views->addWidget(mediaView);
@@ -756,7 +767,7 @@ void MainWindow::showMediaView() {
     }
 
     mediaView->setFocus();
-    showView(mediaView);
+    showWidget(mediaView, transition);
 }
 
 void MainWindow::toggleContextualView() {
@@ -764,19 +775,25 @@ void MainWindow::toggleContextualView() {
         contextualView = new ContextualView(this);
         views->addWidget(contextualView);
     }
-    if (views->currentWidget() == contextualView) {
+
+    bool isShown = views->currentWidget() == contextualView;
+    if (isShown) {
         hideContextualView();
     } else {
         Track *track = mediaView->getActiveTrack();
         if (track) {
             contextualView->setTrack(track);
-            showView(contextualView);
+            showWidget(contextualView);
             contextualAct->setChecked(true);
 
             QList<QKeySequence> shortcuts;
             shortcuts << contextualAct->shortcuts() << QKeySequence(Qt::Key_Escape);
             contextualAct->setShortcuts(shortcuts);
-        }
+            statusBar()->hide();
+#ifndef APP_MAC
+            if (!m_fullscreen) mainToolBar->addAction(fullscreenAct);
+#endif
+        } else contextualAct->setChecked(false);
     }
 }
 
@@ -787,6 +804,11 @@ void MainWindow::hideContextualView() {
     QList<QKeySequence> shortcuts;
     shortcuts << QKeySequence(Qt::CTRL + Qt::Key_I);
     contextualAct->setShortcuts(shortcuts);
+
+    statusBar()->show();
+#ifndef APP_MAC
+    if (!m_fullscreen) mainToolBar->removeAction(fullscreenAct);
+#endif
 }
 
 void MainWindow::updateContextualView(Track *track) {
@@ -802,7 +824,7 @@ void MainWindow::startFullScan(QString directory) {
         collectionScannerView = new CollectionScannerView(this);
         views->addWidget(collectionScannerView);
     }
-    showView(collectionScannerView);
+    showWidget(collectionScannerView);
 
     CollectionScannerThread *scannerThread = new CollectionScannerThread();
     collectionScannerView->setCollectionScannerThread(scannerThread);
@@ -820,12 +842,19 @@ void MainWindow::startFullScan(QString directory) {
 }
 
 void MainWindow::fullScanFinished() {
+#ifdef APP_EXTRA
+    Extra::notify(tr("%1 finished scanning your music collection").arg(Constants::NAME), "", "");
+#else
     QApplication::alert(this, 0);
+#endif
+#ifdef APP_WIN
+    QApplication::alert(this, 0);
+#endif
     startImageDownload();
 }
 
 void MainWindow::startIncrementalScan() {
-    statusBar()->showMessage(tr("Updating collection..."));
+    showMessage(tr("Updating collection..."));
     chooseFolderAct->setEnabled(false);
     CollectionScannerThread *scannerThread = new CollectionScannerThread();
     // incremental!
@@ -836,23 +865,27 @@ void MainWindow::startIncrementalScan() {
 }
 
 void MainWindow::incrementalScanProgress(int percent) {
-    statusBar()->showMessage(tr("Updating collection - %1%").arg(QString::number(percent)));
+    showMessage(tr("Updating collection - %1%").arg(QString::number(percent)));
 }
 
 void MainWindow::incrementalScanFinished() {
-    chooseFolderAct->setEnabled(true);
-    statusBar()->showMessage(tr("Collection updated"));
+    if (views->currentWidget() == mediaView ||
+            views->currentWidget() == contextualView)
+        chooseFolderAct->setEnabled(true);
+    showMessage(tr("Collection updated"));
     startImageDownload();
 }
 
 void MainWindow::startImageDownload() {
     chooseFolderAct->setEnabled(false);
-    ImageDownloaderThread *downladerThread = new ImageDownloaderThread();
-    connect(downladerThread, SIGNAL(finished()), SLOT(imageDownloadFinished()));
-    downladerThread->start();
+    ImageDownloaderThread *downloaderThread = new ImageDownloaderThread();
+    connect(downloaderThread, SIGNAL(finished()), SLOT(imageDownloadFinished()));
+    downloaderThread->start();
 }
 
 void MainWindow::imageDownloadFinished() {
+    if (views->currentWidget() == mediaView ||
+            views->currentWidget() == contextualView)
     chooseFolderAct->setEnabled(true);
 }
 
@@ -871,20 +904,18 @@ void MainWindow::stateChanged(Phonon::State newState, Phonon::State /* oldState
 
     case Phonon::ErrorState:
         if (mediaObject->errorType() == Phonon::FatalError) {
-            statusBar()->showMessage(tr("Fatal error: %1").arg(mediaObject->errorString()));
+            showMessage(tr("Fatal error: %1").arg(mediaObject->errorString()));
         } else {
-            statusBar()->showMessage(tr("Error: %1").arg(mediaObject->errorString()));
+            showMessage(tr("Error: %1").arg(mediaObject->errorString()));
         }
         break;
 
     case Phonon::PlayingState:
         // stopAct->setEnabled(true);
-        contextualAct->setEnabled(true);
         break;
 
     case Phonon::StoppedState:
         // stopAct->setEnabled(false);
-        contextualAct->setEnabled(false);
         break;
 
     case Phonon::PausedState:
@@ -895,18 +926,15 @@ void MainWindow::stateChanged(Phonon::State newState, Phonon::State /* oldState
     case Phonon::LoadingState:
         // stopAct->setEnabled(true);
         currentTime->clear();
-        totalTime->clear();
+        // totalTime->clear();
         break;
-
-    default:
-        contextualAct->setEnabled(false);
     }
 }
 
 void MainWindow::stop() {
     mediaObject->stop();
     currentTime->clear();
-    totalTime->clear();
+    // totalTime->clear();
 }
 
 void MainWindow::resizeEvent(QResizeEvent *event) {
@@ -979,9 +1007,11 @@ void MainWindow::updateUIForFullscreen() {
         fullscreenAct->setShortcuts(QList<QKeySequence>(fsShortcuts)
                                     << QKeySequence(Qt::Key_Escape));
         fullscreenAct->setText(tr("Leave &Full Screen"));
+        fullscreenAct->setIcon(IconUtils::icon("view-restore"));
     } else {
         fullscreenAct->setShortcuts(fsShortcuts);
         fullscreenAct->setText(fsText);
+        fullscreenAct->setIcon(IconUtils::icon("view-fullscreen"));
     }
 
 #ifndef APP_MAC
@@ -1019,8 +1049,9 @@ void MainWindow::initPhonon() {
     volumeSlider->setAudioOutput(audioOutput);
 
     QSettings settings;
-    audioOutput->setVolume(settings.value("volume", 1).toDouble());
-    audioOutput->setMuted(settings.value("volumeMute").toBool());
+    volume = settings.value("volume", 1.).toReal();
+    audioOutput->setVolume(volume);
+    // audioOutput->setMuted(settings.value("volumeMute").toBool());
 }
 
 void MainWindow::tick(qint64 time) {
@@ -1040,11 +1071,13 @@ void MainWindow::tick(qint64 time) {
 }
 
 void MainWindow::totalTimeChanged(qint64 time) {
+    /*
     if (time <= 0) {
         totalTime->clear();
         return;
     }
     totalTime->setText(formatTime(time));
+    */
 }
 
 QString MainWindow::formatTime(qint64 time) {
@@ -1074,27 +1107,55 @@ void MainWindow::volumeDown() {
 }
 
 void MainWindow::volumeMute() {
-    if (volumeSlider->audioOutput()) {
-        volumeSlider->audioOutput()->setMuted(!volumeSlider->audioOutput()->isMuted());
+    bool isMuted = volumeSlider->audioOutput()->isMuted();
+    if (isMuted) {
+        // unmuting
+        volumeSlider->audioOutput()->setMuted(!isMuted);
+        volumeSlider->audioOutput()->setVolume(volume);
+    } else {
+        // muting
+        volume = volumeSlider->audioOutput()->volume();
+        volumeSlider->audioOutput()->setMuted(!isMuted);
     }
 }
 
 void MainWindow::volumeChanged(qreal newVolume) {
-    if (volumeSlider->audioOutput())
-        // automatically unmute when volume changes
-        if (volumeSlider->audioOutput()->isMuted())
-            volumeSlider->audioOutput()->setMuted(false);
-    statusBar()->showMessage(tr("Volume at %1%").arg(newVolume*100));
+    // automatically unmute when volume changes
+    if (volumeSlider->audioOutput()->isMuted())
+        volumeSlider->audioOutput()->setMuted(false);
+
+    bool isZero = volumeSlider->property("zero").toBool();
+    bool styleChanged = false;
+    if (newVolume == 0. && !isZero) {
+        volumeSlider->setProperty("zero", true);
+        styleChanged = true;
+    } else if (newVolume > 0. && isZero) {
+        volumeSlider->setProperty("zero", false);
+        styleChanged = true;
+    }
+    if (styleChanged) {
+        QSlider* volumeQSlider = volumeSlider->findChild<QSlider*>();
+        style()->unpolish(volumeQSlider);
+        style()->polish(volumeQSlider);
+    }
+
+    volume = volumeSlider->audioOutput()->volume();
+
+    showMessage(tr("Volume at %1%").arg((int)(newVolume*100)));
 }
 
 void MainWindow::volumeMutedChanged(bool muted) {
     if (muted) {
-        volumeMuteAct->setIcon(QtIconLoader::icon("audio-volume-muted"));
+        volumeMuteAct->setIcon(IconUtils::icon("audio-volume-muted"));
         statusBar()->showMessage(tr("Volume is muted"));
     } else {
-        volumeMuteAct->setIcon(QtIconLoader::icon("audio-volume-high"));
+        volumeMuteAct->setIcon(IconUtils::icon("audio-volume-high"));
         statusBar()->showMessage(tr("Volume is unmuted"));
     }
+#ifdef Q_WS_X11
+    QToolButton *volumeMuteButton = qobject_cast<QToolButton *>(mainToolBar->widgetForAction(volumeMuteAct));
+    volumeMuteButton->setIcon(volumeMuteButton->icon().pixmap(16));
+#endif
 }
 
 void MainWindow::setShuffle(bool enabled) {
@@ -1134,46 +1195,37 @@ void MainWindow::gotNewVersion(QString version) {
         updateChecker = 0;
     }
 
-#if defined(APP_DEMO) || defined(APP_MAC_STORE)
-    return;
-#endif
-
     QSettings settings;
     QString checkedVersion = settings.value("checkedVersion").toString();
     if (checkedVersion == version) return;
 
-    QMessageBox msgBox(this);
-    msgBox.setIconPixmap(QPixmap(":/images/app.png").scaled(64, 64, Qt::KeepAspectRatio, Qt::SmoothTransformation));
-    msgBox.setText(tr("%1 version %2 is now available.").arg(Constants::NAME, version));
-
-    msgBox.setModal(true);
-    // make it a "sheet" on the Mac
-    msgBox.setWindowModality(Qt::WindowModal);
-
-    QPushButton* laterButton = msgBox.addButton(tr("Remind me later"), QMessageBox::RejectRole);
-
-    QPushButton* updateButton = 0;
-
-#if defined(APP_MAC) || defined(APP_WIN)
-    msgBox.setInformativeText(
-                tr("To get the updated version, download %1 again from the link you received via email and reinstall.")
-                .arg(Constants::NAME)
-                );
-    msgBox.addButton(QMessageBox::Ok);
-#else
-    updateButton = msgBox.addButton(tr("Update"), QMessageBox::AcceptRole);
+#ifdef APP_EXTRA
+#ifndef APP_MAC
+    UpdateDialog *dialog = new UpdateDialog(version, this);
+    dialog->show();
 #endif
+#else
+    simpleUpdateDialog(version);
+#endif
+}
 
+void MainWindow::simpleUpdateDialog(QString version) {
+    QMessageBox msgBox(this);
+    msgBox.setIconPixmap(
+                QPixmap(":/images/app.png")
+                .scaled(64, 64, Qt::KeepAspectRatio, Qt::SmoothTransformation));
+    msgBox.setText(tr("%1 version %2 is now available.").arg(Constants::NAME, version));
+    msgBox.setModal(true);
+    msgBox.setWindowModality(Qt::WindowModal);
+    msgBox.addButton(QMessageBox::Close);
+    QPushButton* laterButton = msgBox.addButton(tr("Remind me later"), QMessageBox::RejectRole);
+    QPushButton* updateButton = msgBox.addButton(tr("Update"), QMessageBox::AcceptRole);
     msgBox.exec();
-
     if (msgBox.clickedButton() != laterButton) {
+        QSettings settings;
         settings.setValue("checkedVersion", version);
     }
-
-    if (updateButton && msgBox.clickedButton() == updateButton) {
-        QDesktopServices::openUrl(QUrl(QLatin1String(Constants::WEBSITE) + "#download"));
-    }
-
+    if (msgBox.clickedButton() == updateButton) visitSite();
 }
 
 QString MainWindow::playlistPath() {
@@ -1219,49 +1271,42 @@ void MainWindow::loadPlaylist() {
         qDebug() << "Cannot open file" << plsPath;
 }
 
+#ifdef APP_MAC_STORE
+void MainWindow::rateOnAppStore() {
+    QDesktopServices::openUrl(QUrl("macappstore://userpub.itunes.apple.com"
+                                   "/WebObjects/MZUserPublishing.woa/wa/addUserReview"
+                                   "?id=474190659&type=Purple+Software"));
+}
+#endif
+
 void MainWindow::search(QString query) {
     showMediaView();
     mediaView->search(query);
     toolbarSearch->setFocus();
 }
 
+void MainWindow::suggestionAccepted(Suggestion *suggestion) {
+    showMediaView();
+    mediaView->search(suggestion->value);
+}
+
 void MainWindow::searchCleared() {
     mediaView->search("");
 }
 
-#ifdef APP_DEMO
-void MainWindow::showDemoDialog(QString message) {
-    QMessageBox msgBox(this);
-    msgBox.setIconPixmap(QPixmap(":/images/app.png").scaled(64, 64, Qt::KeepAspectRatio, Qt::SmoothTransformation));
-    msgBox.setText(message);
-    msgBox.setModal(true);
-    // make it a "sheet" on the Mac
-    msgBox.setWindowModality(Qt::WindowModal);
-
-    msgBox.addButton(QMessageBox::Ok);
-    QPushButton *buyButton = msgBox.addButton(tr("Get the full version"), QMessageBox::ActionRole);
-
-    msgBox.exec();
-
-    if (msgBox.clickedButton() == buyButton) {
-        buy();
-    }
-}
-
-void MainWindow::buy() {
-    QDesktopServices::openUrl(QUrl(QString(Constants::WEBSITE) + "#download"));
-}
-#endif
-
 void MainWindow::showStopAfterThisInStatusBar(bool show) {
     QAction* action = The::globalActions()->value("stopafterthis");
     showActionInStatusBar(action, show);
 }
 
 void MainWindow::showActionInStatusBar(QAction* action, bool show) {
+#ifdef APP_EXTRA
+    Extra::fadeInWidget(statusBar(), statusBar());
+#endif
     if (show) {
         if (!statusToolBar->actions().contains(action))
-            statusToolBar->insertAction(statusToolBar->actions().first(), action);
+            // statusToolBar->insertAction(statusToolBar->actions().first(), action);
+            statusToolBar->insertAction(statusToolBar->actions().at(1), action);
     } else {
         statusToolBar->removeAction(action);
     }
@@ -1273,7 +1318,7 @@ void MainWindow::handleError(QString message) {
 }
 
 void MainWindow::showMessage(QString message) {
-    statusBar()->showMessage(message, 60000);
+    statusBar()->showMessage(message, 5000);
 }
 
 void MainWindow::toggleScrobbling(bool enable) {
@@ -1321,3 +1366,86 @@ void MainWindow::lastFmLogout() {
     action->setEnabled(false);
     action->setVisible(false);
 }
+
+void MainWindow::restore() {
+#ifdef APP_MAC
+    mac::uncloseWindow(window()->winId());
+#endif
+}
+
+void MainWindow::messageReceived(const QString &message) {
+    if (message.isEmpty()) return;
+
+    if (message == "--toggle-playing" && playAct->isEnabled()) playAct->trigger();
+    else if (message == "--next" && skipForwardAct->isEnabled()) skipForwardAct->trigger();
+    else if (message == "--previous" && skipBackwardAct->isEnabled()) skipBackwardAct->trigger();
+    else if (message == QLatin1String("--stop-after-this")) {
+        The::globalActions()->value("stopafterthis")->toggle();
+    }
+    else if (message == "--info" && contextualAct->isEnabled()) contextualAct->trigger();
+    else MainWindow::printHelp();
+}
+
+void MainWindow::printHelp() {
+    QString msg = QString("%1 %2\n\n").arg(Constants::NAME, Constants::VERSION);
+    msg += "Usage: musique [options]\n";
+    msg += "Options:\n";
+    msg += "  --toggle-playing\t";
+    msg += "Start or pause playback.\n";
+    msg += "  --next\t\t";
+    msg += "Skip to the next track.\n";
+    msg += "  --previous\t\t";
+    msg += "Go back to the previous track.\n";
+    msg += "  --info\t\t";
+    msg += "Display information about the current track.\n";
+    std::cout << msg.toLocal8Bit().data();
+}
+
+#ifdef APP_ACTIVATION
+void MainWindow::showActivationView(bool transition) {
+    QWidget *activationView = ActivationView::instance();
+    if (views->currentWidget() == activationView) {
+        buy();
+        return;
+    }
+    views->addWidget(activationView);
+    showWidget(activationView, transition);
+}
+
+void MainWindow::showActivationDialog() {
+    QTimer::singleShot(0, new ActivationDialog(this), SLOT(show()));
+}
+
+void MainWindow::buy() {
+    Extra::buy();
+}
+
+void MainWindow::hideBuyAction() {
+    QAction *action = The::globalActions()->value("buy");
+    action->setVisible(false);
+    action->setEnabled(false);
+}
+
+void MainWindow::showDemoDialog(QString message) {
+    QMessageBox msgBox(this);
+    msgBox.setIconPixmap(QPixmap(":/images/app.png").scaled(64, 64, Qt::KeepAspectRatio, Qt::SmoothTransformation));
+    msgBox.setText(message);
+    msgBox.setModal(true);
+    // make it a "sheet" on the Mac
+    msgBox.setWindowModality(Qt::WindowModal);
+
+    msgBox.addButton(QMessageBox::Ok);
+    QPushButton *buyButton = msgBox.addButton(tr("Get the full version"), QMessageBox::ActionRole);
+
+    msgBox.exec();
+
+    if (msgBox.clickedButton() == buyButton) {
+        showActivationView();
+    }
+}
+#endif
+
+void MainWindow::reportIssue() {
+    QUrl url("http://flavio.tordini.org/forums/forum/musique-forums/musique-troubleshooting");
+    QDesktopServices::openUrl(url);
+}
