@@ -1,7 +1,30 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 #include <phonon/audiooutput.h>
 #include <phonon/volumeslider.h>
 #include <phonon/mediaobject.h>
@@ -13,7 +36,7 @@ class ContextualView;
 class SearchLineEdit;
 class Track;
 class UpdateChecker;
-class FaderWidget;
+class Suggestion;
 
 class MainWindow : public QMainWindow {
 
@@ -22,21 +45,29 @@ class MainWindow : public QMainWindow {
 public:
     static MainWindow* instance();
     ~MainWindow();
+    QToolBar* getStatusToolbar() { return statusToolBar; }
+    static void printHelp();
 
 public slots:
-    void showMediaView();
-    void showChooseFolderView();
+    void showMediaView(bool transition = true);
+    void showChooseFolderView(bool transition = true);
     void toggleContextualView();
     void hideContextualView();
     void updateContextualView(Track *track);
     void showInitialView();
-#ifdef APP_DEMO
-    void showDemoDialog(QString message);
-    void buy();
-#endif
     void quit();
     void showMessage(QString message);
     void handleError(QString message);
+    void restore();
+    void messageReceived(const QString &message);
+    void goBack();
+#ifdef APP_ACTIVATION
+    void showActivationView(bool transition = true);
+    void showActivationDialog();
+    void buy();
+    void hideBuyAction();
+    void showDemoDialog(QString message);
+#endif
 
 protected:
     void closeEvent(QCloseEvent *);
@@ -44,10 +75,10 @@ protected:
     void resizeEvent(QResizeEvent *);
 
 private slots:
-    void crossfadeViews(QWidget *oldWidget, QWidget *newWidget);
-    void goBack();
+    void lazyInit();
     void visitSite();
     void donate();
+    void reportIssue();
     void about();
     void toggleFullscreen();
     void updateUIForFullscreen();
@@ -55,9 +86,6 @@ private slots:
     void setRepeat(bool enabled);
     void checkForUpdate();
     void gotNewVersion(QString version);
-    void enableUnifiedToolbar() {
-        setUnifiedTitleAndToolBarOnMac(true);
-    }
 
     // Phonon related logic
     void stop();
@@ -82,6 +110,7 @@ private slots:
     void startImageDownload();
     void imageDownloadFinished();
     void search(QString query);
+    void suggestionAccepted(Suggestion *suggestion);
     void searchCleared();
 
     void showActionInStatusBar(QAction*, bool show);
@@ -95,9 +124,13 @@ private slots:
     void savePlaylist();
     void loadPlaylist();
 
+#ifdef APP_MAC_STORE
+    void rateOnAppStore();
+#endif
+
 private:
     MainWindow();
-    void showView(QWidget*);
+    void showWidget(QWidget*, bool transition = true);
     void createActions();
     void createMenus();
     void createToolBars();
@@ -107,9 +140,9 @@ private:
     void initPhonon();
     static QString formatTime(qint64 time);
     QString playlistPath();
+    void simpleUpdateDialog(QString version);
 
     // view mechanism
-    QPointer<FaderWidget> faderWidget;
     QStackedWidget *views;
     QStack<QWidget*> *history;
 
@@ -134,7 +167,6 @@ private:
     QAction *skipBackwardAct;
     QAction *skipForwardAct;
     QAction *playAct;
-    // QAction *stopAct;
     QAction *fullscreenAct;
     QAction *volumeUpAct;
     QAction *volumeDownAct;
@@ -162,7 +194,8 @@ private:
     Phonon::MediaObject *mediaObject;
     Phonon::AudioOutput *audioOutput;
     QLabel *currentTime;
-    QLabel *totalTime;
+    // QLabel *totalTime;
+    qreal volume;
 
     // fullscreen
     bool m_fullscreen;
