@@ -1,22 +1,50 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "mediaview.h"
 #include "model/track.h"
 #include "model/artist.h"
-#include "../mainwindow.h"
+#include "mainwindow.h"
 #include "droparea.h"
 #include "minisplitter.h"
 #include "constants.h"
 #include "lastfm.h"
+#include "model/album.h"
+#ifdef APP_ACTIVATION
+#include "activation.h"
+#endif
+#include "database.h"
+#ifdef APP_EXTRA
+#include "extra.h"
+#endif
 
 namespace The {
-QMap<QString, QAction*>* globalActions();
-QMap<QString, QMenu*>* globalMenus();
+QHash<QString, QAction*>* globalActions();
+QHash<QString, QMenu*>* globalMenus();
 }
 
 MediaView::MediaView(QWidget *parent) : QWidget(parent) {
 
     activeTrack = 0;
 
-#ifdef APP_DEMO
+#ifdef APP_ACTIVATION
     tracksPlayed = 0;
 #endif
 
@@ -29,7 +57,8 @@ MediaView::MediaView(QWidget *parent) : QWidget(parent) {
 
     // playlist model
     playlistModel = new PlaylistModel(this);
-    connect(playlistModel, SIGNAL(activeRowChanged(int, bool)), SLOT(activeRowChanged(int, bool)));
+    connect(playlistModel, SIGNAL(activeRowChanged(int, bool, bool)),
+            SLOT(activeRowChanged(int, bool, bool)));
     connect(playlistModel, SIGNAL(playlistFinished()), SLOT(playlistFinished()));
 
     // finder
@@ -55,8 +84,8 @@ MediaView::MediaView(QWidget *parent) : QWidget(parent) {
 
     finderWidget->setPlaylistView(playlistView);
 
-    splitter->setStretchFactor(0, 6);
-    splitter->setStretchFactor(1, 1);
+    splitter->setStretchFactor(0, 8);
+    splitter->setStretchFactor(1, 0);
 
     // restore splitter state
     QSettings settings;
@@ -76,12 +105,15 @@ MediaView::MediaView(QWidget *parent) : QWidget(parent) {
 
 void MediaView::setMediaObject(Phonon::MediaObject *mediaObject) {
     this->mediaObject = mediaObject;
-    // connect(mediaObject, SIGNAL(aboutToFinish()), this, SLOT(aboutToFinish()));
+#ifdef APP_MAC
+    mediaObject->setTransitionTime(-300);
+#endif
     connect(mediaObject, SIGNAL(finished()), SLOT(playbackFinished()));
     connect(mediaObject, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
             SLOT(stateChanged(Phonon::State, Phonon::State)));
-    //connect(mediaObject, SIGNAL(currentSourceChanged(Phonon::MediaSource)),
-    // this, SLOT(currentSourceChanged(Phonon::MediaSource)));
+    connect(mediaObject, SIGNAL(aboutToFinish()), SLOT(aboutToFinish()));
+    connect(mediaObject, SIGNAL(currentSourceChanged(Phonon::MediaSource)),
+        SLOT(currentSourceChanged(Phonon::MediaSource)));
 }
 
 void MediaView::saveSplitterState() {
@@ -124,21 +156,28 @@ void MediaView::stateChanged(Phonon::State newState, Phonon::State /*oldState*/)
     }
 }
 
-void MediaView::activeRowChanged(int row, bool manual) {
+void MediaView::activeRowChanged(int row, bool manual, bool startPlayback) {
 
     errorTimer->stop();
 
     Track *track = playlistModel->trackAt(row);
-    if (!track) return;
+    if (!track) {
+        activeTrack = 0;
+        The::globalActions()->value("contextual")->setEnabled(false);
+        return;
+    }
 
     connect(track, SIGNAL(removed()), SLOT(trackRemoved()));
     activeTrack = track;
+    The::globalActions()->value("contextual")->setEnabled(true);
 
     // go!
-    QString path = track->getAbsolutePath();
-    // qDebug() << "Playing" << path;
-    mediaObject->setCurrentSource(path);
-    mediaObject->play();
+    if (startPlayback) {
+        QString path = track->getAbsolutePath();
+        qDebug() << "Playing" << path;
+        mediaObject->setCurrentSource(path);
+        mediaObject->play();
+    }
 
     track->setStartTime(QDateTime::currentDateTime().toTime_t());
 
@@ -150,10 +189,7 @@ void MediaView::activeRowChanged(int row, bool manual) {
         playlistView->scrollTo(index, QAbstractItemView::PositionAtCenter);
 
     // update info view
-    MainWindow* mainWindow = dynamic_cast<MainWindow*>(window());
-    if (mainWindow) {
-        mainWindow->updateContextualView(track);
-    }
+    MainWindow::instance()->updateContextualView(track);
 
     // track title as window title
     Artist *artist = track->getArtist();
@@ -166,6 +202,12 @@ void MediaView::activeRowChanged(int row, bool manual) {
     // enable/disable actions
     The::globalActions()->value("stopafterthis")->setEnabled(true);
 
+#ifdef APP_EXTRA
+    QString artistName = track->getArtist() ? track->getArtist()->getName() : "";
+    QString albumName = track->getAlbum() ? track->getAlbum()->getName() : "";
+    Extra::notify(track->getTitle(), artistName, albumName);
+#endif
+
     // scrobbling
     QSettings settings;
     if (settings.value("scrobbling").toBool() &&
@@ -178,15 +220,17 @@ void MediaView::activeRowChanged(int row, bool manual) {
 void MediaView::handleError(QString message) {
     // recover from errors by skipping to the next track
     errorTimer->start();
-
-    MainWindow* mainWindow = dynamic_cast<MainWindow*>(window());
-    if (mainWindow) mainWindow->statusBar()->showMessage(message);
+    MainWindow::instance()->showMessage(message);
 }
 
 void MediaView::appear() {
     finderWidget->appear();
 }
 
+void MediaView::disappear() {
+    finderWidget->disappear();
+}
+
 void MediaView::playPause() {
     // qDebug() << "playPause() state" << mediaObject->state();
 
@@ -217,14 +261,27 @@ void MediaView::trackRemoved() {
 }
 
 void MediaView::playlistFinished() {
-    MainWindow* mainWindow = dynamic_cast<MainWindow*>(window());
-    if (mainWindow) mainWindow->statusBar()->showMessage(tr("Playlist finished"));
+    MainWindow::instance()->showMessage(tr("Playlist finished"));
+
+    QAction *a = The::globalActions()->value("contextual");
+    if (a->isChecked()) MainWindow::instance()->hideContextualView();
+    a->setEnabled(false);
 }
 
 void MediaView::playbackFinished() {
-#ifdef APP_DEMO
-    if (tracksPlayed > 1) demoMessage();
-    else tracksPlayed++;
+    trackFinished();
+    QAction* stopAfterThisAction = The::globalActions()->value("stopafterthis");
+    if (stopAfterThisAction->isChecked()) {
+        stopAfterThisAction->setChecked(false);
+    } else playlistModel->skipForward();
+}
+
+void MediaView::trackFinished() {
+#ifdef APP_ACTIVATION
+    if (!Activation::instance().isActivated()) {
+        if (tracksPlayed > 1) demoMessage();
+        else tracksPlayed++;
+    }
 #endif
 
     // scrobbling
@@ -237,16 +294,36 @@ void MediaView::playbackFinished() {
         needScrobble = true;
     }
 
-    QAction* stopAfterThisAction = The::globalActions()->value("stopafterthis");
-    if (stopAfterThisAction->isChecked()) {
-        stopAfterThisAction->setChecked(false);
-    } else playlistModel->skipForward();
-
     if (needScrobble && track) LastFm::instance().scrobble(track);
-
 }
 
-#ifdef APP_DEMO
+void MediaView::aboutToFinish() {
+    QAction* stopAfterThisAction = The::globalActions()->value("stopafterthis");
+    if (!stopAfterThisAction->isChecked()) {
+        Track *nextTrack = playlistModel->getNextTrack();
+        if (nextTrack) {
+            QString absolutePath = nextTrack->getAbsolutePath();
+            qWarning() << "Enqueuing" << absolutePath;
+            mediaObject->enqueue(absolutePath);
+        }
+    }
+    trackFinished();
+}
+
+void MediaView::currentSourceChanged(Phonon::MediaSource mediaSource) {
+    QString path = mediaSource.fileName();
+    QString collectionRoot = Database::instance().collectionRoot();
+    path = path.mid(collectionRoot.length() + 1);
+    qWarning() << path;
+    Track* track = Track::forPath(path);
+    if (track) {
+        int row = playlistModel->rowForTrack(track);
+        if (row >= 0)
+            playlistModel->setActiveRow(row, false, false);
+    }
+}
+
+#ifdef APP_ACTIVATION
 
 static QPushButton *continueButton;
 
@@ -275,7 +352,7 @@ void MediaView::demoMessage() {
 
     if (msgBox.clickedButton() == buyButton) {
         QDesktopServices::openUrl(QUrl(QString(Constants::WEBSITE) + "#download"));
-    }
+    } else mediaObject->play();
 
     tracksPlayed = 0;
 
