@@ -1,6 +1,29 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "album.h"
 #include "../constants.h"
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 
 #include <QtSql>
 #include "../database.h"
@@ -16,7 +39,7 @@ NetworkAccess* http();
 
 static QHash<QString, QByteArray> artistAlbums;
 
-Album::Album() : year(0), artist(0) {
+Album::Album() : year(0), artist(0), listeners(0), photo(0), thumb(0) {
 
 }
 
@@ -44,8 +67,8 @@ Album* Album::forId(int albumId) {
 
         // relations
         int artistId = query.value(2).toInt();
-        // TODO this could be made lazy
         album->setArtist(Artist::forId(artistId));
+        // if (!album->getArtist()) qWarning() << "no artist for" << album->getName();
 
         // put into cache
         cache.insert(albumId, album);
@@ -55,12 +78,12 @@ Album* Album::forId(int albumId) {
     return 0;
 }
 
-int Album::idForName(QString name) {
+int Album::idForHash(QString hash) {
     int id = -1;
     QSqlDatabase db = Database::instance().getConnection();
     QSqlQuery query(db);
     query.prepare("select id from albums where hash=?");
-    query.bindValue(0, Album::getHash(name));
+    query.bindValue(0, hash);
     bool success = query.exec();
     if (!success) qDebug() << query.lastError().text();
     if (query.next()) {
@@ -73,12 +96,14 @@ int Album::idForName(QString name) {
 void Album::insert() {
     QSqlDatabase db = Database::instance().getConnection();
     QSqlQuery query(db);
-    query.prepare("insert into albums (hash,title,year,artist,trackCount) values (?,?,?,?,0)");
+    query.prepare("insert into albums (hash,title,year,artist,trackCount,listeners)"
+                  " values (?,?,?,?,0,?)");
     query.bindValue(0, getHash());
     query.bindValue(1, name);
     query.bindValue(2, year);
     int artistId = artist ? artist->getId() : 0;
     query.bindValue(3, artistId);
+    query.bindValue(4, listeners);
     bool success = query.exec();
     if (!success) qDebug() << query.lastError().text();
 
@@ -89,6 +114,17 @@ void Album::insert() {
         query.bindValue(0, artist->getId());
         bool success = query.exec();
         if (!success) qDebug() << query.lastError().text();
+
+        // for artists that have no yearFrom, use the earliest album year
+        if (year > 0) {
+            query = QSqlQuery(db);
+            query.prepare("update artists set yearFrom=? where id=? and (yearFrom=0 or yearFrom>?)");
+            query.bindValue(0, year);
+            query.bindValue(1, artist->getId());
+            query.bindValue(2, year);
+            bool success = query.exec();
+            if (!success) qDebug() << query.lastError().text();
+        }
     }
 
 }
@@ -107,24 +143,40 @@ void Album::update() {
     if (!success) qDebug() << query.lastError().text();
 }
 
-QString Album::getHash() {
-    return Album::getHash(name);
+QString Album::getHash(QString name, Artist *artist) {
+    QString h;
+    if (artist) h = artist->getHash() + "/";
+    else h = "_unknown/";
+    h += DataUtils::normalizeTag(name);
+    return h;
 }
 
-QString Album::getHash(QString name) {
-    // return DataUtils::calculateHash(DataUtils::normalizeTag(name));
-    return DataUtils::normalizeTag(name);
+const QString & Album::getHash() {
+    if (hash.isNull())
+        hash = getHash(name, artist);
+    return hash;
 }
 
 QString Album::getStatusTip() {
-    QString tip = "◯ ";
+    QString tip = QString::fromUtf8("◯ ");
     Artist* artist = getArtist();
     if (artist) tip += artist->getName() + " - ";
     tip += getTitle();
     if (year) tip += " (" + QString::number(year) + ")";
+    // tip += " - " + formattedDuration();
     return tip;
 }
 
+QString Album::formattedDuration() {
+    int totalLength = Track::getTotalLength(getTracks());
+    QString duration;
+    if (totalLength > 3600)
+        duration =  QTime().addSecs(totalLength).toString("h:mm:ss");
+    else
+        duration = QTime().addSecs(totalLength).toString("m:ss");
+    return duration;
+}
+
 void Album::fetchInfo() {
     // an artist name is needed in order to fix the album title
     // also workaround last.fm bug with selftitled albums
@@ -187,13 +239,22 @@ void Album::parseMusicBrainzReleaseDetails(QByteArray bytes) {
     qDebug() << name << "-> MusicBrainz ->" << correctTitle;
     if (!correctTitle.isEmpty()) {
         this->name = correctTitle;
+        hash.clear();
     }
 }
 
 // *** Last.fm Photo ***
 
-QImage Album::getPhoto() {
-    return QImage(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/albums/" + getHash());
+const QPixmap &Album::getPhoto() {
+    if (!photo)
+        photo = new QPixmap(getImageLocation());
+    return *photo;
+}
+
+const QPixmap &Album::getThumb() {
+    if (!thumb)
+        thumb = new QPixmap(getThumbLocation());
+    return *thumb;
 }
 
 void Album::fetchLastFmSearch() {
@@ -234,6 +295,7 @@ void Album::parseLastFmSearch(QByteArray bytes) {
                     if (name != albumName) {
                         qDebug() << "Fixed album name" << name << "=>" << albumName;
                         name = albumName;
+                        hash.clear();
                     }
                     break;
                 }
@@ -257,6 +319,7 @@ void Album::parseLastFmRedirectedName(QNetworkReply *reply) {
         int slashIndex = location.lastIndexOf('/');
         if (slashIndex > 0) {
             name = location.mid(slashIndex);
+            hash.clear();
             // qDebug() << "*** Redirected name is" << name;
             fetchLastFmSearch();
             return;
@@ -301,127 +364,111 @@ void Album::parseLastFmInfo(QByteArray bytes) {
 
     QMap<QString, QVariant> trackNames;
 
-    while(!xml.atEnd() && !xml.hasError()) {
-        QXmlStreamReader::TokenType token = xml.readNext();
-        if(token == QXmlStreamReader::StartElement) {
+    while(xml.readNextStartElement()) {
 
-            if(xml.name() == "toptags") {
-                xml.skipCurrentElement();
-                continue;
-            }
+        if (xml.name() == QLatin1String("album")) {
 
-            else if(xml.name() == "track") {
+            while (xml.readNextStartElement()) {
+                const QStringRef n = xml.name();
 
-                QString number = xml.attributes().value("rank").toString();
-                if (trackNames.contains(number)) xml.skipCurrentElement();
-                else
-                while (xml.readNextStartElement()) {
-                    // qDebug() << this << track << xml.name();
-                    if (xml.name() == "name") {
-                        QString title = xml.readElementText();
-                        trackNames.insert(number, title);
-                    }
-                    else xml.skipCurrentElement();
+                if(n == QLatin1String("track")) {
+                    QString number = xml.attributes().value("rank").toString();
+                    if (trackNames.contains(number)) xml.skipCurrentElement();
+                    else
+                        while (xml.readNextStartElement()) {
+                            if (xml.name() == "name") {
+                                QString title = xml.readElementText();
+                                trackNames.insert(number, title);
+                            }
+                            else xml.skipCurrentElement();
+                        }
                 }
-            }
 
-            else if(xml.name() == "name") {
-                QString albumTitle = xml.readElementText();
-                if (name != albumTitle) {
-                    qDebug() << "Fixed album name" << name << "->" << albumTitle;
-                    name = albumTitle;
-                }
-            }
-
-            else if(xml.name() == "image" && xml.attributes().value("size") == "extralarge") {
-
-                // qDebug() << title << " photo:" << imageUrl;
-
-                bool imageAlreadyPresent = false;
-                imageAlreadyPresent = property("localCover").toBool();
-                if (!imageAlreadyPresent)
-                    imageAlreadyPresent = QFile::exists(getImageLocation());
-                /*
-                if (QFile::exists(imageLocation)) {
-                    QFileInfo imageFileInfo(imageLocation);
-                    const uint imagelastModified = imageFileInfo.lastModified().toTime_t();
-                    if (imagelastModified > QDateTime::currentDateTime().toTime_t() - 86400*60) {
-                        imageAlreadyPresent = true;
-                    }
-                }*/
-
-                if (!imageAlreadyPresent) {
-                    QString imageUrl = xml.readElementText();
-                    // qDebug() << name << " photo:" << imageUrl;
-                    if (!imageUrl.isEmpty()) {
-                        /*
-                        QUrl url = QUrl::fromEncoded(imageUrl.toUtf8());
-                        QObject *reply = The::http()->get(url);
-                        connect(reply, SIGNAL(data(QByteArray)), SLOT(setPhoto(QByteArray)));
-                        connect(reply, SIGNAL(error(QNetworkReply*)), SIGNAL(gotInfo()));
-                        waitForImage = true;
-                        */
-
-                        setProperty("imageUrl", imageUrl);
+                else if(n == QLatin1String("name")) {
+                    QString albumTitle = xml.readElementText();
+                    if (name != albumTitle) {
+                        qDebug() << "Fixed album name" << name << "->" << albumTitle;
+                        name = albumTitle;
+                        hash.clear();
                     }
                 }
 
-            }
-
-            else if(xml.name() == "releasedate" && year < 1600) {
-                QString releasedateString = xml.readElementText().simplified();
-                if (!releasedateString.isEmpty()) {
-                    // Something like "6 Apr 1999, 00:00"
-                    QDateTime releaseDate = QDateTime::fromString(releasedateString, "d MMM yyyy, hh:mm");
-                    int releaseYear = releaseDate.date().year();
-                    if (releaseYear > 0) {
-                        year = releaseDate.date().year();
-                    }
-                    // qDebug() << name << releasedateString << releaseDate.toString();
+                else if(n == QLatin1String("image") &&
+                        xml.attributes().value("size") == QLatin1String("extralarge")) {
+                    bool imageAlreadyPresent = property("localCover").toBool();
+                    if (!imageAlreadyPresent)
+                        imageAlreadyPresent = QFile::exists(getImageLocation());
+                    if (!imageAlreadyPresent) {
+                        QString imageUrl = xml.readElementText();
+                        if (!imageUrl.isEmpty())
+                            setProperty("imageUrl", imageUrl);
+                    } else xml.skipCurrentElement();
                 }
-            }
 
-            // wiki
-            // TODO check at least parent element name
-            else if(xml.name() == "content") {
-                QString bio = xml.readElementText();
-                bio.remove(QRegExp("User-contributed text.*"));
-                // qDebug() << name << " got wiki";
-                if (!bio.isEmpty()) {
-                    // store bio
-                    const QString storageLocation =
-                            QDesktopServices::storageLocation(QDesktopServices::DataLocation)
-                            + "/albums/wikis/";
-                    QDir dir;
-                    dir.mkpath(storageLocation);
-                    QFile file(storageLocation + getHash());
-                    if (!file.open(QIODevice::WriteOnly)) {
-                        qDebug() << "Error opening file for writing" << file.fileName();
-                    }
-                    QTextStream stream( &file ); // we will serialize the data into the file
-                    stream << bio;
+                else if (n == QLatin1String("listeners")) {
+                    listeners = xml.readElementText().toUInt();
                 }
-            }
 
+                else if(n == QLatin1String("releasedate") && year < 1600) {
+                    QString releasedateString = xml.readElementText().simplified();
+                    if (!releasedateString.isEmpty()) {
+                        // Something like "6 Apr 1999, 00:00"
+                        QDateTime releaseDate = QDateTime::fromString(releasedateString, "d MMM yyyy, hh:mm");
+                        int releaseYear = releaseDate.date().year();
+                        if (releaseYear > 0)
+                            year = releaseDate.date().year();
+                    }
+                }
+
+                // wiki
+                else if(n == QLatin1String("wiki")) {
+                    while (xml.readNextStartElement()) {
+                        if(xml.name() == "content") {
+                            QString wiki = xml.readElementText();
+                            static const QRegExp re("User-contributed text.*");
+                            wiki.remove(re);
+                            wiki = wiki.trimmed();
+                            if (!wiki.isEmpty()) {
+                                QString wikiLocation = getWikiLocation();
+                                QDir().mkpath(QFileInfo(wikiLocation).absolutePath());
+                                QFile file(wikiLocation);
+                                if (!file.open(QIODevice::WriteOnly))
+                                    qWarning() << "Error opening file for writing" << file.fileName();
+                                QTextStream stream(&file);
+                                stream << wiki;
+                            }
+                        } else xml.skipCurrentElement();
+                    }
+                }
+
+                else xml.skipCurrentElement();
+
+            }
         }
-
     }
 
     setProperty("trackNames", trackNames);
 
-    /* Error handling. */
-    if(xml.hasError()) {
+    if(xml.hasError())
         qWarning() << xml.errorString();
-    }
 
     emit gotInfo();
 }
 
+QString Album::getBaseLocation() {
+    return Database::getFilesLocation() + getHash();
+}
+
 QString Album::getImageLocation() {
-    QString l = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/albums/";
-    // if (artist) l += artist->getHash() + "/";
-    l += getHash(); // + ".jpg";
-    return l;
+    return getBaseLocation() + QLatin1String("/_cover");
+}
+
+QString Album::getThumbLocation() {
+    return getBaseLocation() + QLatin1String("/_thumb");
+}
+
+QString Album::getWikiLocation() {
+    return getBaseLocation() + QLatin1String("/_wiki");
 }
 
 void Album::setPhoto(QByteArray bytes) {
@@ -429,15 +476,35 @@ void Album::setPhoto(QByteArray bytes) {
 
     // store photo
     QString storageLocation = getImageLocation();
+
+    QFileInfo info(storageLocation);
+    QDir().mkpath(info.absolutePath());
+
     QFile file(storageLocation);
-    QDir dir;
-    dir.mkpath(QFileInfo(file).path());
     if (!file.open(QIODevice::WriteOnly)) {
         qWarning() << "Error opening file for writing" << file.fileName();
     }
-    QDataStream stream( &file ); // we will serialize the data into the file
+    QDataStream stream(&file);
     stream.writeRawData(bytes.constData(), bytes.size());
 
+    // prescale 150x150 thumb
+    static const int maximumSize = 150;
+    QImage img = QImage::fromData(bytes);
+    img = img.scaled(maximumSize, maximumSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    if (!img.save(getThumbLocation(), "JPG")) {
+        qWarning() << "Error saving thumbnail" << file.fileName();
+    }
+
+    if (thumb) {
+        delete thumb;
+        thumb = 0;
+    }
+
+    if (photo) {
+        delete photo;
+        photo = 0;
+    }
+
     emit gotPhoto();
 }
 
@@ -464,22 +531,14 @@ QList<Track*> Album::getTracks() {
 }
 
 QString Album::getWiki() {
-
-    const QString storageLocation =
-            QDesktopServices::storageLocation(QDesktopServices::DataLocation)
-            + "/albums/wikis/";
-    QFile file(storageLocation + getHash());
-
+    QFile file(getWikiLocation());
     if (!file.exists()) return QString();
-
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         qDebug() << "Cannot open file" << file.fileName();
         return QString();
     }
-
     QByteArray bytes = file.readAll();
     return QString::fromUtf8(bytes.data());
-
 }
 
 QString normalizeString(QString s) {
