@@ -1,6 +1,29 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "artist.h"
 #include "../constants.h"
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 
 #include <QtSql>
 #include "../database.h"
@@ -13,9 +36,11 @@ namespace The {
 NetworkAccess* http();
 }
 
-Artist::Artist(QObject *parent) : Item(parent) {
-
-}
+Artist::Artist(QObject *parent) : Item(parent),
+    trackCount(0),
+    yearFrom(0),
+    yearTo(0),
+    listeners(0) { }
 
 QHash<int, Artist*> Artist::cache;
 
@@ -29,7 +54,7 @@ Artist* Artist::forId(int artistId) {
 
     QSqlDatabase db = Database::instance().getConnection();
     QSqlQuery query(db);
-    query.prepare("select name, trackCount from artists where id=?");
+    query.prepare("select name, trackCount, yearFrom, yearTo, listeners from artists where id=?");
     query.bindValue(0, artistId);
     bool success = query.exec();
     if (!success) qDebug() << query.lastQuery() << query.lastError().text();
@@ -38,8 +63,9 @@ Artist* Artist::forId(int artistId) {
         artist->setId(artistId);
         artist->setName(query.value(0).toString());
         artist->trackCount = query.value(1).toInt();
-        // artist->lifeBegin = query.value(2).toInt();
-        // artist->lifeEnd = query.value(3).toInt();
+        artist->yearFrom = query.value(2).toInt();
+        artist->yearTo = query.value(3).toInt();
+        artist->listeners = query.value(4).toUInt();
         // Add other fields here...
 
         // put into cache
@@ -74,9 +100,14 @@ void Artist::insert() {
     // qDebug() << "Artist::insert";
     QSqlDatabase db = Database::instance().getConnection();
     QSqlQuery query(db);
-    query.prepare("insert into artists (hash, name, albumCount, trackCount) values (?,?,0,0)");
+    query.prepare("insert into artists"
+                  " (hash, name, yearFrom, yearTo, listeners, albumCount, trackCount)"
+                  " values (?,?,?,?,?,0,0)");
     query.bindValue(0, hash);
     query.bindValue(1, name);
+    query.bindValue(2, yearFrom);
+    query.bindValue(3, yearTo);
+    query.bindValue(4, listeners);
     // qDebug() << query.lastQuery();
     bool success = query.exec();
     if (!success) qDebug() << query.lastError().text();
@@ -93,17 +124,18 @@ void Artist::update() {
     if (!success) qDebug() << query.lastError().text();
 }
 
-QString Artist::getHash() {
-    return Artist::getHash(name);
+const QString &Artist::getHash() {
+    if (hash.isNull())
+        hash = getHash(name);
+    return hash;
 }
 
-QString Artist::getHash(QString name) {
-    // return DataUtils::calculateHash(DataUtils::normalizeTag(name));
+QString Artist::getHash(const QString &name) {
     return DataUtils::normalizeTag(name);
 }
 
 QString Artist::getStatusTip() {
-    return name;
+    return name + QLatin1String(" - ") + QString("%1 tracks").arg(trackCount);
 }
 
 void Artist::fetchInfo() {
@@ -127,6 +159,7 @@ void Artist::parseMusicBrainzArtist(QByteArray bytes) {
     qDebug() << name << "-> MusicBrainz ->" << correctName;
     if (!correctName.isEmpty()) {
         this->name = correctName;
+        hash.clear();
     }
 
     // And now gently ask the Last.fm guys for some more info
@@ -204,6 +237,7 @@ void Artist::parseNameAndMbid(QByteArray bytes, QString preferredValue) {
 
             if (text.toLower() == preferredValueLower) {
                 name = text;
+                hash.clear();
                 mbid = artistMbid;
                 return;
             }
@@ -223,13 +257,14 @@ void Artist::parseNameAndMbid(QByteArray bytes, QString preferredValue) {
     }
 
     name = firstValue;
+    hash.clear();
     mbid = firstMbid;
 
 }
 
 void Artist::parseLastFmSearch(QByteArray bytes) {
 
-    static const QString redirectToken = "+noredirect/";
+    // static const QString redirectToken = "+noredirect/";
 
     // mbid = DataUtils::getXMLElementText(bytes, "mbid");
     // name = DataUtils::getXMLElementTextWithPreferredValue(bytes, "name", name);
@@ -270,6 +305,7 @@ void Artist::parseLastFmRedirectedName(QNetworkReply *reply) {
             QString redirectedName = location.mid(slashIndex + 1);
             qDebug() << name << "redirected to" << redirectedName;
             name = redirectedName;
+            hash.clear();
             fetchLastFmSearch();
             return;
         }
@@ -296,129 +332,111 @@ void Artist::fetchLastFmInfo() {
 void Artist::parseLastFmInfo(QByteArray bytes) {
     QXmlStreamReader xml(bytes);
 
-    bool gotImage = false;
-    bool gotBio = false;
+    while(xml.readNextStartElement()) {
 
-    // qDebug() << "Artist::parseLastFmInfo";
+        if (xml.name() == "artist") {
 
-    /* We'll parse the XML until we reach end of it.*/
-    while(!xml.atEnd() && !xml.hasError()) {
+            while (xml.readNextStartElement()) {
+                const QStringRef n = xml.name();
 
-        /* Read next element.*/
-        QXmlStreamReader::TokenType token = xml.readNext();
-
-        /*
-        qDebug() << xml.name();
-        foreach (QXmlStreamAttribute attribute, xml.attributes())
-            qDebug() << attribute.name() << ":" << attribute.value();
-            */
-
-        /* If token is StartElement, we'll see if we can read it.*/
-        if(token == QXmlStreamReader::StartElement) {
-
-            if(xml.name() == "similar" || xml.name() == "tags") {
-                xml.skipCurrentElement();
-                continue;
-            }
-
-            else if(xml.name() == "name") {
-                QString artistName = xml.readElementText();
-                if (name != artistName) {
-                    qDebug() << "Fixed artist name" << name << "->" << artistName;
-                    name = artistName;
-                }
-            }
-
-            // image
-            else if(!gotImage && xml.name() == "image" && xml.attributes().value("size") == "extralarge") {
-                gotImage = true;
-
-                QString imageLocation = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/artists/" + getHash();
-                bool imageAlreadyPresent = QFile::exists(imageLocation);
-
-                /*
-                bool imageAlreadyPresent = false;
-                QString imageLocation = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/artists/" + getHash();
-                if (QFile::exists(imageLocation)) {
-                    QFileInfo imageFileInfo(imageLocation);
-                    const uint imagelastModified = imageFileInfo.lastModified().toTime_t();
-                    if (imagelastModified > QDateTime::currentDateTime().toTime_t() - 86400*60) {
-                        imageAlreadyPresent = true;
+                if(n == QLatin1String("name")) {
+                    QString artistName = xml.readElementText();
+                    if (name != artistName) {
+                        qDebug() << "Fixed artist name" << name << "->" << artistName;
+                        name = artistName;
+                        hash.clear();
                     }
                 }
-                */
 
-                if (!imageAlreadyPresent) {
-                    QString imageUrl = xml.readElementText();
-                    // qDebug() << name << " photo:" << imageUrl;
-                    if (!imageUrl.isEmpty()) {
-                        /*
-                        QUrl url = QUrl::fromEncoded(imageUrl.toUtf8());
-                        QObject *reply = The::http()->get(url);
-                        connect(reply, SIGNAL(data(QByteArray)), SLOT(setPhoto(QByteArray)));
-                        connect(reply, SIGNAL(error(QNetworkReply*)), SIGNAL(gotInfo()));
-                        waitForImage = true;
-                        */
-                        setProperty("imageUrl", imageUrl);
+                else if(n == QLatin1String("image") &&
+                        xml.attributes().value("size") == QLatin1String("extralarge")) {
+                    if (!QFile::exists(getImageLocation())) {
+                        QString imageUrl = xml.readElementText();
+                        if (!imageUrl.isEmpty())
+                            setProperty("imageUrl", imageUrl);
+                    } else xml.skipCurrentElement();
+                }
+
+                else if (n == QLatin1String("stats")) {
+                    while (xml.readNextStartElement()) {
+                        if(xml.name() == "listeners") {
+                            listeners = xml.readElementText().toUInt();
+                        } else xml.skipCurrentElement();
                     }
                 }
-            }
 
-            // bio
-            // TODO check at least parent element name
-            else if(!gotBio && xml.name() == "content") {
-                gotBio = true;
-                bio = xml.readElementText();
+                else if(n == QLatin1String("bio")) {
+                    while (xml.readNextStartElement()) {
+                        if(xml.name() == "content") {
+                            QString bio = xml.readElementText();
+                            static const QRegExp licenseRE("User-contributed text is available.*");
+                            bio.remove(licenseRE);
+                            bio = bio.trimmed();
+                            if (!bio.isEmpty()) {
+                                const QString bioLocation = getBioLocation();
+                                QDir().mkpath(QFileInfo(bioLocation).absolutePath());
+                                QFile file(bioLocation);
+                                if (!file.open(QIODevice::WriteOnly))
+                                    qWarning() << "Error opening file for writing" << file.fileName();
+                                QTextStream stream(&file);
+                                stream << bio;
+                            }
 
-                static QRegExp licenseRE("User-contributed text is available.*");
-                bio.remove(licenseRE);
+                        } else if (xml.name() == "formationlist") {
+                            while (xml.readNextStartElement()) {
+                                if(xml.name() == "formation") {
+                                    while (xml.readNextStartElement()) {
+                                        if(yearFrom == 0 && xml.name() == "yearfrom") {
+                                            yearFrom = xml.readElementText().toInt();
+                                        } else if(xml.name() == "yearto") {
+                                            yearTo = xml.readElementText().toInt();
+                                        } else xml.skipCurrentElement();
+                                    }
+                                } else xml.skipCurrentElement();
+                            }
+                        }
 
-                // qDebug() << name << " got bio";
-                if (!bio.isEmpty()) {
-                    // store bio
-                    const QString storageLocation =
-                            QDesktopServices::storageLocation(QDesktopServices::DataLocation)
-                            + "/artists/biographies/";
-                    QDir dir;
-                    dir.mkpath(storageLocation);
-                    QFile file(storageLocation + getHash());
-                    if (!file.open(QIODevice::WriteOnly)) {
-                        qDebug() << "Error opening file for writing" << file.fileName();
+                        else xml.skipCurrentElement();
                     }
-                    QTextStream stream( &file ); // we will serialize the data into the file
-                    stream << bio;
                 }
+
+                else xml.skipCurrentElement();
+
             }
 
         }
 
-        // if (gotImage && gotBio) break;
     }
 
-    /* Error handling. */
-    if(xml.hasError()) {
-        qDebug() << xml.errorString();
-    }
+    if(xml.hasError())
+        qWarning() << xml.errorString();
 
     emit gotInfo();
 }
 
-QString Artist::getImageLocation() {
-    return QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/artists/" + getHash();
+QString Artist::getBaseLocation() {
+    return Database::getFilesLocation() + getHash();
 }
 
-QImage Artist::getPhoto() {
-    return QImage(getImageLocation());
+QString Artist::getImageLocation() {
+    return getBaseLocation() + QLatin1String("/_photo");
+}
+
+QString Artist::getBioLocation() {
+    return getBaseLocation() + QLatin1String("/_bio");
+}
+
+QPixmap Artist::getPhoto() {
+    return QPixmap(getImageLocation());
 }
 
 void Artist::setPhoto(QByteArray bytes) {
     qDebug() << "Storing photo for" << name;
 
     // store photo
-    QString storageLocation = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/artists/";
-    QDir dir;
-    dir.mkpath(storageLocation);
-    QFile file(storageLocation + getHash());
+    QString storageLocation = getImageLocation();
+    QDir().mkpath(QFileInfo(storageLocation).absolutePath());
+    QFile file(storageLocation);
     if (!file.open(QIODevice::WriteOnly)) {
         qDebug() << "Error opening file for writing" << file.fileName();
     }
@@ -431,7 +449,9 @@ void Artist::setPhoto(QByteArray bytes) {
 QList<Track*> Artist::getTracks() {
     QSqlDatabase db = Database::instance().getConnection();
     QSqlQuery query(db);
-    query.prepare("select id from tracks where artist=? order by album, track, path");
+    query.prepare("select distinct t.id from tracks t, albums a"
+                  " where (t.album=a.id or t.album=0) and t.artist=?"
+                  " order by a.year desc, a.title collate nocase, t.track, t.path");
     query.bindValue(0, id);
     bool success = query.exec();
     if (!success) qDebug() << query.lastQuery() << query.lastError().text() << query.lastError().number();
@@ -441,24 +461,17 @@ QList<Track*> Artist::getTracks() {
         Track* track = Track::forId(trackId);
         tracks << track;
     }
+
     return tracks;
 }
 
 QString Artist::getBio() {
-
-    const QString storageLocation =
-            QDesktopServices::storageLocation(QDesktopServices::DataLocation)
-            + "/artists/biographies/";
-    QFile file(storageLocation + getHash());
-
+    QFile file(getBioLocation());
     if (!file.exists()) return QString();
-
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         qDebug() << "Cannot open file" << file.fileName();
         return QString();
     }
-
     QByteArray bytes = file.readAll();
     return QString::fromUtf8(bytes.data());
-
 }
