@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #ifndef ARTIST_H
 #define ARTIST_H
 
@@ -22,8 +42,10 @@ public:
     // properties
     QString getName()  { return name; }
     void setName(QString name) { this->name = name; }
-    QString getHash();
+    const QString &getHash();
     int getTrackCount() { return trackCount; }
+    QString getBaseLocation();
+    QString getBioLocation();
     QString getBio();
 
     // relations
@@ -49,7 +71,7 @@ public:
     void fetchInfo();
 
     QString getImageLocation();
-    QImage getPhoto();
+    QPixmap getPhoto();
 
     // qhash
     /*
@@ -79,18 +101,24 @@ private slots:
 
 private:
     void parseNameAndMbid(QByteArray bytes, QString preferredName);
-    static QString getHash(QString);
+    static QString getHash(const QString&);
 
     static QHash<int, Artist*> cache;
 
     int trackCount;
 
     QString name;
-    QString bio;
     QString mbid;
 
+    int yearFrom;
+    int yearTo;
+    uint listeners;
+    // QStringList tags;
+
     QStringList lastFmSearches;
 
+    QString hash;
+
 };
 
 // This is required in order to use QPointer<Artist> as a QVariant
