@@ -1,3 +1,23 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "track.h"
 #include "album.h"
 #include "artist.h"
@@ -294,7 +314,7 @@ QString Track::getHash(QString name) {
 }
 
 QString Track::getStatusTip() {
-    QString tip = "♫ ";
+    QString tip = QString::fromUtf8("♫ ");
     Artist* artist = getArtist();
     if (artist) tip += artist->getName() + " - ";
     Album* album = getAlbum();
@@ -343,6 +363,13 @@ QString Track::getAbsolutePath() {
     return absolutePath;
 }
 
+QString Track::getLyricsLocation() {
+    QString l = Database::getFilesLocation();
+    if (artist) l += artist->getHash();
+    l += QLatin1String("/_lyrics/") + getHash();
+    return l;
+}
+
 void Track::getLyrics() {
 #ifdef APP_MAC_STORE_NO
     bool haveStyle = (QFile::exists(qApp->applicationDirPath() + "/../Resources/style.css"));
@@ -351,17 +378,7 @@ void Track::getLyrics() {
     }
 #endif
 
-    QString artistName;
-    if (artist) artistName = artist->getName();
-
-    // read from cache
-    const QString storageLocation =
-            QDesktopServices::storageLocation(QDesktopServices::DataLocation)
-            + "/lyrics";
-    QString filePath = storageLocation;
-    if (artist) filePath += "/" + artist->getHash();
-    filePath += "/" + getHash();
-    QFile file(filePath);
+    QFile file(getLyricsLocation());
     if (file.exists()) {
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             qDebug() << "Cannot open file" << file.fileName();
@@ -372,6 +389,9 @@ void Track::getLyrics() {
         }
     }
 
+    QString artistName;
+    if (artist) artistName = artist->getName();
+
     // http://lyrics.wikia.com/LyricWiki:REST
     QUrl url = QString(
             "http://lyrics.wikia.com/api.php?func=getSong&artist=%1&song=%2&fmt=xml")
@@ -408,8 +428,8 @@ void Track::parseLyricsSearchResults(QByteArray bytes) {
 void Track::scrapeLyrics(QByteArray bytes) {
     QString lyrics = QString::fromUtf8(bytes);
 
-
     int pos = lyrics.indexOf( "'lyricbox'" );
+    if (pos == -1) return;
     int startPos = lyrics.indexOf( ">", pos ) + 1;
     int endPos = lyrics.indexOf( "</div>", startPos );
     int otherDivPos = lyrics.indexOf( "<div", startPos );
@@ -449,13 +469,8 @@ void Track::scrapeLyrics(QByteArray bytes) {
     lyrics = lyrics.simplified();
 
     // cache lyrics
-    QString filePath =
-            QDesktopServices::storageLocation(QDesktopServices::DataLocation)
-            + "/lyrics";
-    if (artist) filePath += "/" + artist->getHash();
-    QDir dir;
-    dir.mkpath(filePath);
-    filePath += "/" + getHash();
+    QString filePath = getLyricsLocation();
+    QDir().mkpath(QFileInfo(filePath).absolutePath());
     QFile file(filePath);
     if (!file.open(QIODevice::WriteOnly)) {
         qDebug() << "Error opening file for writing" << file.fileName();
