@@ -1,15 +1,35 @@
+/* $BEGIN_LICENSE
+
+This file is part of Musique.
+Copyright 2013, Flavio Tordini <flavio.tordini@gmail.com>
+
+Musique is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Musique is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Musique.  If not, see <http://www.gnu.org/licenses/>.
+
+$END_LICENSE */
+
 #include "playlistitemdelegate.h"
 #include "model/track.h"
 #include "model/album.h"
 #include "model/artist.h"
 #include "playlistmodel.h"
-#include "iconloader/qticonloader.h"
+#include "iconutils.h"
 
 const int PlaylistItemDelegate::PADDING = 10;
 int PlaylistItemDelegate::ITEM_HEIGHT = 0;
 
 PlaylistItemDelegate::PlaylistItemDelegate(QObject *parent) :
-        QStyledItemDelegate(parent) {
+    QStyledItemDelegate(parent) {
 
 }
 
@@ -27,7 +47,8 @@ QSize PlaylistItemDelegate::sizeHint(const QStyleOptionViewItem &option, const Q
         if (previousTrack) {
             const TrackPointer trackPointer = index.data(Playlist::DataObjectRole).value<TrackPointer>();
             Track *track = trackPointer.data();
-            if (previousTrack->getAlbum() != track->getAlbum()) {
+            if (previousTrack->getAlbum() != track->getAlbum()
+                    || previousTrack->getArtist() != track->getArtist()) {
                 return QSize(ITEM_HEIGHT*2, ITEM_HEIGHT*2);
             }
         }
@@ -45,28 +66,22 @@ void PlaylistItemDelegate::paint(
     paintTrack(painter, option, index);
 }
 
-QPixmap PlaylistItemDelegate::createPlayIcon() const {
-    QIcon icon = QtIconLoader::icon("media-playback-start");
-    return icon.pixmap(16, 16);
-}
-
-QPixmap PlaylistItemDelegate::getPlayIcon() const {
-    static QPixmap playIcon;
-    if (playIcon.isNull()) {
-        playIcon = createPlayIcon();
-    }
-    return playIcon;
+QPixmap PlaylistItemDelegate::getPlayIcon(const QColor& color, const QStyleOptionViewItem &option) const {
+    static QHash<QString, QPixmap> cache;
+    const QString key = color.name();
+    if (cache.contains(key)) return cache.value(key);
+    const int iconSize = ITEM_HEIGHT / 2;
+    QIcon icon = IconUtils::tintedIcon("media-playback-start", color, QList<QSize>() << QSize(32, 32));
+    QPixmap pixmap = icon.pixmap(iconSize, iconSize);
+    cache.insert(key, pixmap);
+    return pixmap;
 }
 
 void PlaylistItemDelegate::paintTrack(QPainter *painter,
                                       const QStyleOptionViewItem &option,
                                       const QModelIndex &index) const {
 
-    // get the data object
-    const TrackPointer trackPointer = index.data(Playlist::DataObjectRole).value<TrackPointer>();
-    Track *track = trackPointer.data();
-
-    // const PlaylistModel* playlistModel = dynamic_cast<const PlaylistModel*>(index.model());
+    Track *track = index.data(Playlist::DataObjectRole).value<TrackPointer>().data();
 
     const bool isActive = index.data(Playlist::ActiveItemRole).toBool();
     // const bool isHovered = index.data(Playlist::HoveredItemRole).toBool();
@@ -80,12 +95,6 @@ void PlaylistItemDelegate::paintTrack(QPainter *painter,
     painter->translate(option.rect.topLeft());
     QRect line(0, 0, option.rect.width(), option.rect.height());
 
-#if defined(APP_MAC) | defined(APP_WIN)
-    if (isSelected) {
-        paintSelectedOverlay(painter, line);
-    }
-#endif
-
     // text color
     if (isSelected)
         painter->setPen(QPen(option.palette.brush(QPalette::HighlightedText), 0));
@@ -105,123 +114,125 @@ void PlaylistItemDelegate::paintTrack(QPainter *painter,
 
     if (isActive) {
         if (!isSelected) paintActiveOverlay(painter, option, line);
-        QFont boldFont = painter->font();
-        boldFont.setBold(true);
-        painter->setFont(boldFont);
         // play icon
-        painter->drawPixmap(PADDING*2, (ITEM_HEIGHT - 16) / 2, 16, 16, getPlayIcon());
+        QPixmap p = getPlayIcon(painter->pen().color(), option);
+        painter->drawPixmap(PADDING*1.5, (ITEM_HEIGHT - p.height()) / 2, p);
     } else {
         paintTrackNumber(painter, option, line, track);
     }
 
     // qDebug() << "painting" << track;
-    paintTrackTitle(painter, option, line, track);
+    paintTrackTitle(painter, option, line, track, isActive);
     paintTrackLength(painter, option, line, track);
 
     // separator
-    painter->setPen(option.palette.color(QPalette::Midlight));
-    painter->drawLine(0, line.height()-1, line.width(), line.height()-1);
+    if (!isActive) {
+        painter->setOpacity(.1);
+        painter->drawLine(0, line.height()-1, line.width(), line.height()-1);
+    }
 
     painter->restore();
 }
 
 void PlaylistItemDelegate::paintAlbumHeader(
-        QPainter* painter, const QStyleOptionViewItem& option, QRect line, Track* track) const {
+        QPainter* painter, const QStyleOptionViewItem& option,
+        const QRect & line, Track* track) const {
 
     QString headerTitle;
     Album *album = track->getAlbum();
     if (album) headerTitle = album->getTitle();
     Artist *artist = track->getArtist();
-    if (artist) headerTitle += " - " + artist->getName();
+    if (artist) {
+        if (!headerTitle.isEmpty()) headerTitle += " - ";
+        headerTitle += artist->getName();
+    }
 
     painter->save();
 
-    // cover background
-    /*
-    QImage p = album->getPhoto();
-    if (!p.isNull()) {
-        painter->drawTiledPixmap(line, QPixmap::fromImage(p));
-        QLinearGradient linearGrad(0, 0, 0, line.height());
-        linearGrad.setColorAt(0, QColor(0,0,0, 96));
-        linearGrad.setColorAt(1, QColor(0,0,0, 64));
-        painter->fillRect(line, QBrush(linearGrad));
-    } else {
-        QLinearGradient linearGrad(0, 0, 0, line.height());
-        linearGrad.setColorAt(0, option.palette.color(QPalette::Mid));
-        linearGrad.setColorAt(1, option.palette.midlight().color());
-        painter->fillRect(line, QBrush(linearGrad));
-    }*/
+    const int h = line.height();
 
-    QLinearGradient linearGrad(0, 0, 0, line.height());
-#ifdef APP_MAC
-    linearGrad.setColorAt(0, QColor(0x99, 0x99, 0x99, 0xFF));
-    linearGrad.setColorAt(1, QColor(0xCC, 0xCC, 0xCC, 0xFF));
-#else
-    linearGrad.setColorAt(0, option.palette.color(QPalette::Mid));
-    linearGrad.setColorAt(1, option.palette.color(QPalette::Midlight));
-#endif
-    painter->fillRect(line, QBrush(linearGrad));
+    static const int saturation = 24;
+    static const int value = 192;
+    QColor highlightColor = option.palette.color(QPalette::Highlight);
+    QColor topColor = QColor::fromHsv(highlightColor.hue(), saturation, value);
+    QColor bottomColor = QColor::fromHsv(topColor.hue(), saturation, value - 16);
+    QLinearGradient linearGradient(0, 0, 0, h);
+    linearGradient.setColorAt(0.0, topColor);
+    linearGradient.setColorAt(1.0, bottomColor);
+    painter->fillRect(line, linearGradient);
 
-    // borders
-    // painter->setPen(option.palette.color(QPalette::Light));
-    // painter->drawLine(0, 0, line.width(), 0);
-    painter->setPen(option.palette.color(QPalette::Mid));
+    // border
+    QColor borderColor = QColor::fromHsv(topColor.hue(), saturation, value - 32);
+    painter->setPen(borderColor);
     painter->drawLine(0, line.height()-1, line.width(), line.height()-1);
 
-    // font
-    QFont boldFont = painter->font();
-    boldFont.setBold(true);
-    painter->setFont(boldFont);
+    if (album) {
+        QPixmap p = album->getThumb();
+        if (!p.isNull()) {
+            p = p.scaled(h, h, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+            painter->drawPixmap(0, 0, p);
+            painter->drawLine(h, 0, h, h-1);
+        }
+    } else if (artist) {
+        QPixmap p = artist->getPhoto();
+        if (!p.isNull()) {
+            p = p.scaled(h, h, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+            painter->drawPixmap(0, 0, p);
+            painter->drawLine(h, 0, h, h-1);
+        }
+    }
 
-    // text size
-    QFontMetrics fontMetrics = QFontMetrics(painter->font());
-    QSize trackStringSize(fontMetrics.size(Qt::TextSingleLine, headerTitle));
-
-    int width = trackStringSize.width();
-    const int maxWidth = line.width() - 80;
-    if (width > maxWidth) width = maxWidth;
-
-    QPoint textLoc(15, 0);
-    QRect trackTextBox(textLoc.x(), textLoc.y(), width, line.height());
-    headerTitle = fontMetrics.elidedText(headerTitle, Qt::ElideRight, trackTextBox.width());
-
-    // text shadow
-    painter->setPen(QColor(0, 0, 0, 64));
-    painter->drawText(trackTextBox.translated(0, -1), Qt::AlignLeft | Qt::AlignVCenter, headerTitle);
-
-    // text
-    painter->setPen(option.palette.color(QPalette::Light));
-    painter->drawText(trackTextBox, Qt::AlignLeft | Qt::AlignVCenter, headerTitle);
-    
     // album length
+    /*
     if (album) {
         // TODO this is the album duration, but not necessarily what we have in the playlist
-        int totalLength = Track::getTotalLength(album->getTracks());
-        QString albumLength;
-        if (totalLength > 3600)
-            albumLength =  QTime().addSecs(totalLength).toString("h:mm:ss");
-        else
-            albumLength = QTime().addSecs(totalLength).toString("m:ss");
+        QString albumLength = album->formattedDuration();
         QFont normalFont = painter->font();
         normalFont.setBold(false);
         // normalFont.setPointSize(boldFont.pointSize()*.9);
         painter->setFont(normalFont);
 
         // text shadow
-        painter->setPen(QColor(0, 0, 0, 64));
+        painter->setPen(QColor(0, 0, 0, 96));
         painter->drawText(line.translated(-PADDING, -1), Qt::AlignRight | Qt::AlignVCenter, albumLength);
 
-        painter->setPen(option.palette.color(QPalette::Light));
+        painter->setPen(Qt::white);
         painter->drawText(line.translated(-PADDING, 0), Qt::AlignRight | Qt::AlignVCenter, albumLength);
     }
+    */
 
-    // TODO album year
+    // font
+    QFont boldFont = painter->font();
+    boldFont.setBold(true);
+    painter->setFont(boldFont);
+
+    const QFontMetrics fontMetrics = QFontMetrics(boldFont);
+    static const int textLeft = h + fontMetrics.height()/2;
+
+    // text size
+    QSize trackStringSize(fontMetrics.size(Qt::TextSingleLine, headerTitle));
+
+    int width = trackStringSize.width();
+    const int maxWidth = line.width() - textLeft;
+    if (width > maxWidth) width = maxWidth;
+
+    QPoint textLoc(textLeft, 0);
+    QRect trackTextBox(textLoc.x(), textLoc.y(), width, line.height());
+    headerTitle = fontMetrics.elidedText(headerTitle, Qt::ElideRight, trackTextBox.width());
+
+    // text shadow
+    painter->setPen(QColor(0, 0, 0, 96));
+    painter->drawText(trackTextBox.translated(0, -1), Qt::AlignLeft | Qt::AlignVCenter, headerTitle);
+
+    // text
+    painter->setPen(Qt::white);
+    painter->drawText(trackTextBox, Qt::AlignLeft | Qt::AlignVCenter, headerTitle);
 
     painter->restore();
 }
 
-void PlaylistItemDelegate::paintTrackNumber(
-        QPainter* painter, const QStyleOptionViewItem& option, QRect line, Track* track) const {
+void PlaylistItemDelegate::paintTrackNumber(QPainter* painter, const QStyleOptionViewItem& option,
+                                            const QRect &line, Track* track) const {
 
     const int trackNumber = track->getNumber();
     if (trackNumber < 1) return;
@@ -231,39 +242,32 @@ void PlaylistItemDelegate::paintTrackNumber(
     // track number
     QFont boldFont = painter->font();
     boldFont.setBold(true);
-    boldFont.setPointSize(boldFont.pointSize()*.9);
+    boldFont.setPointSize(boldFont.pointSize()-1);
     painter->setFont(boldFont);
     QString trackString = QString("%1").arg(trackNumber, 2, 10, QChar('0'));
     QSize trackStringSize(QFontMetrics(painter->font()).size( Qt::TextSingleLine, trackString));
-    QPoint textLoc(PADDING*2, 0);
+    QPoint textLoc(PADDING*1.5, 0);
     QRect trackTextBox(textLoc.x(), textLoc.y(), trackStringSize.width(), line.height());
 
-    // rounded rect
-    QRect trackRoundedRect = trackTextBox;
-    trackRoundedRect.setY((line.height() - trackStringSize.height()) / 2);
-    trackRoundedRect.setHeight(trackStringSize.height());
-    trackRoundedRect.adjust(-PADDING/2, -PADDING/3, PADDING/2, PADDING/3);
     painter->setOpacity(.5);
-    painter->setRenderHints(QPainter::Antialiasing, true);
-    painter->setBrush(option.palette.window());
-    painter->setPen(option.palette.WindowText);
-
-    painter->drawRoundedRect(trackRoundedRect, PADDING/2, PADDING/2, Qt::AbsoluteSize);
     painter->drawText(trackTextBox, Qt::AlignCenter, trackString);
-
     painter->restore();
-
 }
 
-void PlaylistItemDelegate::paintTrackTitle(
-        QPainter* painter, const QStyleOptionViewItem& option, QRect line, Track* track) const {
+void PlaylistItemDelegate::paintTrackTitle(QPainter* painter, const QStyleOptionViewItem& option,
+                                           const QRect &line, Track* track, bool isActive) const {
+
+    Q_UNUSED(isActive);
+    Q_UNUSED(option);
+
+    painter->save();
 
     QFontMetrics fontMetrics = QFontMetrics(painter->font());
 
     QString trackTitle = track->getTitle();
 
     QSize trackStringSize(fontMetrics.size(Qt::TextSingleLine, trackTitle));
-    QPoint textLoc(PADDING*6, 0);
+    QPoint textLoc(PADDING*4.5, 0);
 
     int width = trackStringSize.width();
     const int maxWidth = line.width() - 110;
@@ -273,10 +277,11 @@ void PlaylistItemDelegate::paintTrackTitle(
     trackTitle = fontMetrics.elidedText(trackTitle, Qt::ElideRight, trackTextBox.width());
 
     painter->drawText(trackTextBox, Qt::AlignLeft | Qt::AlignVCenter, trackTitle);
+    painter->restore();
 }
 
-void PlaylistItemDelegate::paintTrackLength(
-        QPainter* painter, const QStyleOptionViewItem& option, QRect line, Track* track) const {
+void PlaylistItemDelegate::paintTrackLength(QPainter* painter, const QStyleOptionViewItem& option,
+                                            const QRect &line, Track* track) const {
 
     QString trackLength;
     if (track->getLength() > 3600)
@@ -288,16 +293,15 @@ void PlaylistItemDelegate::paintTrackLength(
     QPoint textLoc(PADDING*10, 0);
     QRect trackTextBox(textLoc.x(), textLoc.y(), line.width() - textLoc.x() - PADDING, line.height());
 
-    const bool isSelected = option.state & QStyle::State_Selected;
     painter->save();
-    if (!isSelected) painter->setPen(option.palette.color(QPalette::Mid));
+    painter->setOpacity(.5);
     painter->drawText(trackTextBox, Qt::AlignRight | Qt::AlignVCenter, trackLength);
     painter->restore();
 
 }
 
 void PlaylistItemDelegate::paintActiveOverlay(
-        QPainter *painter, const QStyleOptionViewItem& option, QRect line) const {
+        QPainter *painter,const QStyleOptionViewItem& option, const QRect &line) const {
 
     QColor highlightColor = option.palette.color(QPalette::Highlight);
     QColor backgroundColor = option.palette.color(QPalette::Base);
@@ -305,15 +309,15 @@ void PlaylistItemDelegate::paintActiveOverlay(
     const int gradientRange = 16;
 
     QColor color2 = QColor::fromHsv(
-            highlightColor.hue(),
-            (int) (backgroundColor.saturation() * (1.0f - animation) + highlightColor.saturation() * animation),
-            (int) (backgroundColor.value() * (1.0f - animation) + highlightColor.value() * animation)
-            );
+                highlightColor.hue(),
+                (int) (backgroundColor.saturation() * (1.0f - animation) + highlightColor.saturation() * animation),
+                (int) (backgroundColor.value() * (1.0f - animation) + highlightColor.value() * animation)
+                );
     QColor color1 = QColor::fromHsv(
-            color2.hue(),
-            qMax(color2.saturation() - gradientRange, 0),
-            qMin(color2.value() + gradientRange, 255)
-            );
+                color2.hue(),
+                qMax(color2.saturation() - gradientRange, 0),
+                qMin(color2.value() + gradientRange, 255)
+                );
 
     painter->save();
     painter->setPen(Qt::NoPen);
@@ -323,16 +327,3 @@ void PlaylistItemDelegate::paintActiveOverlay(
     painter->fillRect(line, linearGradient);
     painter->restore();
 }
-
-void PlaylistItemDelegate::paintSelectedOverlay( QPainter *painter, QRect line) const {
-    QColor color1 = QColor::fromRgb(0x69, 0xa6, 0xd9);
-    QColor color2 = QColor::fromRgb(0x14, 0x6b, 0xd4);
-    painter->save();
-    painter->setPen(Qt::NoPen);
-    QLinearGradient linearGradient(0, 0, 0, line.height());
-    linearGradient.setColorAt(0.0, color1);
-    linearGradient.setColorAt(1.0, color2);
-    painter->setBrush(linearGradient);
-    painter->drawRect(line);
-    painter->restore();
-}
